@@ -30,6 +30,8 @@ import org.apache.inlong.agent.conf.ProfileFetcher;
 import org.apache.inlong.agent.conf.TriggerProfile;
 import org.apache.inlong.agent.core.AgentManager;
 import org.apache.inlong.agent.db.CommandDb;
+import org.apache.inlong.agent.db.JobProfileDb;
+import org.apache.inlong.agent.db.StateSearchKey;
 import org.apache.inlong.agent.plugin.Trigger;
 import org.apache.inlong.agent.plugin.utils.PluginUtils;
 import org.apache.inlong.agent.pojo.ConfirmAgentIpRequest;
@@ -55,7 +57,9 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
+import java.util.Objects;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.stream.Collectors;
 
 import static java.util.Objects.requireNonNull;
@@ -85,6 +89,7 @@ import static org.apache.inlong.agent.constant.FetcherConstants.DEFAULT_AGENT_MA
 import static org.apache.inlong.agent.constant.FetcherConstants.DEFAULT_AGENT_TDM_IP_CHECK_HTTP_PATH;
 import static org.apache.inlong.agent.constant.FetcherConstants.DEFAULT_AGENT_TDM_VIP_HTTP_PATH;
 import static org.apache.inlong.agent.constant.FetcherConstants.VERSION;
+import static org.apache.inlong.agent.constant.JobConstants.JOB_ID;
 import static org.apache.inlong.agent.constant.JobConstants.JOB_OP;
 import static org.apache.inlong.agent.constant.JobConstants.JOB_RETRY_TIME;
 import static org.apache.inlong.agent.constant.JobConstants.JOB_TRIGGER;
@@ -255,7 +260,7 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
      * request manager to get db collect task, make sure it is not throwing exceptions
      */
     public void fetchDbCollectTask() {
-        if (agentManager.getJobManager().sqlJobExsit()) {
+        if (agentManager.getJobManager().sqlJobExist()) {
             return;
         }
         JsonObject resultData = getResultData(httpManager.doSentPost(managerDbCollectorTaskUrl, getSqlTaskRequest()));
@@ -287,6 +292,9 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
         }
         for (DataConfig dataConfig : taskResult.getDataConfigs()) {
             TriggerProfile profile = TriggerProfile.getTriggerProfiles(dataConfig);
+            if (triggerIsRunning(profile)) {
+                continue;
+            }
             LOGGER.info("the triggerProfile: {}", profile.toJsonStr());
             if (profile.hasKey(JOB_TRIGGER)) {
                 dealWithTdmTriggerProfile(profile);
@@ -300,6 +308,24 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
         }
     }
 
+    private boolean triggerIsRunning(TriggerProfile newProfile) {
+        int type = ManagerOpEnum.getOpType(newProfile.getInt(JOB_OP)).getType();
+        if (ManagerOpEnum.ACTIVE.getType() != type || ManagerOpEnum.ADD.getType() != type) {
+            return false;
+        }
+        JobProfileDb jobProfileDb = agentManager.getJobProfileDb();
+        List<JobProfile> jobsByState = jobProfileDb.getJobsByState(StateSearchKey.ACCEPTED);
+        jobsByState.addAll(jobProfileDb.getJobsByState(StateSearchKey.RUNNING));
+        AtomicBoolean jobIsRunning = new AtomicBoolean(false);
+        jobsByState.forEach(jobProfile -> {
+            if (Objects.equals(jobProfile.get(JOB_ID), newProfile.get(JOB_ID))) {
+                LOGGER.error("job is running or accepted, {} submit failed", newProfile.get(JOB_ID));
+                jobIsRunning.set(true);
+            }
+        });
+        return jobIsRunning.get();
+    }
+
     /**
      * form file command fetch request
      */
@@ -387,7 +413,7 @@ public class ManagerFetcher extends AbstractDaemon implements ProfileFetcher {
         Collection<File> suitFiles = PluginUtils.findSuitFiles(triggerProfile);
         // filter files exited before
         List<File> pendingFiles = suitFiles.stream().filter(file ->
-                !agentManager.getJobManager().checkJobExsit(file.getAbsolutePath()))
+                !agentManager.getJobManager().checkJobExist(file.getAbsolutePath()))
                 .collect(Collectors.toList());
         for (File pendingFile : pendingFiles) {
             JobProfile copiedProfile = copyJobProfile(triggerProfile, dataTime,
