@@ -1,10 +1,10 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
+ * contributor license agreements. See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
+ * the License. You may obtain a copy of the License at
  *
  * http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -66,35 +66,30 @@ import java.util.Set;
 import java.util.concurrent.locks.ReentrantLock;
 
 /**
- * Application
+ * DataProxy application
  */
 public class Application {
 
-    private static final Logger logger = LoggerFactory
-            .getLogger(Application.class);
-
-    public static final String CONF_MONITOR_CLASS = "flume.monitoring.type";
-    public static final String CONF_MONITOR_PREFIX = "flume.monitoring.";
+    private static final Logger LOGGER = LoggerFactory.getLogger(Application.class);
 
+    private static final String CONF_MONITOR_CLASS = "flume.monitoring.type";
+    private static final String CONF_MONITOR_PREFIX = "flume.monitoring.";
     private final List<LifecycleAware> components;
     private final LifecycleSupervisor supervisor;
+    private final ReentrantLock lifecycleLock = new ReentrantLock();
     private MaterializedConfiguration materializedConfiguration;
     private MonitorService monitorServer;
-    private final ReentrantLock lifecycleLock = new ReentrantLock();
     private AdminTask adminTask;
-    private HeartbeatManager heartbeatManager;
 
     /**
      * Constructor
      */
     public Application() {
-        this(new ArrayList<LifecycleAware>(0));
+        this(new ArrayList<>(0));
     }
 
     /**
      * Constructor
-     *
-     * @param components
      */
     public Application(List<LifecycleAware> components) {
         this.components = components;
@@ -102,223 +97,11 @@ public class Application {
     }
 
     /**
-     * start
-     */
-    public void start() {
-        lifecycleLock.lock();
-        try {
-            for (LifecycleAware component : components) {
-                // update dataproxy config
-                if (component instanceof IDataProxyConfigHolder) {
-                    ((IDataProxyConfigHolder) component)
-                            .setDataProxyConfig(
-                                    RemoteConfigManager.getInstance().getCurrentClusterConfigRef());
-                }
-                supervisor.supervise(component,
-                        new SupervisorPolicy.AlwaysRestartPolicy(), LifecycleState.START);
-            }
-            // start admin task
-            this.adminTask = new AdminTask(new Context(CommonPropertiesHolder.get()));
-            this.adminTask.start();
-            this.heartbeatManager = new HeartbeatManager();
-            this.heartbeatManager.start();
-        } finally {
-            lifecycleLock.unlock();
-        }
-    }
-
-    /**
-     * handleConfigurationEvent
-     *
-     * @param conf
-     */
-    @Subscribe
-    public void handleConfigurationEvent(MaterializedConfiguration conf) {
-        try {
-            lifecycleLock.lockInterruptibly();
-            stopAllComponents();
-            startAllComponents(conf);
-        } catch (InterruptedException e) {
-            logger.info("Interrupted while trying to handle configuration event");
-            return;
-        } finally {
-            // If interrupted while trying to lock, we don't own the lock, so must not attempt to unlock
-            if (lifecycleLock.isHeldByCurrentThread()) {
-                lifecycleLock.unlock();
-            }
-        }
-    }
-
-    /**
-     * stop
-     */
-    public void stop() {
-        lifecycleLock.lock();
-        stopAllComponents();
-        try {
-            supervisor.stop();
-            if (monitorServer != null) {
-                monitorServer.stop();
-            }
-            // stop admin task
-            if (this.adminTask != null) {
-                this.adminTask.stop();
-            }
-        } finally {
-            lifecycleLock.unlock();
-        }
-    }
-
-    /**
-     * stopAllComponents
-     */
-    private void stopAllComponents() {
-        if (this.materializedConfiguration != null) {
-            logger.info("Shutting down configuration: {}", this.materializedConfiguration);
-            for (Entry<String, SourceRunner> entry : this.materializedConfiguration
-                    .getSourceRunners().entrySet()) {
-                try {
-                    logger.info("Stopping Source " + entry.getKey());
-                    supervisor.unsupervise(entry.getValue());
-                } catch (Exception e) {
-                    logger.error("Error while stopping {}", entry.getValue(), e);
-                }
-            }
-
-            for (Entry<String, SinkRunner> entry : this.materializedConfiguration.getSinkRunners()
-                    .entrySet()) {
-                try {
-                    logger.info("Stopping Sink " + entry.getKey());
-                    supervisor.unsupervise(entry.getValue());
-                } catch (Exception e) {
-                    logger.error("Error while stopping {}", entry.getValue(), e);
-                }
-            }
-
-            for (Entry<String, Channel> entry : this.materializedConfiguration.getChannels()
-                    .entrySet()) {
-                try {
-                    logger.info("Stopping Channel " + entry.getKey());
-                    supervisor.unsupervise(entry.getValue());
-                } catch (Exception e) {
-                    logger.error("Error while stopping {}", entry.getValue(), e);
-                }
-            }
-        }
-        if (monitorServer != null) {
-            monitorServer.stop();
-        }
-    }
-
-    /**
-     * startAllComponents
-     *
-     * @param materializedConfiguration
-     */
-    private void startAllComponents(MaterializedConfiguration materializedConfiguration) {
-        logger.info("Starting new configuration:{}", materializedConfiguration);
-
-        this.materializedConfiguration = materializedConfiguration;
-
-        for (Entry<String, Channel> entry : materializedConfiguration.getChannels().entrySet()) {
-            try {
-                logger.info("Starting Channel " + entry.getKey());
-                supervisor.supervise(entry.getValue(),
-                        new SupervisorPolicy.AlwaysRestartPolicy(), LifecycleState.START);
-            } catch (Exception e) {
-                logger.error("Error while starting {}", entry.getValue(), e);
-            }
-        }
-
-        /*
-         * Wait for all channels to start.
-         */
-        for (Channel ch : materializedConfiguration.getChannels().values()) {
-            while (ch.getLifecycleState() != LifecycleState.START
-                    && !supervisor.isComponentInErrorState(ch)) {
-                try {
-                    logger.info("Waiting for channel: " + ch.getName()
-                            + " to start. Sleeping for 500 ms");
-                    Thread.sleep(500);
-                } catch (InterruptedException e) {
-                    logger.error("Interrupted while waiting for channel to start.", e);
-                    Throwables.propagate(e);
-                }
-            }
-        }
-
-        for (Entry<String, SinkRunner> entry : materializedConfiguration.getSinkRunners()
-                .entrySet()) {
-            try {
-                logger.info("Starting Sink " + entry.getKey());
-                supervisor.supervise(entry.getValue(),
-                        new SupervisorPolicy.AlwaysRestartPolicy(), LifecycleState.START);
-            } catch (Exception e) {
-                logger.error("Error while starting {}", entry.getValue(), e);
-            }
-        }
-
-        for (Entry<String, SourceRunner> entry : materializedConfiguration.getSourceRunners()
-                .entrySet()) {
-            try {
-                logger.info("Starting Source " + entry.getKey());
-                supervisor.supervise(entry.getValue(),
-                        new SupervisorPolicy.AlwaysRestartPolicy(), LifecycleState.START);
-            } catch (Exception e) {
-                logger.error("Error while starting {}", entry.getValue(), e);
-            }
-        }
-
-        this.loadMonitoring();
-    }
-
-    /**
-     * loadMonitoring
-     */
-    @SuppressWarnings("unchecked")
-    private void loadMonitoring() {
-        Properties systemProps = System.getProperties();
-        Set<String> keys = systemProps.stringPropertyNames();
-        try {
-            if (keys.contains(CONF_MONITOR_CLASS)) {
-                String monitorType = systemProps.getProperty(CONF_MONITOR_CLASS);
-                Class<? extends MonitorService> klass;
-                try {
-                    // Is it a known type?
-                    klass = MonitoringType.valueOf(
-                            monitorType.toUpperCase(Locale.ENGLISH)).getMonitorClass();
-                } catch (Exception e) {
-                    // Not a known type, use FQCN
-                    klass = (Class<? extends MonitorService>) Class.forName(monitorType);
-                }
-                this.monitorServer = klass.getDeclaredConstructor().newInstance();
-                Context context = new Context();
-                for (String key : keys) {
-                    if (key.startsWith(CONF_MONITOR_PREFIX)) {
-                        context.put(key.substring(CONF_MONITOR_PREFIX.length()),
-                                systemProps.getProperty(key));
-                    }
-                }
-                monitorServer.configure(context);
-                monitorServer.start();
-            }
-        } catch (Exception e) {
-            logger.warn("Error starting monitoring. "
-                    + "Monitoring might not be available.", e);
-        }
-
-    }
-
-    /**
-     * main
-     *
-     * @param args
+     * Main entrance
      */
     public static void main(String[] args) {
-
         try {
             SSLUtil.initGlobalSSLParameters();
-
             Options options = new Options();
 
             Option option = new Option("n", "name", true, "the name of this agent");
@@ -362,7 +145,7 @@ public class Application {
                 return;
             }
 
-            // start by manager configuation
+            // start by manager configuration
             if (commandLine.hasOption("load-conf-from-manager")) {
                 startByManagerConf(commandLine);
                 return;
@@ -371,10 +154,7 @@ public class Application {
             String agentName = commandLine.getOptionValue('n');
             boolean reload = !commandLine.hasOption("no-reload-conf");
 
-            boolean isZkConfigured = false;
-            if (commandLine.hasOption('z') || commandLine.hasOption("zkConnString")) {
-                isZkConfigured = true;
-            }
+            boolean isZkConfigured = commandLine.hasOption('z') || commandLine.hasOption("zkConnString");
 
             Application application;
             if (isZkConfigured) {
@@ -398,7 +178,6 @@ public class Application {
                 }
             } else {
                 File configurationFile = new File(commandLine.getOptionValue('f'));
-
                 // The following is to ensure that by default the agent will fail on startup
                 // if the file does not exist.
                 if (!configurationFile.exists()) {
@@ -408,15 +187,13 @@ public class Application {
                         try {
                             path = configurationFile.getCanonicalPath();
                         } catch (IOException ex) {
-                            logger.error("Failed to read canonical path for file: " + path,
-                                    ex);
+                            LOGGER.error("failed to read canonical path for file: " + path, ex);
                         }
-                        throw new ParseException(
-                                "The specified configuration file does not exist: " + path);
+                        throw new ParseException("configuration file does not exist: " + path);
                     }
                 }
-                List<LifecycleAware> components = Lists.newArrayList();
 
+                List<LifecycleAware> components = Lists.newArrayList();
                 if (reload) {
                     EventBus eventBus = new EventBus(agentName + "-event-bus");
                     PollingPropertiesFileConfigurationProvider configurationProvider;
@@ -427,8 +204,7 @@ public class Application {
                     eventBus.register(application);
                 } else {
                     PropertiesFileConfigurationProvider configurationProvider;
-                    configurationProvider = new PropertiesFileConfigurationProvider(
-                            agentName, configurationFile);
+                    configurationProvider = new PropertiesFileConfigurationProvider(agentName, configurationFile);
                     application = new Application();
                     application.handleConfigurationEvent(configurationProvider.getConfiguration());
                 }
@@ -439,11 +215,10 @@ public class Application {
             AuditUtils.initAudit();
 
             final Application appReference = application;
-            Runtime.getRuntime().addShutdownHook(new Thread("agent-shutdown-hook") {
-
+            Runtime.getRuntime().addShutdownHook(new Thread("data-proxy-shutdown-hook") {
                 @Override
                 public void run() {
-                    AuditUtils.sendReport();
+                    AuditUtils.send();
                     appReference.stop();
                 }
             });
@@ -452,30 +227,217 @@ public class Application {
             application.start();
             Thread.sleep(5000);
         } catch (Exception e) {
-            logger.error("A fatal error occurred while running. Exception follows.", e);
+            LOGGER.error("fatal error occurred while running data-proxy: ", e);
         }
     }
 
     /**
-     * startByManagerConf
-     *
-     * @param commandLine
+     * Start by Manager config
      */
     private static void startByManagerConf(CommandLine commandLine) {
         String proxyName = CommonPropertiesHolder.getString(RemoteConfigManager.KEY_PROXY_CLUSTER_NAME);
-        ManagerPropertiesConfigurationProvider configurationProvider = new ManagerPropertiesConfigurationProvider(
-                proxyName);
+        ManagerPropsConfigProvider configurationProvider = new ManagerPropsConfigProvider(proxyName);
         Application application = new Application();
         application.handleConfigurationEvent(configurationProvider.getConfiguration());
         application.start();
 
         final Application appReference = application;
-        Runtime.getRuntime().addShutdownHook(new Thread("agent-shutdown-hook") {
-
+        Runtime.getRuntime().addShutdownHook(new Thread("data-proxy-shutdown-hook") {
             @Override
             public void run() {
                 appReference.stop();
             }
         });
     }
-}
\ No newline at end of file
+
+    /**
+     * Start all components
+     */
+    public void start() {
+        lifecycleLock.lock();
+        try {
+            for (LifecycleAware component : components) {
+                // update dataproxy config
+                if (component instanceof IDataProxyConfigHolder) {
+                    ((IDataProxyConfigHolder) component).setDataProxyConfig(
+                            RemoteConfigManager.getInstance().getCurrentClusterConfigRef());
+                }
+                supervisor.supervise(component, new SupervisorPolicy.AlwaysRestartPolicy(), LifecycleState.START);
+            }
+            // start admin task
+            this.adminTask = new AdminTask(new Context(CommonPropertiesHolder.get()));
+            this.adminTask.start();
+            HeartbeatManager heartbeatManager = new HeartbeatManager();
+            heartbeatManager.start();
+        } finally {
+            lifecycleLock.unlock();
+        }
+    }
+
+    /**
+     * Handle the configuration event
+     */
+    @Subscribe
+    public void handleConfigurationEvent(MaterializedConfiguration conf) {
+        try {
+            lifecycleLock.lockInterruptibly();
+            stopAllComponents();
+            startAllComponents(conf);
+        } catch (InterruptedException e) {
+            LOGGER.info("interrupted while handle the configuration event");
+        } finally {
+            // If interrupted while trying to lock, we don't own the lock, so must not attempt to unlock
+            if (lifecycleLock.isHeldByCurrentThread()) {
+                lifecycleLock.unlock();
+            }
+        }
+    }
+
+    /**
+     * Stop the application
+     */
+    public void stop() {
+        lifecycleLock.lock();
+        stopAllComponents();
+        try {
+            supervisor.stop();
+            if (monitorServer != null) {
+                monitorServer.stop();
+            }
+            // stop admin task
+            if (this.adminTask != null) {
+                this.adminTask.stop();
+            }
+        } finally {
+            lifecycleLock.unlock();
+        }
+    }
+
+    /**
+     * Stop all components
+     */
+    private void stopAllComponents() {
+        LOGGER.info("shutting down configuration: {}", materializedConfiguration);
+        if (materializedConfiguration != null) {
+            for (Entry<String, SourceRunner> entry : materializedConfiguration.getSourceRunners().entrySet()) {
+                try {
+                    LOGGER.info("stopping source " + entry.getKey());
+                    supervisor.unsupervise(entry.getValue());
+                } catch (Exception e) {
+                    LOGGER.error("error while stopping source " + entry.getValue(), e);
+                }
+            }
+
+            for (Entry<String, SinkRunner> entry : materializedConfiguration.getSinkRunners().entrySet()) {
+                try {
+                    LOGGER.info("stopping sink " + entry.getKey());
+                    supervisor.unsupervise(entry.getValue());
+                } catch (Exception e) {
+                    LOGGER.error("error while stopping sink " + entry.getValue(), e);
+                }
+            }
+
+            for (Entry<String, Channel> entry : materializedConfiguration.getChannels().entrySet()) {
+                try {
+                    LOGGER.info("stopping channel " + entry.getKey());
+                    supervisor.unsupervise(entry.getValue());
+                } catch (Exception e) {
+                    LOGGER.error("error while stopping channel " + entry.getValue(), e);
+                }
+            }
+        }
+
+        LOGGER.info("shutting down monitor server: {}", monitorServer);
+        if (monitorServer != null) {
+            monitorServer.stop();
+        }
+    }
+
+    /**
+     * Start all components
+     */
+    private void startAllComponents(MaterializedConfiguration materializedConfiguration) {
+        LOGGER.info("Starting new configuration:{}", materializedConfiguration);
+
+        this.materializedConfiguration = materializedConfiguration;
+        for (Entry<String, Channel> entry : materializedConfiguration.getChannels().entrySet()) {
+            try {
+                LOGGER.info("starting channel " + entry.getKey());
+                supervisor.supervise(entry.getValue(), new SupervisorPolicy.AlwaysRestartPolicy(),
+                        LifecycleState.START);
+            } catch (Exception e) {
+                LOGGER.error("error while starting channel " + entry.getValue(), e);
+            }
+        }
+
+        // Wait for all channels to start.
+        for (Channel ch : materializedConfiguration.getChannels().values()) {
+            while (ch.getLifecycleState() != LifecycleState.START
+                    && !supervisor.isComponentInErrorState(ch)) {
+                try {
+                    LOGGER.info("sleeping for 500 ms to wait for channel: {} to start", ch.getName());
+                    Thread.sleep(500);
+                } catch (InterruptedException e) {
+                    LOGGER.error("interrupted while waiting for channel to start: ", e);
+                    Throwables.propagate(e);
+                }
+            }
+        }
+
+        for (Entry<String, SinkRunner> entry : materializedConfiguration.getSinkRunners().entrySet()) {
+            try {
+                LOGGER.info("starting sink " + entry.getKey());
+                supervisor.supervise(entry.getValue(), new SupervisorPolicy.AlwaysRestartPolicy(),
+                        LifecycleState.START);
+            } catch (Exception e) {
+                LOGGER.error("error while starting sink: " + entry.getValue(), e);
+            }
+        }
+
+        for (Entry<String, SourceRunner> entry : materializedConfiguration.getSourceRunners().entrySet()) {
+            try {
+                LOGGER.info("starting source " + entry.getKey());
+                supervisor.supervise(entry.getValue(), new SupervisorPolicy.AlwaysRestartPolicy(),
+                        LifecycleState.START);
+            } catch (Exception e) {
+                LOGGER.error("error while starting source: " + entry.getValue(), e);
+            }
+        }
+
+        this.loadMonitoring();
+    }
+
+    /**
+     * Load monitoring
+     */
+    @SuppressWarnings("unchecked")
+    private void loadMonitoring() {
+        Properties systemProps = System.getProperties();
+        Set<String> keys = systemProps.stringPropertyNames();
+        try {
+            if (keys.contains(CONF_MONITOR_CLASS)) {
+                String monitorType = systemProps.getProperty(CONF_MONITOR_CLASS);
+                Class<? extends MonitorService> klass;
+                try {
+                    // Is it a known type?
+                    klass = MonitoringType.valueOf(monitorType.toUpperCase(Locale.ENGLISH)).getMonitorClass();
+                } catch (Exception e) {
+                    // Not a known type, use FQCN
+                    klass = (Class<? extends MonitorService>) Class.forName(monitorType);
+                }
+                this.monitorServer = klass.getDeclaredConstructor().newInstance();
+                Context context = new Context();
+                for (String key : keys) {
+                    if (key.startsWith(CONF_MONITOR_PREFIX)) {
+                        context.put(key.substring(CONF_MONITOR_PREFIX.length()), systemProps.getProperty(key));
+                    }
+                }
+                monitorServer.configure(context);
+                monitorServer.start();
+            }
+        } catch (Exception e) {
+            LOGGER.warn("starting monitoring error, the monitoring might not be available: ", e);
+        }
+    }
+
+}
