@@ -17,9 +17,10 @@
 
 package org.apache.inlong.dataproxy.sink;
 
-import static org.apache.inlong.dataproxy.consts.AttributeConstants.SEP_HASHTAG;
+import static org.apache.inlong.dataproxy.consts.AttrConstants.SEP_HASHTAG;
 import static org.apache.inlong.dataproxy.consts.ConfigConstants.MAX_MONITOR_CNT;
-import java.util.HashMap;
+
+import com.google.common.base.Preconditions;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
@@ -29,10 +30,9 @@ import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
-import com.google.common.base.Preconditions;
 import org.apache.commons.collections.SetUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.lang3.math.NumberUtils;
+import org.apache.commons.lang3.tuple.Pair;
 import org.apache.flume.Channel;
 import org.apache.flume.Context;
 import org.apache.flume.Event;
@@ -42,25 +42,27 @@ import org.apache.flume.Transaction;
 import org.apache.flume.conf.Configurable;
 import org.apache.flume.sink.AbstractSink;
 import org.apache.flume.source.shaded.guava.RateLimiter;
+import org.apache.inlong.common.enums.DataProxyErrCode;
 import org.apache.inlong.common.metric.MetricRegister;
 import org.apache.inlong.common.monitor.LogCounter;
 import org.apache.inlong.common.monitor.MonitorIndex;
 import org.apache.inlong.common.monitor.MonitorIndexExt;
+import org.apache.inlong.common.msg.AttributeConstants;
+import org.apache.inlong.common.util.NetworkUtils;
 import org.apache.inlong.dataproxy.base.HighPriorityThreadFactory;
+import org.apache.inlong.dataproxy.base.SinkRspEvent;
 import org.apache.inlong.dataproxy.config.ConfigManager;
 import org.apache.inlong.dataproxy.config.holder.ConfigUpdateCallback;
 import org.apache.inlong.dataproxy.config.pojo.MQClusterConfig;
-import org.apache.inlong.dataproxy.consts.AttributeConstants;
 import org.apache.inlong.dataproxy.consts.ConfigConstants;
-import org.apache.inlong.dataproxy.metrics.DataProxyMetricItem;
 import org.apache.inlong.dataproxy.metrics.DataProxyMetricItemSet;
 import org.apache.inlong.dataproxy.metrics.audit.AuditUtils;
 import org.apache.inlong.dataproxy.sink.common.MsgDedupHandler;
 import org.apache.inlong.dataproxy.sink.common.TubeProducerHolder;
 import org.apache.inlong.dataproxy.sink.common.TubeUtils;
-import org.apache.inlong.dataproxy.utils.Constants;
+import org.apache.inlong.dataproxy.utils.DateTimeUtils;
 import org.apache.inlong.dataproxy.utils.FailoverChannelProcessorHolder;
-import org.apache.inlong.dataproxy.utils.NetworkUtils;
+import org.apache.inlong.dataproxy.utils.MessageUtils;
 import org.apache.inlong.tubemq.client.exception.TubeClientException;
 import org.apache.inlong.tubemq.client.producer.MessageProducer;
 import org.apache.inlong.tubemq.client.producer.MessageSentCallback;
@@ -74,8 +76,6 @@ public class TubeSink extends AbstractSink implements Configurable {
     private static final Logger logger = LoggerFactory.getLogger(TubeSink.class);
     private static final MsgDedupHandler MSG_DEDUP_HANDLER = new MsgDedupHandler();
     private TubeProducerHolder producerHolder = null;
-    private static final String TOPIC = "topic";
-    private volatile boolean canTake = false;
     private volatile boolean canSend = false;
     private volatile boolean isOverFlow = false;
     private ConfigManager configManager;
@@ -95,7 +95,6 @@ public class TubeSink extends AbstractSink implements Configurable {
     // used for RoundRobin different cluster while send message
     private RateLimiter diskRateLimiter;
     private Thread[] sinkThreadPool;
-    private Map<String, String> dimensions;
     private DataProxyMetricItemSet metricItemSet;
     private final AtomicBoolean started = new AtomicBoolean(false);
     private static final LogCounter LOG_SINK_TASK_PRINTER =
@@ -128,14 +127,16 @@ public class TubeSink extends AbstractSink implements Configurable {
         tubeConfig = configManager.getMqClusterConfig();
         topicProperties = configManager.getTopicProperties();
         masterHostAndPortLists = configManager.getMqClusterUrl2Token().keySet();
-        // start message deduplication handler
-        MSG_DEDUP_HANDLER.start(tubeConfig.getClientIdCache(),
-                tubeConfig.getMaxSurvivedTime(), tubeConfig.getMaxSurvivedSize());
         // only use first cluster address now
         usedMasterAddr = getFirstClusterAddr(masterHostAndPortLists);
         // create producer holder
-        producerHolder = new TubeProducerHolder(getName(),
-                usedMasterAddr, configManager.getMqClusterConfig());
+        if (usedMasterAddr != null) {
+            producerHolder = new TubeProducerHolder(getName(),
+                    usedMasterAddr, configManager.getMqClusterConfig());
+        }
+        // start message deduplication handler
+        MSG_DEDUP_HANDLER.start(tubeConfig.getClientIdCache(),
+                tubeConfig.getMaxSurvivedTime(), tubeConfig.getMaxSurvivedSize());
         // get statistic configure items
         maxMonitorCnt = context.getInteger(MAX_MONITOR_CNT, 300000);
         statIntervalSec = tubeConfig.getStatIntervalSec();
@@ -187,25 +188,29 @@ public class TubeSink extends AbstractSink implements Configurable {
             monitorIndexExt = new MonitorIndexExt("Tube_Sink_monitors#" + this.getName(),
                     statIntervalSec, maxMonitorCnt);
         }
-        // initial dimensions
-        this.dimensions = new HashMap<>();
-        this.dimensions.put(DataProxyMetricItem.KEY_CLUSTER_ID, "DataProxy");
-        this.dimensions.put(DataProxyMetricItem.KEY_SINK_ID, this.getName());
         // register metrics
-        this.metricItemSet = new DataProxyMetricItemSet(this.getName());
+        ConfigManager configManager = ConfigManager.getInstance();
+        String clusterId =
+                configManager.getCommonProperties().getOrDefault(
+                        ConfigConstants.PROXY_CLUSTER_NAME,
+                        ConfigConstants.DEFAULT_PROXY_CLUSTER_NAME);
+        this.metricItemSet = new DataProxyMetricItemSet(clusterId, this.getName());
         MetricRegister.register(metricItemSet);
         // create tube connection
-        try {
-            producerHolder.start(new HashSet<>(topicProperties.values()));
-        } catch (FlumeException e) {
-            logger.error("Unable to start TubeMQ client. Exception follows.", e);
-            super.stop();
-            return;
+        if (producerHolder != null) {
+            try {
+                producerHolder.start(new HashSet<>(topicProperties.values()));
+                ConfigManager.getInstance().updMqClusterStatus(true);
+                logger.info("[{}] MQ Cluster service status ready!", getName());
+            } catch (FlumeException e) {
+                logger.error("Unable to start TubeMQ client. Exception follows.", e);
+                super.stop();
+                return;
+            }
         }
         // start the cleaner thread
         super.start();
         this.canSend = true;
-        this.canTake = true;
         for (int i = 0; i < sinkThreadPool.length; i++) {
             sinkThreadPool[i] = new Thread(new TubeSinkTask(),
                     getName() + "_tube_sink_sender-" + i);
@@ -220,7 +225,6 @@ public class TubeSink extends AbstractSink implements Configurable {
             logger.info("Duplicated call, " + getName() + " has stopped!");
             return;
         }
-        this.canTake = false;
         // waiting inflight message processed
         int waitCount = 0;
         while (takenMsgCnt.get() > 0 && waitCount++ < 10) {
@@ -260,7 +264,7 @@ public class TubeSink extends AbstractSink implements Configurable {
 
     @Override
     public Status process() throws EventDeliveryException {
-        if (!this.canTake) {
+        if (!this.started.get()) {
             return Status.BACKOFF;
         }
         Status status = Status.READY;
@@ -273,31 +277,13 @@ public class TubeSink extends AbstractSink implements Configurable {
                 if (diskRateLimiter != null) {
                     diskRateLimiter.acquire(event.getBody().length);
                 }
-                Map<String, String> dimensions;
-                if (event.getHeaders().containsKey(TOPIC)) {
-                    dimensions = getNewDimension(DataProxyMetricItem.KEY_SINK_DATA_ID,
-                            event.getHeaders().get(TOPIC));
-                } else {
-                    dimensions = getNewDimension(DataProxyMetricItem.KEY_SINK_DATA_ID, "");
-                }
                 if (eventQueue.offer(event, 3 * 1000, TimeUnit.MILLISECONDS)) {
                     tx.commit();
                     cachedMsgCnt.incrementAndGet();
-                    DataProxyMetricItem metricItem = this.metricItemSet.findMetricItem(dimensions);
-                    metricItem.readSuccessCount.incrementAndGet();
-                    metricItem.readFailSize.addAndGet(event.getBody().length);
                 } else {
                     tx.rollback();
-                    //logger.info("[{}] Channel --> Queue(has no enough space,current code point) "
-                    //        + "--> TubeMQ, check if TubeMQ server or network is ok.(if this situation last long time "
-                    //        + "it will cause memoryChannel full and fileChannel write.)", getName());
-                    // metric
-                    DataProxyMetricItem metricItem = this.metricItemSet.findMetricItem(dimensions);
-                    metricItem.readFailCount.incrementAndGet();
-                    metricItem.readFailSize.addAndGet(event.getBody().length);
                 }
             } else {
-                // logger.info("[{}]No data to process in the channel.",getName());
                 status = Status.BACKOFF;
                 tx.commit();
             }
@@ -325,43 +311,35 @@ public class TubeSink extends AbstractSink implements Configurable {
             EventStat es = null;
             String topic = null;
             boolean bChangedInflightValue = false;
-            MessageProducer producer = null;
             logger.info("sink task {} started.", Thread.currentThread().getName());
             while (canSend) {
                 try {
+                    if (!started.get() && cachedMsgCnt.get() <= 0) {
+                        logger.info("Found started is false and taken message count is zero, braek!");
+                        break;
+                    }
                     if (isOverFlow) {
                         isOverFlow = false;
                         Thread.sleep(30);
                     }
-                    event = null;
-                    topic = null;
                     // get event from queues
-                    if (!resendQueue.isEmpty()) {
+                    if (resendQueue.isEmpty()) {
+                        event = eventQueue.poll(2000, TimeUnit.MILLISECONDS);
+                        if (event == null) {
+                            continue;
+                        }
+                        cachedMsgCnt.decrementAndGet();
+                        takenMsgCnt.incrementAndGet();
+                        es = new EventStat(event);
+                    } else {
                         es = resendQueue.poll();
                         if (es == null) {
                             continue;
                         }
                         resendMsgCnt.decrementAndGet();
                         event = es.getEvent();
-                        if (event.getHeaders().containsKey(TOPIC)) {
-                            topic = event.getHeaders().get(TOPIC);
-                        }
-                    } else {
-                        event = eventQueue.poll(2000, TimeUnit.MILLISECONDS);
-                        if (event == null) {
-                            if (!canTake && takenMsgCnt.get() <= 0) {
-                                logger.info("Found canTake is false and taken message count is zero, braek!");
-                                break;
-                            }
-                            continue;
-                        }
-                        cachedMsgCnt.decrementAndGet();
-                        takenMsgCnt.incrementAndGet();
-                        es = new EventStat(event);
-                        if (event.getHeaders().containsKey(TOPIC)) {
-                            topic = event.getHeaders().get(TOPIC);
-                        }
                     }
+                    topic = event.getHeaders().get(ConfigConstants.TOPIC_KEY);
                     // valid event status
                     if (StringUtils.isBlank(topic)) {
                         blankTopicDiscardMsgCnt.incrementAndGet();
@@ -376,12 +354,13 @@ public class TubeSink extends AbstractSink implements Configurable {
                         continue;
                     }
                     // send message
-                    bChangedInflightValue = sendMessage(es, event, topic);
+                    bChangedInflightValue = sendMessage(es, topic);
                 } catch (InterruptedException e) {
                     logger.info("Thread {} has been interrupted!", Thread.currentThread().getName());
                     return;
                 } catch (Throwable t) {
-                    resendEvent(es, bChangedInflightValue);
+                    resendEvent(es, bChangedInflightValue,
+                            DataProxyErrCode.SEND_REQUEST_TO_MQ_FAILURE, t.getMessage());
                     if (t instanceof TubeClientException) {
                         String message = t.getMessage();
                         if (message != null && (message.contains("No available queue for topic")
@@ -400,7 +379,9 @@ public class TubeSink extends AbstractSink implements Configurable {
             logger.info("sink task {} stopped!", Thread.currentThread().getName());
         }
 
-        private boolean sendMessage(EventStat es, Event event, String topic) throws Exception {
+        private boolean sendMessage(EventStat es, String topic) throws Exception {
+            String errMsg = "";
+            Event event = es.getEvent();
             MessageProducer producer = producerHolder.getProducer(topic);
             if (producer == null) {
                 frozenTopicDiscardMsgCnt.incrementAndGet();
@@ -408,8 +389,13 @@ public class TubeSink extends AbstractSink implements Configurable {
                 if (statIntervalSec > 0) {
                     monitorIndexExt.incrementAndGet(KEY_SINK_DROPPED);
                 }
+                errMsg = "Get producer failed for " + topic;
+                if (MessageUtils.isSinkRspType(event)) {
+                    MessageUtils.sinkReturnRspPackage((SinkRspEvent) event,
+                            DataProxyErrCode.PRODUCER_IS_NULL, errMsg);
+                }
                 if (LOG_SINK_TASK_PRINTER.shouldPrint()) {
-                    logger.error("Get producer failed for " + topic);
+                    logger.error(errMsg);
                 }
                 return false;
             }
@@ -420,13 +406,18 @@ public class TubeSink extends AbstractSink implements Configurable {
                 if (statIntervalSec > 0) {
                     monitorIndexExt.incrementAndGet(KEY_SINK_DROPPED);
                 }
+                errMsg = "Duplicated message discard, by uuid = "
+                        + event.getHeaders().get(ConfigConstants.SEQUENCE_ID);
+                if (MessageUtils.isSinkRspType(event)) {
+                    MessageUtils.sinkReturnRspPackage((SinkRspEvent) event,
+                            DataProxyErrCode.DUPLICATED_MESSAGE, errMsg);
+                }
                 logger.info("{} agent package {} existed,just discard.",
                         Thread.currentThread().getName(),
                         event.getHeaders().get(ConfigConstants.SEQUENCE_ID));
                 return false;
             } else {
-                producer.sendMessage(TubeUtils.buildMessage(
-                        topic, event, false), new MyCallback(es));
+                producer.sendMessage(TubeUtils.buildMessage(topic, event), new MyCallback(es));
                 inflightMsgCnt.incrementAndGet();
                 return true;
             }
@@ -449,17 +440,13 @@ public class TubeSink extends AbstractSink implements Configurable {
                 successMsgCnt.incrementAndGet();
                 inflightMsgCnt.decrementAndGet();
                 takenMsgCnt.decrementAndGet();
-                this.addMetric(myEventStat.getEvent(), true, sendTime);
-                if (statIntervalSec > 0) {
-                    monitorIndexExt.incrementAndGet(KEY_SINK_SUCCESS);
+                this.addStatistics(myEventStat.getEvent(), true, false, sendTime);
+                if (MessageUtils.isSinkRspType(myEventStat.getEvent())) {
+                    MessageUtils.sinkReturnRspPackage((SinkRspEvent) myEventStat.getEvent(),
+                            DataProxyErrCode.SUCCESS, "");
                 }
-                this.editStatistic(myEventStat.getEvent(), true);
             } else {
-                this.addMetric(myEventStat.getEvent(), false, 0);
-                if (statIntervalSec > 0) {
-                    monitorIndexExt.incrementAndGet(KEY_SINK_FAILURE);
-                }
-                this.editStatistic(myEventStat.getEvent(), false);
+                this.addStatistics(myEventStat.getEvent(), false, false, 0);
                 if (result.getErrCode() == TErrCodeConstants.FORBIDDEN) {
                     logger.warn("Send message failed, error message: {}, resendQueue size: {}, event:{}",
                             result.getErrMsg(), resendQueue.size(),
@@ -471,105 +458,68 @@ public class TubeSink extends AbstractSink implements Configurable {
                             result.getErrMsg(), resendQueue.size(),
                             myEventStat.getEvent().hashCode());
                 }
-                resendEvent(myEventStat, true);
+                resendEvent(myEventStat, true, DataProxyErrCode.MQ_RETURN_ERROR,
+                        result.getErrCode() + "#" + result.getErrMsg());
             }
         }
 
         @Override
         public void onException(final Throwable e) {
-            if (statIntervalSec > 0) {
-                monitorIndexExt.incrementAndGet(KEY_SINK_EXP);
-            }
-            this.editStatistic(myEventStat.getEvent(), false);
-            resendEvent(myEventStat, true);
+            addStatistics(myEventStat.getEvent(), false, true, 0);
+            resendEvent(myEventStat, true, DataProxyErrCode.UNKNOWN_ERROR, e.getMessage());
         }
 
         /**
-         * addMetric
+         * Add statistics information
+         *
+         * @param event   the statistic event
+         * @param isSuccess  is processed successfully
+         * @param isException is exception when failure processed
+         * @param sendTime   the send time when success processed
          */
-        private void addMetric(Event event, boolean result, long sendTime) {
-            Map<String, String> dimensions = new HashMap<>();
-            dimensions.put(DataProxyMetricItem.KEY_CLUSTER_ID, TubeSink.this.getName());
-            dimensions.put(DataProxyMetricItem.KEY_SINK_ID, TubeSink.this.getName());
-            dimensions.put(DataProxyMetricItem.KEY_SINK_DATA_ID, event.getHeaders().getOrDefault(TOPIC, ""));
-            DataProxyMetricItem.fillInlongId(event, dimensions);
-            DataProxyMetricItem.fillAuditFormatTime(event, dimensions);
-            DataProxyMetricItem metricItem = TubeSink.this.metricItemSet.findMetricItem(dimensions);
-            if (result) {
-                metricItem.sendSuccessCount.incrementAndGet();
-                metricItem.sendSuccessSize.addAndGet(event.getBody().length);
-                AuditUtils.add(AuditUtils.AUDIT_ID_DATAPROXY_SEND_SUCCESS, event);
-                if (sendTime > 0) {
-                    long currentTime = System.currentTimeMillis();
-                    long msgTime = NumberUtils.toLong(event.getHeaders().get(Constants.HEADER_KEY_MSG_TIME),
-                            sendTime);
-                    long sinkDuration = currentTime - sendTime;
-                    long nodeDuration = currentTime - NumberUtils.toLong(Constants.HEADER_KEY_SOURCE_TIME, msgTime);
-                    long wholeDuration = currentTime - msgTime;
-                    metricItem.sinkDuration.addAndGet(sinkDuration);
-                    metricItem.nodeDuration.addAndGet(nodeDuration);
-                    metricItem.wholeDuration.addAndGet(wholeDuration);
-                }
-            } else {
-                metricItem.sendFailCount.incrementAndGet();
-                metricItem.sendFailSize.addAndGet(event.getBody().length);
+        private void addStatistics(Event event, boolean isSuccess,
+                                   boolean isException, long sendTime) {
+            if (event == null) {
+                return;
             }
-        }
-
-        private void editStatistic(final Event event, boolean isSuccess) {
-            String topic = "";
-            String streamId = "";
-            String nodeIp;
-            if (event != null) {
-                if (event.getHeaders().containsKey(TOPIC)) {
-                    topic = event.getHeaders().get(TOPIC);
-                }
-                if (event.getHeaders().containsKey(AttributeConstants.STREAM_ID)) {
-                    streamId = event.getHeaders().get(AttributeConstants.STREAM_ID);
-                } else if (event.getHeaders().containsKey(AttributeConstants.INAME)) {
-                    streamId = event.getHeaders().get(AttributeConstants.INAME);
-                }
-                // Compatible agent
-                if (event.getHeaders().containsKey("ip")) {
-                    event.getHeaders().put(ConfigConstants.REMOTE_IP_KEY, event.getHeaders().get("ip"));
-                    event.getHeaders().remove("ip");
-                }
-                // Compatible agent
-                if (event.getHeaders().containsKey("time")) {
-                    event.getHeaders().put(AttributeConstants.DATA_TIME, event.getHeaders().get("time"));
-                    event.getHeaders().remove("time");
-                }
-                if (event.getHeaders().containsKey(ConfigConstants.REMOTE_IP_KEY)) {
-                    nodeIp = event.getHeaders().get(ConfigConstants.REMOTE_IP_KEY);
-                    if (event.getHeaders().containsKey(ConfigConstants.REMOTE_IDC_KEY)) {
-                        if (nodeIp != null) {
-                            nodeIp = nodeIp.split(":")[0];
-                        }
-                        long msgCounterL = 1L;
-                        // msg counter
-                        if (event.getHeaders().containsKey(ConfigConstants.MSG_COUNTER_KEY)) {
-                            msgCounterL = Integer.parseInt(event.getHeaders().get(ConfigConstants.MSG_COUNTER_KEY));
-                        }
-                        StringBuilder newBase = new StringBuilder();
-                        newBase.append(getName()).append(SEP_HASHTAG).append(topic)
-                                .append(SEP_HASHTAG).append(streamId).append(SEP_HASHTAG)
-                                .append(nodeIp).append(SEP_HASHTAG).append(NetworkUtils.getLocalIp())
-                                .append(SEP_HASHTAG).append("non-order").append(SEP_HASHTAG)
-                                .append(event.getHeaders().get(ConfigConstants.PKG_TIME_KEY));
-                        long messageSize = event.getBody().length;
-                        if (event.getHeaders().get(ConfigConstants.TOTAL_LEN) != null) {
-                            messageSize = Long.parseLong(event.getHeaders().get(ConfigConstants.TOTAL_LEN));
-                        }
-                        if (statIntervalSec > 0) {
-                            if (isSuccess) {
-                                monitorIndex.addAndGet(new String(newBase),
-                                        (int) msgCounterL, 1, messageSize, 0);
-                            } else {
-                                monitorIndex.addAndGet(new String(newBase),
-                                        0, 0, 0, (int) msgCounterL);
-                            }
-                        }
-                    }
+            // add jmx metric items;
+            TubeSink.this.metricItemSet.fillSinkSendMetricItemsByEvent(
+                    event, sendTime, isSuccess, event.getBody().length);
+            // add audit items;
+            if (isSuccess) {
+                AuditUtils.add(AuditUtils.AUDIT_ID_DATAPROXY_SEND_SUCCESS, event);
+            }
+            if (statIntervalSec <= 0) {
+                return;
+            }
+            // add monitor items base file storage
+            String topic = event.getHeaders().get(ConfigConstants.TOPIC_KEY);
+            String streamId = event.getHeaders().get(AttributeConstants.STREAM_ID);
+            String nodeIp = event.getHeaders().get(ConfigConstants.REMOTE_IP_KEY);
+            int intMsgCnt = Integer.parseInt(
+                    event.getHeaders().get(ConfigConstants.MSG_COUNTER_KEY));
+            long dataTimeL = Long.parseLong(
+                    event.getHeaders().get(AttributeConstants.DATA_TIME));
+            Pair<Boolean, String> evenProcType =
+                    MessageUtils.getEventProcType("", "");
+            // build statistic key
+            StringBuilder newBase = new StringBuilder(512)
+                    .append(getName()).append(SEP_HASHTAG).append(topic)
+                    .append(SEP_HASHTAG).append(streamId).append(SEP_HASHTAG)
+                    .append(nodeIp).append(SEP_HASHTAG).append(NetworkUtils.getLocalIp())
+                    .append(SEP_HASHTAG).append(evenProcType.getRight()).append(SEP_HASHTAG)
+                    .append(DateTimeUtils.ms2yyyyMMddHHmm(dataTimeL));
+            // count data
+            if (isSuccess) {
+                monitorIndex.addAndGet(newBase.toString(),
+                        intMsgCnt, 1, event.getBody().length, 0);
+                monitorIndexExt.incrementAndGet(KEY_SINK_SUCCESS);
+            } else {
+                monitorIndex.addAndGet(newBase.toString(),
+                        0, 0, 0, intMsgCnt);
+                monitorIndexExt.incrementAndGet(KEY_SINK_FAILURE);
+                if (isException) {
+                    monitorIndexExt.incrementAndGet(KEY_SINK_EXP);
                 }
             }
         }
@@ -579,7 +529,7 @@ public class TubeSink extends AbstractSink implements Configurable {
 
         @Override
         public void run() {
-            if (!canTake && takenMsgCnt.get() <= 0) {
+            if (!started.get()) {
                 return;
             }
             logger.info(getName() + "[TubeSink Stats] cachedMsgCnt=" + cachedMsgCnt.get()
@@ -596,7 +546,8 @@ public class TubeSink extends AbstractSink implements Configurable {
     /**
      * resend event
      */
-    private void resendEvent(EventStat es, boolean sendFinished) {
+    private void resendEvent(EventStat es, boolean sendFinished,
+                             DataProxyErrCode errCode, String errMsg) {
         try {
             if (sendFinished) {
                 inflightMsgCnt.decrementAndGet();
@@ -607,16 +558,20 @@ public class TubeSink extends AbstractSink implements Configurable {
             }
             MSG_DEDUP_HANDLER.invalidMsgSeqId(es.getEvent()
                     .getHeaders().get(ConfigConstants.SEQUENCE_ID));
-            if (resendQueue.offer(es)) {
-                resendMsgCnt.incrementAndGet();
+            if (MessageUtils.isSinkRspType(es.getEvent())) {
+                MessageUtils.sinkReturnRspPackage((SinkRspEvent) es.getEvent(), errCode, errMsg);
             } else {
-                FailoverChannelProcessorHolder.getChannelProcessor().processEvent(es.getEvent());
-                takenMsgCnt.decrementAndGet();
-                if (LOG_SINK_TASK_PRINTER.shouldPrint()) {
-                    logger.error(Thread.currentThread().getName()
-                            + " Channel --> Tube --> ResendQueue(full) -->"
-                            + "FailOverChannelProcessor(current code point),"
-                            + " Resend queue is full,Check if Tube server or network is ok.");
+                if (resendQueue.offer(es)) {
+                    resendMsgCnt.incrementAndGet();
+                } else {
+                    FailoverChannelProcessorHolder.getChannelProcessor().processEvent(es.getEvent());
+                    takenMsgCnt.decrementAndGet();
+                    if (LOG_SINK_TASK_PRINTER.shouldPrint()) {
+                        logger.error(Thread.currentThread().getName()
+                                + " Channel --> Tube --> ResendQueue(full) -->"
+                                + "FailOverChannelProcessor(current code point),"
+                                + " Resend queue is full,Check if Tube server or network is ok.");
+                    }
                 }
             }
         } catch (Throwable throwable) {
@@ -632,14 +587,6 @@ public class TubeSink extends AbstractSink implements Configurable {
         }
     }
 
-    private Map<String, String> getNewDimension(String otherKey, String value) {
-        Map<String, String> dimensions = new HashMap<>();
-        dimensions.put(DataProxyMetricItem.KEY_CLUSTER_ID, "DataProxy");
-        dimensions.put(DataProxyMetricItem.KEY_SINK_ID, this.getName());
-        dimensions.put(otherKey, value);
-        return dimensions;
-    }
-
     /**
      * Differentiate unpublished topic sets and publish them
      * attention: only append added topics
@@ -666,10 +613,12 @@ public class TubeSink extends AbstractSink implements Configurable {
         }
         // publish them
         if (!addedTopics.isEmpty()) {
-            try {
-                producerHolder.createProducersByTopicSet(addedTopics);
-            } catch (Exception e) {
-                logger.info(getName() + "'s publish new topic set fail.", e);
+            if (producerHolder != null) {
+                try {
+                    producerHolder.createProducersByTopicSet(addedTopics);
+                } catch (Throwable e) {
+                    logger.info(getName() + "'s publish new topic set fail.", e);
+                }
             }
             logger.info(getName() + "'s topics set has changed, trigger diff publish for {}",
                     addedTopics);
@@ -714,7 +663,16 @@ public class TubeSink extends AbstractSink implements Configurable {
         producerHolder = newProducerHolder;
         usedMasterAddr = newMasterAddr;
         // close old producer holder
-        tmpProducerHolder.stop();
+        if (tmpProducerHolder == null) {
+            diffSetPublish(new HashSet<>(),
+                    new HashSet<>(configManager.getTopicProperties().values()));
+        } else {
+            tmpProducerHolder.stop();
+        }
+        if (!ConfigManager.getInstance().isMqClusterReady()) {
+            ConfigManager.getInstance().updMqClusterStatus(true);
+            logger.info("[{}] MQ Cluster service status ready!", getName());
+        }
         logger.info(getName() + " switch cluster from "
                 + tmpMasterAddr + " to " + usedMasterAddr);
     }
@@ -737,14 +695,4 @@ public class TubeSink extends AbstractSink implements Configurable {
         }
         return tmpMasterAddr;
     }
-
-    /**
-     * get metricItemSet
-     *
-     * @return the metricItemSet
-     */
-    private DataProxyMetricItemSet getMetricItemSet() {
-        return metricItemSet;
-    }
-
 }
