@@ -18,20 +18,25 @@
 package org.apache.inlong.dataproxy.sink.pulsar;
 
 import com.google.common.base.Preconditions;
-import io.netty.buffer.ByteBuf;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicLong;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.flume.Event;
 import org.apache.flume.FlumeException;
-import org.apache.inlong.dataproxy.base.OrderEvent;
+import org.apache.inlong.common.enums.DataProxyErrCode;
+import org.apache.inlong.common.msg.AttributeConstants;
 import org.apache.inlong.dataproxy.config.ConfigManager;
 import org.apache.inlong.dataproxy.config.pojo.MQClusterConfig;
-import org.apache.inlong.dataproxy.consts.AttributeConstants;
 import org.apache.inlong.dataproxy.consts.ConfigConstants;
-import org.apache.inlong.dataproxy.metrics.audit.AuditUtils;
 import org.apache.inlong.dataproxy.sink.EventStat;
-import org.apache.inlong.dataproxy.source.MsgType;
+import org.apache.inlong.dataproxy.sink.PulsarSink;
 import org.apache.inlong.dataproxy.utils.MessageUtils;
-import org.apache.inlong.dataproxy.utils.NetworkUtils;
 import org.apache.pulsar.client.api.AuthenticationFactory;
 import org.apache.pulsar.client.api.ClientBuilder;
 import org.apache.pulsar.client.api.CompressionType;
@@ -43,15 +48,6 @@ import org.apache.pulsar.client.api.PulsarClientException.NotFoundException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.util.ArrayList;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicLong;
-
 public class PulsarClientService {
 
     private static final Logger logger = LoggerFactory.getLogger(PulsarClientService.class);
@@ -82,8 +78,6 @@ public class PulsarClientService {
     private int maxBatchingMessages = 1000;
     private long maxBatchingPublishDelayMillis = 1;
     private long retryIntervalWhenSendMsgError = 30 * 1000L;
-    private String localIp = "127.0.0.1";
-
     private int sinkThreadPoolSize;
 
     /**
@@ -120,10 +114,9 @@ public class PulsarClientService {
         maxBatchingPublishDelayMillis = pulsarConfig.getMaxBatchingPublishDelayMillis();
         producerInfoMap = new ConcurrentHashMap<>();
         topicSendIndexMap = new ConcurrentHashMap<>();
-        localIp = NetworkUtils.getLocalIp();
     }
 
-    public void initCreateConnection(CreatePulsarClientCallBack callBack) {
+    public void initCreateConnection(CreatePulsarClientCallBack callBack, String sinkName) {
         pulsarUrl2token = ConfigManager.getInstance().getMqClusterUrl2Token();
         if (pulsarUrl2token == null || pulsarUrl2token.isEmpty()) {
             logger.warn("failed to get Pulsar Cluster, make sure register pulsar to manager successfully.");
@@ -131,6 +124,10 @@ public class PulsarClientService {
         }
         try {
             createConnection(callBack);
+            if (!ConfigManager.getInstance().isMqClusterReady()) {
+                ConfigManager.getInstance().updMqClusterStatus(true);
+                logger.info("[{}] MQ Cluster service status ready!", sinkName);
+            }
         } catch (FlumeException e) {
             logger.error("unable to create pulsar client: ", e);
             close();
@@ -140,16 +137,22 @@ public class PulsarClientService {
     /**
      * send message
      */
-    public boolean sendMessage(int poolIndex, String topic, Event event,
-            SendMessageCallBack sendMessageCallBack, EventStat es) {
-        TopicProducerInfo producerInfo = null;
+    public boolean sendMessage(int poolIndex, String topic,
+                               EventStat es, PulsarSink pulsarSink) {
         boolean result;
-        final String inlongStreamId = getInlongStreamId(event);
-        final String inlongGroupId = getInlongGroupId(event);
+        TopicProducerInfo producerInfo = null;
+        Event event = es.getEvent();
+        final String pkgVersion =
+                event.getHeaders().get(ConfigConstants.MSG_ENCODE_VER);
+        final String inlongGroupId =
+                event.getHeaders().get(AttributeConstants.GROUP_ID);
+        final String inlongStreamId =
+                event.getHeaders().get(AttributeConstants.STREAM_ID);
+        String errMsg = "";
         try {
             producerInfo = getProducerInfo(poolIndex, topic, inlongGroupId, inlongStreamId);
         } catch (Exception e) {
-            logger.error("get producer failed for topic=" + topic, e);
+            errMsg = "Get producer failed for topic=" + topic + ", reason is " + e.getMessage();
         }
         /*
          * If the producer is a null value,\ it means that the topic is not yet
@@ -162,98 +165,66 @@ public class PulsarClientService {
              * After 30s, reopen the topic check, if it is still a null value,
              *  put it back into the illegal map
              */
-            checkAndResponse(event, inlongGroupId, inlongStreamId);
-            sendMessageCallBack.handleMessageSendException(topic, es, new NotFoundException("producer info is null"));
-            return true;
+            pulsarSink.handleRequestProcError(topic, es,
+                    false, DataProxyErrCode.NO_AVAILABLE_PRODUCER, errMsg);
+            return false;
         }
-
-        Map<String, String> proMap = new HashMap<>();
-        proMap.put("data_proxy_ip", localIp);
-        proMap.put(inlongStreamId, event.getHeaders().get(ConfigConstants.PKG_TIME_KEY));
-
         TopicProducerInfo forCallBackP = producerInfo;
         Producer producer = producerInfo.getProducer(poolIndex);
         if (producer == null) {
-            logger.warn("get producer is null! topic = {}", topic);
-            checkAndResponse(event, inlongGroupId, inlongStreamId);
-            sendMessageCallBack.handleMessageSendException(topic, es, new NotFoundException("producer is null"));
-            return true;
+            errMsg = "get producer is null! topic = " + topic;
+            pulsarSink.handleRequestProcError(topic, es,
+                    false, DataProxyErrCode.PRODUCER_IS_NULL, errMsg);
+            return false;
         }
+        // build and send message
+        Map<String, String> proMap =
+                MessageUtils.getXfsAttrs(event.getHeaders(), pkgVersion);
+        long startTime = System.currentTimeMillis();
+        pulsarSink.getCurrentInFlightCount().incrementAndGet();
         if (es.isOrderMessage()) {
-            String partitionKey = event.getHeaders().get(AttributeConstants.MESSAGE_PARTITION_KEY);
             try {
+                String partitionKey =
+                        event.getHeaders().get(AttributeConstants.MESSAGE_PARTITION_KEY);
                 MessageId msgId = producer.newMessage()
                         .properties(proMap)
                         .key(partitionKey)
                         .value(event.getBody())
                         .send();
-                sendMessageCallBack.handleMessageSendSuccess(topic, msgId, es);
-                AuditUtils.add(AuditUtils.AUDIT_ID_DATAPROXY_SEND_SUCCESS, event);
+                pulsarSink.handleMessageSendSuccess(topic, msgId, es, startTime);
                 forCallBackP.setCanUseSend(true);
                 result = true;
-            } catch (PulsarClientException ex) {
+            } catch (Throwable ex) {
                 forCallBackP.setCanUseSend(false);
-                sendMessageCallBack.handleMessageSendException(topic, es, ex);
+                pulsarSink.handleMessageSendException(topic, es, ex,
+                        DataProxyErrCode.MQ_RETURN_ERROR, ex.getMessage());
                 result = ex instanceof NotFoundException;
             }
-            /*
-             * avoid client timeout
-             */
-            logger.debug("es.getRetryCnt() = {}", es.getRetryCnt());
-            if (es.getRetryCnt() == 0 || es.getRetryCnt() == 1) {
-                sendResponse((OrderEvent) event, inlongGroupId, inlongStreamId);
-            }
         } else {
-            producer.newMessage().properties(proMap)
-                    .value(event.getBody())
-                    .sendAsync()
-                    .thenAccept((msgId) -> {
-                        AuditUtils.add(AuditUtils.AUDIT_ID_DATAPROXY_SEND_SUCCESS, event);
-                        forCallBackP.setCanUseSend(true);
-                        sendMessageCallBack.handleMessageSendSuccess(topic, msgId, es);
-                    })
-                    .exceptionally((e) -> {
-                        forCallBackP.setCanUseSend(false);
-                        sendMessageCallBack.handleMessageSendException(topic, es, e);
-                        return null;
-                    });
+            try {
+                producer.newMessage().properties(proMap)
+                        .value(event.getBody())
+                        .sendAsync()
+                        .thenAccept((msgId) -> {
+                            forCallBackP.setCanUseSend(true);
+                            pulsarSink.handleMessageSendSuccess(topic, msgId, es, startTime);
+                        })
+                        .exceptionally((e) -> {
+                            forCallBackP.setCanUseSend(false);
+                            pulsarSink.handleMessageSendException(topic, es, e,
+                                    DataProxyErrCode.MQ_RETURN_ERROR, e.toString());
+                            return null;
+                        });
+            } catch (Throwable ex) {
+                pulsarSink.getCurrentInFlightCount().decrementAndGet();
+                pulsarSink.handleRequestProcError(topic, es, true,
+                        DataProxyErrCode.SEND_REQUEST_TO_MQ_FAILURE, ex.getMessage());
+            }
             result = true;
         }
         return result;
     }
 
-    private void checkAndResponse(Event event, String inlongGroupId, String inlongStreamId) {
-        if (MessageUtils.isSyncSendForOrder(event) && (event instanceof OrderEvent)) {
-            sendResponse((OrderEvent) event, inlongGroupId, inlongStreamId);
-        }
-    }
-
-    /**
-     * send Response
-     *
-     * @param orderEvent orderEvent
-     */
-    private void sendResponse(OrderEvent orderEvent, String inlongGroupId, String inlongStreamId) {
-        String sequenceId = orderEvent.getHeaders().get(AttributeConstants.UNIQ_ID);
-        if ("false".equals(orderEvent.getHeaders().get(AttributeConstants.MESSAGE_IS_ACK))) {
-            if (logger.isDebugEnabled()) {
-                logger.debug("not need to rsp message: seqId = {}, inlongGroupId = {}, inlongStreamId = {}",
-                        sequenceId, inlongGroupId, inlongStreamId);
-            }
-            return;
-        }
-        if (orderEvent.getCtx() != null && orderEvent.getCtx().channel().isActive()) {
-            orderEvent.getCtx().channel().eventLoop().execute(() -> {
-                if (logger.isDebugEnabled()) {
-                    logger.debug("order message rsp: seqId = {}, inlongGroupId = {}, inlongStreamId = {}", sequenceId,
-                            inlongGroupId, inlongStreamId);
-                }
-                ByteBuf binBuffer = MessageUtils.getResponsePackage("", MsgType.MSG_BIN_MULTI_BODY, sequenceId);
-                orderEvent.getCtx().writeAndFlush(binBuffer);
-            });
-        }
-    }
-
     /**
      * If this function is called successively without calling {@see #destroyConnection()}, only the
      * first call has any effect.
@@ -328,6 +299,20 @@ public class PulsarClientService {
         return initTopicProducer(topic, null, null);
     }
 
+    public boolean destroyProducerByTopic(String topic) {
+        List<TopicProducerInfo> producerInfoList = producerInfoMap.remove(topic);
+        if (producerInfoList == null || producerInfoList.isEmpty()) {
+            return true;
+        }
+        for (TopicProducerInfo producerInfo : producerInfoList) {
+            if (producerInfo != null) {
+                producerInfo.close();
+                logger.info("destroy producer for topic={}", topic);
+            }
+        }
+        return true;
+    }
+
     private TopicProducerInfo getProducerInfo(int poolIndex, String topic, String inlongGroupId,
             String inlongStreamId) {
         List<TopicProducerInfo> producerList = initTopicProducer(topic, inlongGroupId, inlongStreamId);
@@ -369,10 +354,15 @@ public class PulsarClientService {
 
     private void removeProducers(PulsarClient pulsarClient) {
         for (List<TopicProducerInfo> producers : producerInfoMap.values()) {
-            for (TopicProducerInfo topicProducer : producers) {
-                if (topicProducer.getPulsarClient().equals(pulsarClient)) {
-                    topicProducer.close();
-                    producers.remove(topicProducer);
+            if (producers == null || producers.isEmpty()) {
+                continue;
+            }
+            Iterator<TopicProducerInfo> it = producers.iterator();
+            while (it.hasNext()) {
+                TopicProducerInfo entry = it.next();
+                if (entry.getPulsarClient().equals(pulsarClient)) {
+                    entry.close();
+                    it.remove();
                 }
             }
         }
@@ -418,10 +408,17 @@ public class PulsarClientService {
                             topic);
                     info.initProducer();
                     if (info.isCanUseToSendMessage()) {
-                        producerInfoMap.computeIfAbsent(topic, k -> new ArrayList<>()).add(info);
+                        List<TopicProducerInfo> producerInfos = producerInfoMap.get(topic);
+                        if (producerInfos == null) {
+                            List<TopicProducerInfo> tmpProdInfos = new ArrayList<>();
+                            producerInfos = producerInfoMap.putIfAbsent(topic, tmpProdInfos);
+                            if (producerInfos == null) {
+                                producerInfos = tmpProdInfos;
+                            }
+                        }
+                        producerInfos.add(info);
                     }
                 }
-
             } catch (PulsarClientException e) {
                 callBack.handleCreateClientException(url);
                 logger.error("create connection error in pulsar sink, "
