@@ -20,6 +20,7 @@ package org.apache.inlong.manager.client.cli.pojo;
 import com.fasterxml.jackson.annotation.JsonFormat;
 import lombok.Data;
 import org.apache.inlong.manager.client.cli.util.ParseStatus;
+import org.apache.inlong.manager.common.enums.SimpleGroupStatus;
 
 import java.util.Date;
 
@@ -33,7 +34,7 @@ public class GroupInfo {
     private String inlongGroupId;
     private String name;
 
-    @ParseStatus
+    @ParseStatus(clazz = SimpleGroupStatus.class)
     private String status;
     @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
     private Date modifyTime;
