@@ -23,11 +23,13 @@ import com.google.common.collect.Lists;
 import lombok.extern.slf4j.Slf4j;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.tuple.Pair;
+import org.apache.inlong.common.constant.ProtocolType;
 import org.apache.inlong.manager.client.api.ClientConfiguration;
 import org.apache.inlong.manager.client.api.impl.InlongClientImpl;
 import org.apache.inlong.manager.client.api.inner.client.ClientFactory;
 import org.apache.inlong.manager.client.api.inner.client.DataNodeClient;
 import org.apache.inlong.manager.client.api.inner.client.InlongClusterClient;
+import org.apache.inlong.manager.client.api.inner.client.InlongConsumeClient;
 import org.apache.inlong.manager.client.api.inner.client.InlongGroupClient;
 import org.apache.inlong.manager.client.api.inner.client.InlongStreamClient;
 import org.apache.inlong.manager.client.api.inner.client.StreamSinkClient;
@@ -38,7 +40,6 @@ import org.apache.inlong.manager.client.api.util.ClientUtils;
 import org.apache.inlong.manager.common.auth.DefaultAuthentication;
 import org.apache.inlong.manager.common.auth.TokenAuthentication;
 import org.apache.inlong.manager.common.consts.DataNodeType;
-import org.apache.inlong.manager.common.consts.MQType;
 import org.apache.inlong.manager.common.consts.SinkType;
 import org.apache.inlong.manager.common.consts.SourceType;
 import org.apache.inlong.manager.common.enums.ClusterType;
@@ -60,10 +61,11 @@ import org.apache.inlong.manager.pojo.group.InlongGroupCountResponse;
 import org.apache.inlong.manager.pojo.group.InlongGroupExtInfo;
 import org.apache.inlong.manager.pojo.group.InlongGroupInfo;
 import org.apache.inlong.manager.pojo.group.InlongGroupResetRequest;
-import org.apache.inlong.manager.pojo.group.InlongGroupTopicInfo;
 import org.apache.inlong.manager.pojo.group.pulsar.InlongPulsarInfo;
 import org.apache.inlong.manager.pojo.group.pulsar.InlongPulsarRequest;
-import org.apache.inlong.manager.pojo.node.DataNodeResponse;
+import org.apache.inlong.manager.pojo.group.pulsar.InlongPulsarTopicInfo;
+import org.apache.inlong.manager.pojo.node.DataNodeInfo;
+import org.apache.inlong.manager.pojo.node.hive.HiveDataNodeInfo;
 import org.apache.inlong.manager.pojo.node.hive.HiveDataNodeRequest;
 import org.apache.inlong.manager.pojo.sink.StreamSink;
 import org.apache.inlong.manager.pojo.sink.ck.ClickHouseSink;
@@ -80,9 +82,7 @@ import org.apache.inlong.manager.pojo.source.autopush.AutoPushSource;
 import org.apache.inlong.manager.pojo.source.file.FileSource;
 import org.apache.inlong.manager.pojo.source.kafka.KafkaSource;
 import org.apache.inlong.manager.pojo.source.mysql.MySQLBinlogSource;
-import org.apache.inlong.manager.pojo.stream.InlongStreamBriefInfo;
 import org.apache.inlong.manager.pojo.stream.InlongStreamInfo;
-import org.apache.inlong.manager.pojo.stream.InlongStreamResponse;
 import org.apache.inlong.manager.pojo.stream.StreamField;
 import org.apache.inlong.manager.pojo.user.UserInfo;
 import org.apache.inlong.manager.pojo.user.UserRequest;
@@ -92,6 +92,7 @@ import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.List;
@@ -111,10 +112,8 @@ import static com.github.tomakehurst.wiremock.core.WireMockConfiguration.options
 class ClientFactoryTest {
 
     private static final int SERVICE_PORT = 8085;
-    private static WireMockServer wireMockServer;
-
     static ClientFactory clientFactory;
-
+    private static WireMockServer wireMockServer;
     private static InlongGroupClient groupClient;
     private static InlongStreamClient streamClient;
     private static StreamSourceClient sourceClient;
@@ -123,6 +122,7 @@ class ClientFactoryTest {
     private static DataNodeClient dataNodeClient;
     private static UserClient userClient;
     private static WorkflowClient workflowClient;
+    private static InlongConsumeClient consumeClient;
 
     @BeforeAll
     static void setup() {
@@ -145,6 +145,7 @@ class ClientFactoryTest {
         dataNodeClient = clientFactory.getDataNodeClient();
         userClient = clientFactory.getUserClient();
         workflowClient = clientFactory.getWorkflowClient();
+        consumeClient = clientFactory.getConsumeClient();
     }
 
     @AfterAll
@@ -168,31 +169,32 @@ class ClientFactoryTest {
     void testGetGroupInfo() {
         FlinkSortConf flinkSortConf = new FlinkSortConf();
         flinkSortConf.setAuthentication(new TokenAuthentication());
-        InlongPulsarInfo inlongGroupResponse = InlongPulsarInfo.builder()
-                .id(1)
-                .inlongGroupId("1")
-                .mqType("PULSAR")
-                .enableCreateResource(1)
-                .extList(
-                        Lists.newArrayList(InlongGroupExtInfo.builder()
-                                .id(1)
-                                .inlongGroupId("1")
-                                .keyName("keyName")
-                                .keyValue("keyValue")
-                                .build()
-                        )
-                ).sortConf(flinkSortConf).build();
+        InlongPulsarInfo pulsarInfo = new InlongPulsarInfo();
+        pulsarInfo.setId(1);
+        pulsarInfo.setInlongGroupId("1");
+        pulsarInfo.setMqType("PULSAR");
+        pulsarInfo.setEnableCreateResource(1);
+        pulsarInfo.setExtList(
+                Lists.newArrayList(InlongGroupExtInfo.builder()
+                        .id(1)
+                        .inlongGroupId("1")
+                        .keyName("keyName")
+                        .keyValue("keyValue")
+                        .build()
+                )
+        );
+        pulsarInfo.setSortConf(flinkSortConf);
 
         stubFor(
                 get(urlMatching("/inlong/manager/api/group/get/1.*"))
                         .willReturn(
-                                okJson(JsonUtils.toJsonString(Response.success(inlongGroupResponse)))
+                                okJson(JsonUtils.toJsonString(Response.success(pulsarInfo)))
                         )
         );
 
         InlongGroupInfo groupInfo = groupClient.getGroupInfo("1");
         Assertions.assertTrue(groupInfo instanceof InlongPulsarInfo);
-        Assertions.assertEquals(JsonUtils.toJsonString(inlongGroupResponse), JsonUtils.toJsonString(groupInfo));
+        Assertions.assertEquals(JsonUtils.toJsonString(pulsarInfo), JsonUtils.toJsonString(groupInfo));
     }
 
     @Test
@@ -477,19 +479,14 @@ class ClientFactoryTest {
 
     @Test
     void getTopic() {
-        InlongGroupTopicInfo expected = new InlongGroupTopicInfo();
+        InlongPulsarTopicInfo expected = new InlongPulsarTopicInfo();
         expected.setInlongGroupId("1");
-        expected.setMqResource("testTopic");
-        expected.setMqType(MQType.TUBEMQ);
-        expected.setPulsarAdminUrl("http://127.0.0.1:8080");
-        expected.setPulsarServiceUrl("http://127.0.0.1:8081");
-        expected.setTubeMasterUrl("http://127.0.0.1:8082");
-        List<InlongStreamBriefInfo> list = new ArrayList<>();
-        expected.setStreamTopics(list);
-        InlongStreamBriefInfo briefInfo = new InlongStreamBriefInfo();
-        briefInfo.setId(1);
-        briefInfo.setInlongGroupId("testgroup");
-        briefInfo.setModifyTime(new Date());
+        expected.setNamespace("testTopic");
+        PulsarClusterInfo clusterInfo = new PulsarClusterInfo();
+        clusterInfo.setUrl("pulsar://127.0.0.1:6650");
+        clusterInfo.setAdminUrl("http://127.0.0.1:8080");
+        expected.setClusterInfos(Collections.singletonList(clusterInfo));
+        expected.setTopics(new ArrayList<>());
         stubFor(
                 get(urlMatching("/inlong/manager/api/group/getTopic/1.*"))
                         .willReturn(
@@ -497,13 +494,12 @@ class ClientFactoryTest {
                                         Response.success(expected))
                                 ))
         );
-        InlongGroupTopicInfo actual = groupClient.getTopic("1");
+
+        InlongPulsarTopicInfo actual = (InlongPulsarTopicInfo) groupClient.getTopic("1");
         Assertions.assertEquals(expected.getInlongGroupId(), actual.getInlongGroupId());
         Assertions.assertEquals(expected.getMqType(), actual.getMqType());
-        Assertions.assertEquals(expected.getTubeMasterUrl(), actual.getTubeMasterUrl());
-        Assertions.assertEquals(expected.getPulsarAdminUrl(), actual.getPulsarAdminUrl());
-        Assertions.assertEquals(expected.getPulsarServiceUrl(), actual.getPulsarServiceUrl());
-        Assertions.assertEquals(expected.getStreamTopics(), actual.getStreamTopics());
+        Assertions.assertEquals(expected.getTopics().size(), actual.getTopics().size());
+        Assertions.assertEquals(expected.getClusterInfos().size(), actual.getClusterInfos().size());
     }
 
     @Test
@@ -538,36 +534,36 @@ class ClientFactoryTest {
 
     @Test
     void testGetStream() {
-        InlongStreamResponse streamResponse = InlongStreamResponse.builder()
-                .id(1)
-                .inlongGroupId("123")
-                .inlongStreamId("11")
-                .name("name")
-                .fieldList(
-                        Lists.newArrayList(
-                                StreamField.builder()
-                                        .id(1)
-                                        .inlongGroupId("123")
-                                        .fieldType("string")
-                                        .build(),
-                                StreamField.builder()
-                                        .id(2)
-                                        .inlongGroupId("123")
-                                        .inlongGroupId("11")
-                                        .isMetaField(1)
-                                        .build()
-                        )
-                ).build();
+        InlongStreamInfo streamInfo = new InlongStreamInfo();
+        streamInfo.setId(1);
+        streamInfo.setInlongGroupId("123");
+        streamInfo.setInlongStreamId("11");
+        streamInfo.setName("name");
+        streamInfo.setFieldList(
+                Lists.newArrayList(
+                        StreamField.builder()
+                                .id(1)
+                                .inlongGroupId("123")
+                                .fieldType("string")
+                                .build(),
+                        StreamField.builder()
+                                .id(2)
+                                .inlongGroupId("123")
+                                .inlongGroupId("11")
+                                .isMetaField(1)
+                                .build()
+                )
+        );
 
         stubFor(
                 get(urlMatching("/inlong/manager/api/stream/get.*"))
                         .willReturn(
-                                okJson(JsonUtils.toJsonString(Response.success(streamResponse)))
+                                okJson(JsonUtils.toJsonString(Response.success(streamInfo)))
                         )
         );
 
-        InlongStreamInfo inlongStreamInfo = streamClient.getStreamInfo("123", "11");
-        Assertions.assertNotNull(inlongStreamInfo);
+        InlongStreamInfo streamInfoResult = streamClient.getStreamInfo("123", "11");
+        Assertions.assertNotNull(streamInfoResult);
     }
 
     @Test
@@ -586,24 +582,24 @@ class ClientFactoryTest {
 
     @Test
     void testListStream4AllSink() {
-        InlongStreamInfo streamInfo = InlongStreamInfo.builder()
-                .id(1)
-                .inlongGroupId("11")
-                .inlongStreamId("11")
-                .fieldList(
-                        Lists.newArrayList(
-                                StreamField.builder()
-                                        .id(1)
-                                        .inlongGroupId("123")
-                                        .inlongGroupId("11")
-                                        .build(),
-                                StreamField.builder()
-                                        .id(2)
-                                        .isMetaField(1)
-                                        .fieldFormat("yyyy-MM-dd HH:mm:ss")
-                                        .build()
-                        )
-                ).build();
+        InlongStreamInfo streamInfo = new InlongStreamInfo();
+        streamInfo.setId(1);
+        streamInfo.setInlongGroupId("11");
+        streamInfo.setInlongStreamId("11");
+        streamInfo.setFieldList(
+                Lists.newArrayList(
+                        StreamField.builder()
+                                .id(1)
+                                .inlongGroupId("123")
+                                .inlongGroupId("11")
+                                .build(),
+                        StreamField.builder()
+                                .id(2)
+                                .isMetaField(1)
+                                .fieldFormat("yyyy-MM-dd HH:mm:ss")
+                                .build()
+                )
+        );
 
         ArrayList<StreamSource> sourceList = Lists.newArrayList(
                 AutoPushSource.builder()
@@ -915,7 +911,7 @@ class ClientFactoryTest {
     }
 
     @Test
-    void testGetNode() {
+    void testGetClusterNode() {
         ClusterNodeResponse response = ClusterNodeResponse.builder()
                 .id(1)
                 .type(ClusterType.DATAPROXY)
@@ -934,6 +930,30 @@ class ClientFactoryTest {
         Assertions.assertEquals(1, clientNode.getId());
     }
 
+    @Test
+    void testListClusterNode() {
+        ClusterNodeResponse response = ClusterNodeResponse.builder()
+                .id(5)
+                .type(ClusterType.DATAPROXY)
+                .parentId(1)
+                .ip("127.0.0.1")
+                .port(46801)
+                .protocolType(ProtocolType.HTTP)
+                .build();
+        List<ClusterNodeResponse> responses = new ArrayList<>();
+        responses.add(response);
+        stubFor(
+                get(urlMatching("/inlong/manager/api/cluster/node/listByGroupId.*"))
+                        .willReturn(
+                                okJson(JsonUtils.toJsonString(
+                                        Response.success(responses))
+                                ))
+        );
+        List<ClusterNodeResponse> clusterNode = clusterClient.listNode(
+                "1", ClusterType.DATAPROXY, ProtocolType.HTTP);
+        Assertions.assertEquals(1, clusterNode.size());
+    }
+
     @Test
     void testGetStreamSourceById() {
         StreamSource streamSource = MySQLBinlogSource.builder()
@@ -979,7 +999,7 @@ class ClientFactoryTest {
 
     @Test
     void testGetDataNode() {
-        DataNodeResponse response = DataNodeResponse.builder()
+        HiveDataNodeInfo dataNodeInfo = HiveDataNodeInfo.builder()
                 .id(1)
                 .name("test_node")
                 .type(DataNodeType.HIVE)
@@ -988,17 +1008,17 @@ class ClientFactoryTest {
                 get(urlMatching("/inlong/manager/api/node/get/1.*"))
                         .willReturn(
                                 okJson(JsonUtils.toJsonString(
-                                        Response.success(response))
+                                        Response.success(dataNodeInfo))
                                 ))
         );
-        DataNodeResponse nodeInfo = dataNodeClient.get(1);
+        DataNodeInfo nodeInfo = dataNodeClient.get(1);
         Assertions.assertEquals(1, nodeInfo.getId());
     }
 
     @Test
     void testListDataNode() {
-        List<DataNodeResponse> nodeResponses = Lists.newArrayList(
-                DataNodeResponse.builder()
+        List<DataNodeInfo> nodeResponses = Lists.newArrayList(
+                HiveDataNodeInfo.builder()
                         .id(1)
                         .name("test_node")
                         .type(DataNodeType.HIVE)
@@ -1014,8 +1034,8 @@ class ClientFactoryTest {
 
         HiveDataNodeRequest request = new HiveDataNodeRequest();
         request.setName("test_hive_node");
-        PageResult<DataNodeResponse> nodePageInfo = dataNodeClient.list(request);
-        Assertions.assertEquals(JsonUtils.toJsonString(nodePageInfo.getList()), JsonUtils.toJsonString(nodeResponses));
+        PageResult<DataNodeInfo> pageInfo = dataNodeClient.list(request);
+        Assertions.assertEquals(JsonUtils.toJsonString(pageInfo.getList()), JsonUtils.toJsonString(nodeResponses));
     }
 
     @Test
