@@ -17,8 +17,6 @@
 
 package org.apache.inlong.manager.pojo.sink.es;
 
-import com.fasterxml.jackson.databind.DeserializationFeature;
-import com.fasterxml.jackson.databind.ObjectMapper;
 import io.swagger.annotations.ApiModelProperty;
 import lombok.AllArgsConstructor;
 import lombok.Builder;
@@ -27,6 +25,7 @@ import lombok.NoArgsConstructor;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
+import org.apache.inlong.manager.common.util.JsonUtils;
 
 import javax.validation.constraints.NotNull;
 
@@ -36,8 +35,6 @@ import javax.validation.constraints.NotNull;
 @AllArgsConstructor
 public class ElasticsearchFieldInfo {
 
-    private static final ObjectMapper OBJECT_MAPPER = new ObjectMapper();
-
     @ApiModelProperty("Elasticsearch Field name")
     private String name;
 
@@ -64,8 +61,7 @@ public class ElasticsearchFieldInfo {
             return new ElasticsearchFieldInfo();
         }
         try {
-            OBJECT_MAPPER.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
-            return OBJECT_MAPPER.readValue(extParams, ElasticsearchFieldInfo.class);
+            return JsonUtils.parseObject(extParams, ElasticsearchFieldInfo.class);
         } catch (Exception e) {
             throw new BusinessException(ErrorCodeEnum.SINK_INFO_INCORRECT.getMessage() + ": " + e.getMessage());
         }
