@@ -24,7 +24,6 @@ import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.inlong.common.enums.DataTypeEnum;
 import org.apache.inlong.manager.common.consts.SourceType;
-import org.apache.inlong.manager.common.enums.DataSeparator;
 import org.apache.inlong.manager.pojo.source.StreamSource;
 import org.apache.inlong.manager.pojo.source.kafka.KafkaOffset;
 import org.apache.inlong.manager.pojo.source.kafka.KafkaSource;
@@ -33,13 +32,17 @@ import org.apache.inlong.manager.pojo.source.mysql.MySQLBinlogSource;
 import org.apache.inlong.manager.pojo.source.oracle.OracleSource;
 import org.apache.inlong.manager.pojo.source.postgresql.PostgreSQLSource;
 import org.apache.inlong.manager.pojo.source.pulsar.PulsarSource;
+import org.apache.inlong.manager.pojo.source.redis.RedisSource;
 import org.apache.inlong.manager.pojo.source.sqlserver.SQLServerSource;
 import org.apache.inlong.manager.pojo.source.tubemq.TubeMQSource;
 import org.apache.inlong.manager.pojo.stream.StreamField;
 import org.apache.inlong.sort.protocol.FieldInfo;
+import org.apache.inlong.sort.protocol.LookupOptions;
 import org.apache.inlong.sort.protocol.constant.OracleConstant.ScanStartUpMode;
 import org.apache.inlong.sort.protocol.enums.KafkaScanStartupMode;
 import org.apache.inlong.sort.protocol.enums.PulsarScanStartupMode;
+import org.apache.inlong.sort.protocol.enums.RedisCommand;
+import org.apache.inlong.sort.protocol.enums.RedisMode;
 import org.apache.inlong.sort.protocol.node.ExtractNode;
 import org.apache.inlong.sort.protocol.node.extract.KafkaExtractNode;
 import org.apache.inlong.sort.protocol.node.extract.MongoExtractNode;
@@ -47,6 +50,7 @@ import org.apache.inlong.sort.protocol.node.extract.MySqlExtractNode;
 import org.apache.inlong.sort.protocol.node.extract.OracleExtractNode;
 import org.apache.inlong.sort.protocol.node.extract.PostgresExtractNode;
 import org.apache.inlong.sort.protocol.node.extract.PulsarExtractNode;
+import org.apache.inlong.sort.protocol.node.extract.RedisExtractNode;
 import org.apache.inlong.sort.protocol.node.extract.SqlServerExtractNode;
 import org.apache.inlong.sort.protocol.node.extract.TubeMQExtractNode;
 import org.apache.inlong.sort.protocol.node.format.AvroFormat;
@@ -98,6 +102,8 @@ public class ExtractNodeUtils {
                 return createExtractNode((MongoDBSource) sourceInfo);
             case SourceType.TUBEMQ:
                 return createExtractNode((TubeMQSource) sourceInfo);
+            case SourceType.REDIS:
+                return createExtractNode((RedisSource) sourceInfo);
             default:
                 throw new IllegalArgumentException(
                         String.format("Unsupported sourceType=%s to create extractNode", sourceType));
@@ -166,7 +172,7 @@ public class ExtractNodeUtils {
         String topic = kafkaSource.getTopic();
         String bootstrapServers = kafkaSource.getBootstrapServers();
         Format format;
-        DataTypeEnum dataType = DataTypeEnum.forName(kafkaSource.getSerializationType());
+        DataTypeEnum dataType = DataTypeEnum.forType(kafkaSource.getSerializationType());
         switch (dataType) {
             case CSV:
                 format = new CsvFormat();
@@ -183,6 +189,9 @@ public class ExtractNodeUtils {
             case DEBEZIUM_JSON:
                 format = new DebeziumJsonFormat();
                 break;
+            case RAW:
+                format = new RawFormat();
+                break;
             default:
                 throw new IllegalArgumentException(String.format("Unsupported dataType=%s for kafka source", dataType));
         }
@@ -195,6 +204,9 @@ public class ExtractNodeUtils {
             case SPECIFIC:
                 startupMode = KafkaScanStartupMode.SPECIFIC_OFFSETS;
                 break;
+            case TIMESTAMP_MILLIS:
+                startupMode = KafkaScanStartupMode.TIMESTAMP_MILLIS;
+                break;
             case LATEST:
             default:
                 startupMode = KafkaScanStartupMode.LATEST_OFFSET;
@@ -203,6 +215,7 @@ public class ExtractNodeUtils {
         String groupId = kafkaSource.getGroupId();
         Map<String, String> properties = parseProperties(kafkaSource.getProperties());
         String partitionOffset = kafkaSource.getPartitionOffsets();
+        String scanTimestampMillis = kafkaSource.getTimestampMillis();
         return new KafkaExtractNode(kafkaSource.getSourceName(),
                 kafkaSource.getSourceName(),
                 fieldInfos,
@@ -214,7 +227,8 @@ public class ExtractNodeUtils {
                 startupMode,
                 primaryKey,
                 groupId,
-                partitionOffset
+                partitionOffset,
+                scanTimestampMillis
         );
     }
 
@@ -230,12 +244,15 @@ public class ExtractNodeUtils {
                 pulsarSource.getTenant() + "/" + pulsarSource.getNamespace() + "/" + pulsarSource.getTopic();
 
         Format format;
-        DataTypeEnum dataType = DataTypeEnum.forName(pulsarSource.getSerializationType());
+        DataTypeEnum dataType = DataTypeEnum.forType(pulsarSource.getSerializationType());
         switch (dataType) {
             case CSV:
-                String separator = DataSeparator
-                        .forAscii(Integer.parseInt(pulsarSource.getDataSeparator())).getSeparator();
-                format = new CsvFormat(separator);
+                String separatorStr = pulsarSource.getDataSeparator();
+                if (StringUtils.isNumeric(separatorStr)) {
+                    char dataSeparator = (char) Integer.parseInt(pulsarSource.getDataSeparator());
+                    separatorStr = Character.toString(dataSeparator);
+                }
+                format = new CsvFormat(separatorStr);
                 break;
             case AVRO:
                 format = new AvroFormat();
@@ -398,6 +415,45 @@ public class ExtractNodeUtils {
         );
     }
 
+    /**
+     * Create Redis extract node
+     *
+     * @param source redis source info
+     * @return redis extract source info
+     */
+    public static RedisExtractNode createExtractNode(RedisSource source) {
+        List<FieldInfo> fieldInfos = parseFieldInfos(source.getFieldList(), source.getSourceName());
+        Map<String, String> properties = parseProperties(source.getProperties());
+        RedisCommand command = RedisCommand.forName(source.getRedisCommand());
+        RedisMode mode = RedisMode.forName(source.getRedisMode());
+        LookupOptions lookupOptions = new LookupOptions(source.getLookupCacheMaxRows(), source.getLookupCacheTtl(),
+                source.getLookupMaxRetries(), source.getLookupAsync());
+        return new RedisExtractNode(
+                source.getSourceName(),
+                source.getSourceName(),
+                fieldInfos,
+                null,
+                properties,
+                source.getPrimaryKey(),
+                mode,
+                command,
+                source.getClusterNodes(),
+                source.getMasterName(),
+                source.getSentinelsInfo(),
+                source.getHostname(),
+                source.getPort(),
+                source.getPassword(),
+                source.getAdditionalKey(),
+                source.getDatabase(),
+                source.getTimeout(),
+                source.getSoTimeout(),
+                source.getMaxTotal(),
+                source.getMaxIdle(),
+                source.getMinIdle(),
+                lookupOptions
+        );
+    }
+
     /**
      * Parse FieldInfos
      *
