@@ -19,15 +19,15 @@ package org.apache.inlong.manager.pojo.source.kafka;
 
 import io.swagger.annotations.ApiModel;
 import io.swagger.annotations.ApiModelProperty;
-import java.nio.charset.StandardCharsets;
 import lombok.Data;
 import lombok.EqualsAndHashCode;
 import lombok.ToString;
 import org.apache.inlong.manager.common.consts.SourceType;
-import org.apache.inlong.manager.common.enums.DataSeparator;
 import org.apache.inlong.manager.common.util.JsonTypeDefine;
 import org.apache.inlong.manager.pojo.source.SourceRequest;
 
+import java.nio.charset.StandardCharsets;
+
 /**
  * Kafka source request
  */
@@ -60,6 +60,9 @@ public class KafkaSourceRequest extends SourceRequest {
                     + "indicates offset 42 for partition 0 and offset 300 for partition 1.")
     private String partitionOffsets;
 
+    @ApiModelProperty(value = "timestamp is millis")
+    private String timestampMillis;
+
     @ApiModelProperty(value = "The strategy of auto offset reset",
             notes = "including earliest, latest (the default), none")
     private String autoOffsetReset;
@@ -82,10 +85,10 @@ public class KafkaSourceRequest extends SourceRequest {
     @ApiModelProperty(value = "Data encoding format: UTF-8, GBK")
     private String dataEncoding = StandardCharsets.UTF_8.toString();
 
-    @ApiModelProperty(value = "Data separator, stored as ASCII code")
-    private String dataSeparator = DataSeparator.VERTICAL_BAR.getAsciiCode().toString();
+    @ApiModelProperty(value = "Data separator")
+    private String dataSeparator = String.valueOf((int) '|');
 
-    @ApiModelProperty(value = "Data field escape symbol, stored as ASCII code")
+    @ApiModelProperty(value = "Data field escape symbol")
     private String dataEscapeChar;
 
     public KafkaSourceRequest() {
