@@ -65,10 +65,10 @@ public class PulsarSource extends StreamSource {
     @ApiModelProperty(value = "Data encoding format: UTF-8, GBK")
     private String dataEncoding;
 
-    @ApiModelProperty(value = "Data separator, stored as ASCII code")
+    @ApiModelProperty(value = "Data separator")
     private String dataSeparator;
 
-    @ApiModelProperty(value = "Data field escape symbol, stored as ASCII code")
+    @ApiModelProperty(value = "Data field escape symbol")
     private String dataEscapeChar;
 
     @ApiModelProperty("Configure the Source's startup mode. "
