@@ -17,11 +17,11 @@
 
 package org.apache.inlong.manager.service.core;
 
-import java.io.IOException;
-import java.util.List;
 import org.apache.inlong.manager.pojo.audit.AuditRequest;
 import org.apache.inlong.manager.pojo.audit.AuditVO;
 
+import java.util.List;
+
 /**
  * The service interface for audit.
  */
@@ -34,6 +34,6 @@ public interface AuditService {
      * @param request The audit request of query condition
      * @return The result of query
      */
-    List<AuditVO> listByCondition(AuditRequest request) throws IOException;
+    List<AuditVO> listByCondition(AuditRequest request) throws Exception;
 
 }
