@@ -40,6 +40,7 @@ import org.apache.inlong.manager.dao.entity.StreamSourceEntity;
 import org.apache.inlong.manager.dao.mapper.InlongGroupEntityMapper;
 import org.apache.inlong.manager.dao.mapper.InlongGroupExtEntityMapper;
 import org.apache.inlong.manager.dao.mapper.StreamSourceEntityMapper;
+import org.apache.inlong.manager.pojo.cluster.ClusterInfo;
 import org.apache.inlong.manager.pojo.common.OrderFieldEnum;
 import org.apache.inlong.manager.pojo.common.OrderTypeEnum;
 import org.apache.inlong.manager.pojo.common.PageResult;
@@ -56,12 +57,14 @@ import org.apache.inlong.manager.pojo.sort.BaseSortConf.SortType;
 import org.apache.inlong.manager.pojo.sort.FlinkSortConf;
 import org.apache.inlong.manager.pojo.sort.UserDefinedSortConf;
 import org.apache.inlong.manager.pojo.source.StreamSource;
+import org.apache.inlong.manager.service.cluster.InlongClusterService;
 import org.apache.inlong.manager.service.source.SourceOperatorFactory;
 import org.apache.inlong.manager.service.source.StreamSourceOperator;
 import org.apache.inlong.manager.service.stream.InlongStreamService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.beans.factory.annotation.Value;
 import org.springframework.stereotype.Service;
 import org.springframework.transaction.annotation.Isolation;
 import org.springframework.transaction.annotation.Propagation;
@@ -77,6 +80,9 @@ import java.util.Objects;
 import java.util.Set;
 import java.util.stream.Collectors;
 
+import static org.apache.inlong.common.constant.ClusterSwitch.BACKUP_CLUSTER_TAG;
+import static org.apache.inlong.manager.pojo.common.PageRequest.MAX_PAGE_SIZE;
+
 /**
  * Inlong group service layer implementation
  */
@@ -85,20 +91,25 @@ import java.util.stream.Collectors;
 public class InlongGroupServiceImpl implements InlongGroupService {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(InlongGroupServiceImpl.class);
-    private static final Integer MAX_PAGE_SIZE = 100;
 
-    @Autowired
-    private InlongGroupOperatorFactory groupOperatorFactory;
+    @Value("${sort.enable.zookeeper:false}")
+    private boolean enableZookeeper;
+
     @Autowired
     private InlongGroupEntityMapper groupMapper;
     @Autowired
     private InlongGroupExtEntityMapper groupExtMapper;
     @Autowired
+    private InlongStreamService streamService;
+    @Autowired
     private StreamSourceEntityMapper streamSourceMapper;
     @Autowired
-    private SourceOperatorFactory sourceOperatorFactory;
+    private InlongClusterService clusterService;
+
     @Autowired
-    private InlongStreamService streamService;
+    private InlongGroupOperatorFactory groupOperatorFactory;
+    @Autowired
+    private SourceOperatorFactory sourceOperatorFactory;
 
     /**
      * Check whether modification is supported under the current group status, and which fields can be modified.
@@ -147,7 +158,7 @@ public class InlongGroupServiceImpl implements InlongGroupService {
             LOGGER.error("groupId {} has already exists", groupId);
             throw new BusinessException(ErrorCodeEnum.GROUP_DUPLICATE);
         }
-
+        request.setEnableZookeeper(enableZookeeper ? InlongConstants.ENABLE_ZK : InlongConstants.DISABLE_ZK);
         InlongGroupOperator instance = groupOperatorFactory.getInstance(request.getMqType());
         groupId = instance.saveOpt(request, operator);
 
@@ -184,7 +195,7 @@ public class InlongGroupServiceImpl implements InlongGroupService {
     @Override
     public PageResult<InlongGroupBriefInfo> listBrief(InlongGroupPageRequest request) {
         if (request.getPageSize() > MAX_PAGE_SIZE) {
-            LOGGER.warn("list group info, but page size is {}, change to {}", request.getPageSize(), MAX_PAGE_SIZE);
+            LOGGER.warn("list inlong groups, change page size from {} to {}", request.getPageSize(), MAX_PAGE_SIZE);
             request.setPageSize(MAX_PAGE_SIZE);
         }
         PageHelper.startPage(request.getPageNum(), request.getPageSize());
@@ -239,6 +250,7 @@ public class InlongGroupServiceImpl implements InlongGroupService {
         // check whether the current status can be modified
         checkGroupCanUpdate(entity, request, operator);
 
+        request.setEnableZookeeper(enableZookeeper ? InlongConstants.ENABLE_ZK : InlongConstants.DISABLE_ZK);
         InlongGroupOperator instance = groupOperatorFactory.getInstance(request.getMqType());
         instance.updateOpt(request, operator);
 
@@ -275,8 +287,8 @@ public class InlongGroupServiceImpl implements InlongGroupService {
         return true;
     }
 
-    @Transactional(rollbackFor = Throwable.class)
     @Override
+    @Transactional(rollbackFor = Throwable.class)
     public boolean delete(String groupId, String operator) {
         LOGGER.info("begin to delete inlong group for groupId={} by user={}", groupId, operator);
         Preconditions.checkNotNull(groupId, ErrorCodeEnum.GROUP_ID_IS_EMPTY.getMessage());
@@ -362,16 +374,50 @@ public class InlongGroupServiceImpl implements InlongGroupService {
     public InlongGroupTopicInfo getTopic(String groupId) {
         // the group info will not null in get() method
         InlongGroupInfo groupInfo = this.get(groupId);
+        InlongGroupOperator groupOperator = groupOperatorFactory.getInstance(groupInfo.getMqType());
+        InlongGroupTopicInfo topicInfo = groupOperator.getTopic(groupInfo);
 
-        InlongGroupOperator instance = groupOperatorFactory.getInstance(groupInfo.getMqType());
-        InlongGroupTopicInfo topicInfo = instance.getTopic(groupInfo);
+        // set the base params
+        topicInfo.setInlongGroupId(groupId);
+        String clusterTag = groupInfo.getInlongClusterTag();
+        topicInfo.setInlongClusterTag(clusterTag);
 
-        if (LOGGER.isDebugEnabled()) {
-            LOGGER.debug("success to get topic for groupId={}, result=" + topicInfo, groupId);
-        }
+        // assert: each MQ type has a corresponding type of cluster
+        List<ClusterInfo> clusterInfos = clusterService.listByTagAndType(clusterTag, groupInfo.getMqType());
+        topicInfo.setClusterInfos(clusterInfos);
+
+        LOGGER.debug("success to get topic for groupId={}, result={}", groupId, topicInfo);
         return topicInfo;
     }
 
+    @Override
+    public InlongGroupTopicInfo getBackupTopic(String groupId) {
+        // backup topic info saved in the ext table
+        InlongGroupExtEntity extEntity = groupExtMapper.selectByUniqueKey(groupId, BACKUP_CLUSTER_TAG);
+        if (extEntity == null || StringUtils.isBlank(extEntity.getKeyValue())) {
+            LOGGER.warn("not found any backup topic for groupId={}", groupId);
+            return null;
+        }
+
+        // the group info will not null in get() method
+        InlongGroupInfo groupInfo = this.get(groupId);
+        InlongGroupOperator groupOperator = groupOperatorFactory.getInstance(groupInfo.getMqType());
+        InlongGroupTopicInfo backupTopicInfo = groupOperator.getBackupTopic(groupInfo);
+
+        // set the base params
+        backupTopicInfo.setInlongGroupId(groupId);
+        String backupClusterTag = extEntity.getKeyValue();
+        backupTopicInfo.setInlongClusterTag(backupClusterTag);
+
+        // set backup cluster info
+        // assert: each MQ type has a corresponding type of cluster
+        List<ClusterInfo> clusterInfos = clusterService.listByTagAndType(backupClusterTag, groupInfo.getMqType());
+        backupTopicInfo.setClusterInfos(clusterInfos);
+
+        LOGGER.debug("success to get backup topic for groupId={}, result={}", groupId, backupTopicInfo);
+        return backupTopicInfo;
+    }
+
     @Override
     @Transactional(rollbackFor = Throwable.class, propagation = Propagation.REQUIRES_NEW)
     public void updateAfterApprove(InlongGroupApproveRequest approveRequest, String operator) {
