@@ -27,6 +27,7 @@ import org.apache.inlong.manager.common.util.Preconditions;
 import org.apache.inlong.manager.dao.entity.DataNodeEntity;
 import org.apache.inlong.manager.dao.mapper.DataNodeEntityMapper;
 import org.apache.inlong.manager.pojo.common.PageResult;
+import org.apache.inlong.manager.pojo.common.UpdateResult;
 import org.apache.inlong.manager.pojo.node.DataNodeInfo;
 import org.apache.inlong.manager.pojo.node.DataNodePageRequest;
 import org.apache.inlong.manager.pojo.node.DataNodeRequest;
@@ -35,10 +36,10 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
+import org.springframework.transaction.annotation.Transactional;
 
 import java.sql.Connection;
 import java.util.List;
-import java.util.Objects;
 import java.util.stream.Collectors;
 
 /**
@@ -60,8 +61,8 @@ public class DataNodeServiceImpl implements DataNodeService {
         String type = request.getType();
 
         // check if data node already exist
-        DataNodeEntity exist = dataNodeMapper.selectByNameAndType(name, type);
-        if (exist != null) {
+        DataNodeEntity existEntity = dataNodeMapper.selectByUniqueKey(name, type);
+        if (existEntity != null) {
             String errMsg = String.format("data node already exist for name=%s type=%s)", name, type);
             LOGGER.error(errMsg);
             throw new BusinessException(errMsg);
@@ -88,6 +89,21 @@ public class DataNodeServiceImpl implements DataNodeService {
         return dataNodeInfo;
     }
 
+    @Override
+    public DataNodeInfo get(String name, String type) {
+        DataNodeEntity entity = dataNodeMapper.selectByUniqueKey(name, type);
+        if (entity == null) {
+            String errMsg = String.format("data node not found by name=%s, type=%s", name, type);
+            LOGGER.error(errMsg);
+            throw new BusinessException(errMsg);
+        }
+
+        DataNodeOperator dataNodeOperator = operatorFactory.getInstance(type);
+        DataNodeInfo dataNodeInfo = dataNodeOperator.getFromEntity(entity);
+        LOGGER.debug("success to get data node by name={} type={}", name, type);
+        return dataNodeInfo;
+    }
+
     @Override
     public PageResult<DataNodeInfo> list(DataNodePageRequest request) {
         PageHelper.startPage(request.getPageNum(), request.getPageSize());
@@ -106,34 +122,49 @@ public class DataNodeServiceImpl implements DataNodeService {
     }
 
     @Override
+    @Transactional(rollbackFor = Throwable.class)
     public Boolean update(DataNodeRequest request, String operator) {
+        LOGGER.info("begin to update data node by id: {}", request);
+
+        // Check whether the data node name exists with the same groupId and streamId
         String name = request.getName();
         String type = request.getType();
-        DataNodeEntity exist = dataNodeMapper.selectByNameAndType(name, type);
+        DataNodeEntity existEntity = dataNodeMapper.selectByUniqueKey(name, type);
         Integer id = request.getId();
-        if (exist != null && !Objects.equals(id, exist.getId())) {
-            String errMsg = String.format("data node already exist for name=%s type=%s", name, type);
+        if (existEntity != null && !existEntity.getId().equals(id)) {
+            String errMsg = String.format("data node already exist for name=%s, type=%s", name, type);
             LOGGER.error(errMsg);
             throw new BusinessException(errMsg);
         }
 
-        DataNodeEntity entity = dataNodeMapper.selectById(id);
-        if (entity == null) {
-            LOGGER.error("data node not found by id={}", id);
-            throw new BusinessException(String.format("data node not found by id=%s", id));
-        }
-        String errMsg = String.format("data node has already updated with name=%s, type=%s, curVersion=%s",
-                entity.getName(), entity.getType(), request.getVersion());
-        if (!Objects.equals(entity.getVersion(), request.getVersion())) {
-            LOGGER.error(errMsg);
-            throw new BusinessException(ErrorCodeEnum.CONFIG_EXPIRED);
-        }
         DataNodeOperator dataNodeOperator = operatorFactory.getInstance(request.getType());
         dataNodeOperator.updateOpt(request, operator);
+
         LOGGER.info("success to update data node={}", request);
         return true;
     }
 
+    @Override
+    @Transactional(rollbackFor = Throwable.class)
+    public UpdateResult updateByKey(DataNodeRequest request, String operator) {
+        LOGGER.info("begin to update data node by key: {}", request);
+
+        // Check whether the data node exists
+        String name = request.getName();
+        String type = request.getType();
+        DataNodeEntity entity = dataNodeMapper.selectByUniqueKey(name, type);
+        if (entity == null) {
+            String errMsg = String.format("data node not found by name=%s, type=%s", name, type);
+            LOGGER.error(errMsg);
+            throw new BusinessException(errMsg);
+        }
+
+        request.setId(entity.getId());
+        Boolean result = this.update(request, operator);
+        LOGGER.info("success to update data node by key: {}", request);
+        return new UpdateResult(entity.getId(), result, request.getVersion() + 1);
+    }
+
     @Override
     public Boolean delete(Integer id, String operator) {
         DataNodeEntity entity = dataNodeMapper.selectById(id);
@@ -142,6 +173,10 @@ public class DataNodeServiceImpl implements DataNodeService {
             return false;
         }
 
+        return delete(entity, operator);
+    }
+
+    private Boolean delete(DataNodeEntity entity, String operator) {
         entity.setIsDeleted(entity.getId());
         entity.setModifier(operator);
         int rowCount = dataNodeMapper.updateById(entity);
@@ -150,10 +185,20 @@ public class DataNodeServiceImpl implements DataNodeService {
                     entity.getName(), entity.getType(), entity.getVersion());
             throw new BusinessException(ErrorCodeEnum.CONFIG_EXPIRED);
         }
-        LOGGER.info("success to delete data node by id={}", id);
+        LOGGER.info("success to delete data node by id={}, name={}", entity.getId(), entity.getName());
         return true;
     }
 
+    @Override
+    public Boolean deleteByKey(String name, String type, String operator) {
+        DataNodeEntity entity = dataNodeMapper.selectByUniqueKey(name, type);
+        if (entity == null || entity.getIsDeleted() > InlongConstants.UN_DELETED) {
+            LOGGER.error("data node not found or was already deleted for name={}", name);
+            return false;
+        }
+        return delete(entity, operator);
+    }
+
     @Override
     public Boolean testConnection(DataNodeRequest request) {
         LOGGER.info("begin test connection for: {}", request);
