@@ -24,7 +24,7 @@ import org.apache.inlong.manager.common.conversion.ConversionHandle;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.common.util.Preconditions;
 import org.apache.inlong.manager.pojo.group.pulsar.InlongPulsarInfo;
-import org.apache.inlong.manager.pojo.queue.pulsar.PulsarTopicBean;
+import org.apache.inlong.manager.pojo.queue.pulsar.PulsarTopicInfo;
 import org.apache.inlong.manager.service.cluster.InlongClusterServiceImpl;
 import org.apache.pulsar.client.admin.Namespaces;
 import org.apache.pulsar.client.admin.PulsarAdmin;
@@ -92,7 +92,7 @@ public class PulsarOperator {
         LOGGER.info("begin to create namespace={}", namespaceName);
         try {
             // Check whether the namespace exists, and create it if it does not exist
-            boolean isExists = this.namespacesIsExists(pulsarAdmin, tenant, namespace);
+            boolean isExists = this.namespaceExists(pulsarAdmin, tenant, namespace);
             if (isExists) {
                 LOGGER.warn("namespace={} already exists, skip to create", namespaceName);
                 return;
@@ -138,41 +138,41 @@ public class PulsarOperator {
     /**
      * Create Pulsar topic
      */
-    public void createTopic(PulsarAdmin pulsarAdmin, PulsarTopicBean topicBean) throws PulsarAdminException {
-        Preconditions.checkNotNull(topicBean, "pulsar topic info cannot be empty");
-        String tenant = topicBean.getTenant();
-        String namespace = topicBean.getNamespace();
-        String topic = topicBean.getTopicName();
-        String topicFullName = tenant + "/" + namespace + "/" + topic;
+    public void createTopic(PulsarAdmin pulsarAdmin, PulsarTopicInfo topicInfo) throws PulsarAdminException {
+        Preconditions.checkNotNull(topicInfo, "pulsar topic info cannot be empty");
+        String tenant = topicInfo.getTenant();
+        String namespace = topicInfo.getNamespace();
+        String topicName = topicInfo.getTopicName();
+        String fullTopicName = tenant + "/" + namespace + "/" + topicName;
 
         // Topic will be returned if it exists, and created if it does not exist
-        if (topicIsExists(pulsarAdmin, tenant, namespace, topic,
-                InlongConstants.PULSAR_QUEUE_TYPE_PARALLEL.equals(topicBean.getQueueModule()))) {
-            LOGGER.warn("pulsar topic={} already exists in {}", topicFullName, pulsarAdmin.getServiceUrl());
+        if (topicExists(pulsarAdmin, tenant, namespace, topicName,
+                InlongConstants.PULSAR_QUEUE_TYPE_PARALLEL.equals(topicInfo.getQueueModule()))) {
+            LOGGER.warn("pulsar topic={} already exists in {}", fullTopicName, pulsarAdmin.getServiceUrl());
             return;
         }
 
         try {
-            if (InlongConstants.PULSAR_QUEUE_TYPE_SERIAL.equals(topicBean.getQueueModule())) {
-                pulsarAdmin.topics().createNonPartitionedTopic(topicFullName);
-                String res = pulsarAdmin.lookups().lookupTopic(topicFullName);
-                LOGGER.info("success to create topic={}, lookup result is {}", topicFullName, res);
+            if (InlongConstants.PULSAR_QUEUE_TYPE_SERIAL.equals(topicInfo.getQueueModule())) {
+                pulsarAdmin.topics().createNonPartitionedTopic(fullTopicName);
+                String res = pulsarAdmin.lookups().lookupTopic(fullTopicName);
+                LOGGER.info("success to create topic={}, lookup result is {}", fullTopicName, res);
             } else {
                 // The number of brokers as the default value of topic partition
                 List<String> clusters = PulsarUtils.getPulsarClusters(pulsarAdmin);
-                Integer numPartitions = topicBean.getNumPartitions();
+                Integer numPartitions = topicInfo.getNumPartitions();
                 if (numPartitions < 0 || numPartitions <= MAX_PARTITION) {
                     List<String> brokers = pulsarAdmin.brokers().getActiveBrokers(clusters.get(0));
                     numPartitions = brokers.size();
                 }
 
-                pulsarAdmin.topics().createPartitionedTopic(topicFullName, numPartitions);
-                Map<String, String> res = pulsarAdmin.lookups().lookupPartitionedTopic(topicFullName);
+                pulsarAdmin.topics().createPartitionedTopic(fullTopicName, numPartitions);
+                Map<String, String> res = pulsarAdmin.lookups().lookupPartitionedTopic(fullTopicName);
                 // if lookup failed (res.size not equals the partition number)
                 if (res.keySet().size() != numPartitions) {
                     // look up partition failed, retry to get partition numbers
                     for (int i = 0; (i < RETRY_TIMES && res.keySet().size() != numPartitions); i++) {
-                        res = pulsarAdmin.lookups().lookupPartitionedTopic(topicFullName);
+                        res = pulsarAdmin.lookups().lookupPartitionedTopic(fullTopicName);
                         try {
                             Thread.sleep(500);
                         } catch (InterruptedException e) {
@@ -183,10 +183,10 @@ public class PulsarOperator {
                 if (numPartitions != res.keySet().size()) {
                     throw new PulsarAdminException("The number of partitions not equal to lookupPartitionedTopic");
                 }
-                LOGGER.info("success to create topic={}", topicFullName);
+                LOGGER.info("success to create topic={}", fullTopicName);
             }
         } catch (PulsarAdminException e) {
-            LOGGER.error("failed to create topic=" + topicFullName, e);
+            LOGGER.error("failed to create topic=" + fullTopicName, e);
             throw e;
         }
     }
@@ -194,26 +194,26 @@ public class PulsarOperator {
     /**
      * Force delete Pulsar topic
      */
-    public void forceDeleteTopic(PulsarAdmin pulsarAdmin, PulsarTopicBean topicBean) throws PulsarAdminException {
-        Preconditions.checkNotNull(topicBean, "pulsar topic info cannot be empty");
+    public void forceDeleteTopic(PulsarAdmin pulsarAdmin, PulsarTopicInfo topicInfo) throws PulsarAdminException {
+        Preconditions.checkNotNull(topicInfo, "pulsar topic info cannot be empty");
 
-        String tenant = topicBean.getTenant();
-        String namespace = topicBean.getNamespace();
-        String topic = topicBean.getTopicName();
-        String topicFullName = tenant + "/" + namespace + "/" + topic;
+        String tenant = topicInfo.getTenant();
+        String namespace = topicInfo.getNamespace();
+        String topic = topicInfo.getTopicName();
+        String fullTopicName = tenant + "/" + namespace + "/" + topic;
 
         // Topic will be returned if it not exists
-        if (topicIsExists(pulsarAdmin, tenant, namespace, topic,
-                InlongConstants.PULSAR_QUEUE_TYPE_PARALLEL.equals(topicBean.getQueueModule()))) {
-            LOGGER.warn("pulsar topic={} already delete", topicFullName);
+        if (topicExists(pulsarAdmin, tenant, namespace, topic,
+                InlongConstants.PULSAR_QUEUE_TYPE_PARALLEL.equals(topicInfo.getQueueModule()))) {
+            LOGGER.warn("pulsar topic={} already delete", fullTopicName);
             return;
         }
 
         try {
-            pulsarAdmin.topics().delete(topicFullName, true);
-            LOGGER.info("success to delete topic={}", topicFullName);
+            pulsarAdmin.topics().delete(fullTopicName, true);
+            LOGGER.info("success to delete topic={}", fullTopicName);
         } catch (PulsarAdminException e) {
-            LOGGER.error("failed to delete topic=" + topicFullName, e);
+            LOGGER.error("failed to delete topic=" + fullTopicName, e);
             throw e;
         }
     }
@@ -221,21 +221,17 @@ public class PulsarOperator {
     /**
      * Create a Pulsar subscription for the given topic
      */
-    public void createSubscription(PulsarAdmin pulsarAdmin, PulsarTopicBean topicBean, String subscription)
-            throws PulsarAdminException {
-        Preconditions.checkNotNull(topicBean, "can not find tenant information to create subscription");
-        Preconditions.checkNotNull(subscription, "subscription cannot be empty during creating subscription");
-
-        String topicName = topicBean.getTenant() + "/" + topicBean.getNamespace() + "/" + topicBean.getTopicName();
-        LOGGER.info("begin to create pulsar subscription={} for topic={}", subscription, topicName);
+    public void createSubscription(PulsarAdmin pulsarAdmin, String fullTopicName, String queueModule,
+            String subscription) throws PulsarAdminException {
+        LOGGER.info("begin to create pulsar subscription={} for topic={}", subscription, fullTopicName);
         try {
-            boolean isExists = this.subscriptionIsExists(pulsarAdmin, topicName, subscription,
-                    InlongConstants.PULSAR_QUEUE_TYPE_PARALLEL.equals(topicBean.getQueueModule()));
+            boolean isExists = this.subscriptionExists(pulsarAdmin, fullTopicName, subscription,
+                    InlongConstants.PULSAR_QUEUE_TYPE_PARALLEL.equals(queueModule));
             if (isExists) {
                 LOGGER.warn("pulsar subscription={} already exists, skip to create", subscription);
                 return;
             }
-            pulsarAdmin.topics().createSubscription(topicName, subscription, MessageId.latest);
+            pulsarAdmin.topics().createSubscription(fullTopicName, subscription, MessageId.latest);
             LOGGER.info("success to create subscription={}", subscription);
         } catch (PulsarAdminException e) {
             LOGGER.error("failed to create pulsar subscription=" + subscription, e);
@@ -246,11 +242,12 @@ public class PulsarOperator {
     /**
      * Create a Pulsar subscription for the specified topic list
      */
-    public void createSubscriptions(PulsarAdmin pulsarAdmin, String subscription, PulsarTopicBean topicBean,
+    public void createSubscriptions(PulsarAdmin pulsarAdmin, String subscription, PulsarTopicInfo topicInfo,
             List<String> topicList) throws PulsarAdminException {
         for (String topic : topicList) {
-            topicBean.setTopicName(topic);
-            this.createSubscription(pulsarAdmin, topicBean, subscription);
+            topicInfo.setTopicName(topic);
+            String fullTopicName = topicInfo.getTenant() + "/" + topicInfo.getNamespace() + "/" + topic;
+            this.createSubscription(pulsarAdmin, fullTopicName, topicInfo.getQueueModule(), subscription);
         }
         LOGGER.info("success to create subscription={} for multiple topics={}", subscription, topicList);
     }
@@ -266,7 +263,7 @@ public class PulsarOperator {
     /**
      * Check whether the Pulsar namespace exists under the specified tenant
      */
-    private boolean namespacesIsExists(PulsarAdmin pulsarAdmin, String tenant, String namespace)
+    private boolean namespaceExists(PulsarAdmin pulsarAdmin, String tenant, String namespace)
             throws PulsarAdminException {
         List<String> namespaceList = pulsarAdmin.namespaces().getNamespaces(tenant);
         return namespaceList.contains(tenant + "/" + namespace);
@@ -278,9 +275,9 @@ public class PulsarOperator {
      * @apiNote cannot compare whether the string contains, otherwise it may be misjudged, such as:
      *         Topic "ab" does not exist, but if "abc" exists, "ab" will be mistakenly judged to exist
      */
-    public boolean topicIsExists(PulsarAdmin pulsarAdmin, String tenant, String namespace, String topic,
+    public boolean topicExists(PulsarAdmin pulsarAdmin, String tenant, String namespace, String topicName,
             boolean isPartitioned) {
-        if (StringUtils.isBlank(topic)) {
+        if (StringUtils.isBlank(topicName)) {
             return true;
         }
 
@@ -295,36 +292,39 @@ public class PulsarOperator {
             }
             for (String t : topicList) {
                 t = t.substring(t.lastIndexOf("/") + 1); // not contains /
-                if (topic.equals(t)) {
+                if (topicName.equals(t)) {
                     topicExists = true;
                     break;
                 }
             }
         } catch (PulsarAdminException pe) {
-            LOGGER.error("check if the pulsar topic={} exists error, begin retry", topic, pe);
+            LOGGER.error("check if the pulsar topic={} exists error, begin retry", topicName, pe);
             int count = 0;
             try {
                 while (!topicExists && ++count <= RETRY_TIMES) {
-                    LOGGER.info("check whether the pulsar topic={} exists error, try count={}", topic, count);
+                    LOGGER.info("check whether the pulsar topic={} exists error, try count={}", topicName, count);
                     Thread.sleep(DELAY_SECONDS);
 
                     topicList = pulsarAdmin.topics().getPartitionedTopicList(tenant + "/" + namespace);
                     for (String t : topicList) {
                         t = t.substring(t.lastIndexOf("/") + 1);
-                        if (topic.equals(t)) {
+                        if (topicName.equals(t)) {
                             topicExists = true;
                             break;
                         }
                     }
                 }
             } catch (Exception e) {
-                LOGGER.error("after retry, check if the pulsar topic={} exists still error", topic, pe);
+                LOGGER.error("after retry, check if the pulsar topic={} exists still error", topicName, pe);
             }
         }
         return topicExists;
     }
 
-    private boolean subscriptionIsExists(PulsarAdmin pulsarAdmin, String topic, String subscription,
+    /**
+     * Check whether the Pulsar topic exists.
+     */
+    private boolean subscriptionExists(PulsarAdmin pulsarAdmin, String topic, String subscription,
             boolean isPartitioned) {
         int count = 0;
         while (++count <= RETRY_TIMES) {
@@ -353,7 +353,7 @@ public class PulsarOperator {
                 LOGGER.error("check if the subscription exists for topic={} error, continue retry", topic, e);
                 if (count == RETRY_TIMES) {
                     LOGGER.error("after {} times retry, still check subscription exception for topic {}", count, topic);
-                    throw new BusinessException("check if the subscription exists error");
+                    throw new BusinessException("check if the subscription exists error: " + e.getMessage());
                 }
             }
         }
