@@ -17,23 +17,22 @@
 
 package org.apache.inlong.manager.service.resource.sort;
 
-import com.google.common.collect.Lists;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.inlong.manager.common.consts.InlongConstants;
 import org.apache.inlong.manager.pojo.group.InlongGroupExtInfo;
 import org.apache.inlong.manager.pojo.group.InlongGroupInfo;
 import org.apache.inlong.manager.pojo.sink.StreamSink;
+import org.apache.inlong.manager.pojo.sort.util.ExtractNodeUtils;
+import org.apache.inlong.manager.pojo.sort.util.LoadNodeUtils;
+import org.apache.inlong.manager.pojo.sort.util.NodeRelationUtils;
+import org.apache.inlong.manager.pojo.sort.util.TransformNodeUtils;
 import org.apache.inlong.manager.pojo.source.StreamSource;
 import org.apache.inlong.manager.pojo.stream.InlongStreamExtInfo;
 import org.apache.inlong.manager.pojo.stream.InlongStreamInfo;
 import org.apache.inlong.manager.pojo.stream.StreamField;
 import org.apache.inlong.manager.pojo.transform.TransformResponse;
 import org.apache.inlong.manager.service.sink.StreamSinkService;
-import org.apache.inlong.manager.pojo.sort.util.ExtractNodeUtils;
-import org.apache.inlong.manager.pojo.sort.util.LoadNodeUtils;
-import org.apache.inlong.manager.pojo.sort.util.NodeRelationUtils;
-import org.apache.inlong.manager.pojo.sort.util.TransformNodeUtils;
 import org.apache.inlong.manager.service.source.StreamSourceService;
 import org.apache.inlong.manager.service.transform.StreamTransformService;
 import org.apache.inlong.sort.protocol.GroupInfo;
@@ -47,8 +46,11 @@ import org.springframework.stereotype.Service;
 
 import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
+import java.util.ListIterator;
 import java.util.Map;
+import java.util.Set;
 import java.util.stream.Collectors;
 
 /**
@@ -75,39 +77,32 @@ public class DefaultSortConfigOperator implements SortConfigOperator {
     @Override
     public void buildConfig(InlongGroupInfo groupInfo, List<InlongStreamInfo> streamInfos, boolean isStream)
             throws Exception {
+        if (isStream) {
+            LOGGER.warn("no need to build sort config for stream process when disable zk");
+            return;
+        }
         if (groupInfo == null || CollectionUtils.isEmpty(streamInfos)) {
-            LOGGER.warn("group info is null or stream infos is empty, no need to build sort config for disable zk");
+            LOGGER.warn("no need to build sort config as the group is null or streams is empty when disable zk");
             return;
         }
 
-        GroupInfo configInfo;
-        // if the mode of inlong group is LIGHTWEIGHT, means not using any MQ as a cached source
-        if (InlongConstants.LIGHTWEIGHT_MODE.equals(groupInfo.getLightweight())) {
-            configInfo = this.getLightweightGroupInfo(groupInfo, streamInfos);
-        } else {
-            configInfo = this.getStandardGroupInfo(groupInfo, streamInfos);
-        }
-
-        String dataflow = OBJECT_MAPPER.writeValueAsString(configInfo);
-        if (isStream) {
-            this.addToStreamExt(streamInfos, dataflow);
-        } else {
-            this.addToGroupExt(groupInfo, dataflow);
-        }
+        GroupInfo sortConfigInfo = this.getGroupInfo(groupInfo, streamInfos);
+        String dataflow = OBJECT_MAPPER.writeValueAsString(sortConfigInfo);
+        this.addToGroupExt(groupInfo, dataflow);
 
         if (LOGGER.isDebugEnabled()) {
             LOGGER.debug("success to build sort config, isStream={}, dataflow={}", isStream, dataflow);
         }
     }
 
-    private GroupInfo getLightweightGroupInfo(InlongGroupInfo groupInfo, List<InlongStreamInfo> streamInfoList) {
+    private GroupInfo getGroupInfo(InlongGroupInfo groupInfo, List<InlongStreamInfo> streamInfoList) {
         // get source info
         Map<String, List<StreamSource>> sourceMap = sourceService.getSourcesMap(groupInfo, streamInfoList);
         // get sink info
         Map<String, List<StreamSink>> sinkMap = sinkService.getSinksMap(groupInfo, streamInfoList);
 
-        List<TransformResponse> transformResponses = transformService.listTransform(groupInfo.getInlongGroupId(), null);
-        Map<String, List<TransformResponse>> transformMap = transformResponses.stream()
+        List<TransformResponse> transformList = transformService.listTransform(groupInfo.getInlongGroupId(), null);
+        Map<String, List<TransformResponse>> transformMap = transformList.stream()
                 .collect(Collectors.groupingBy(TransformResponse::getInlongStreamId, HashMap::new,
                         Collectors.toCollection(ArrayList::new)));
 
@@ -117,68 +112,94 @@ public class DefaultSortConfigOperator implements SortConfigOperator {
             Map<String, StreamField> fieldMap = new HashMap<>();
             inlongStream.getSourceList().forEach(
                     source -> parseConstantFieldMap(source.getSourceName(), source.getFieldList(), fieldMap));
-            List<TransformResponse> transformResponseList = transformMap.get(streamId);
-            if (CollectionUtils.isNotEmpty(transformResponseList)) {
-                transformResponseList.forEach(
+
+            List<TransformResponse> transformResponses = transformMap.get(streamId);
+            if (CollectionUtils.isNotEmpty(transformResponses)) {
+                transformResponses.forEach(
                         trans -> parseConstantFieldMap(trans.getTransformName(), trans.getFieldList(), fieldMap));
             }
 
             // build a stream info from the nodes and relations
-            List<Node> nodes = this.createNodesWithTransform(sourceMap.get(streamId),
-                    transformResponseList, sinkMap.get(streamId), fieldMap);
-            List<NodeRelation> relations = NodeRelationUtils.createNodeRelations(inlongStream);
+            List<StreamSource> sources = sourceMap.get(streamId);
+            List<StreamSink> sinks = sinkMap.get(streamId);
+            List<NodeRelation> relations;
+
+            if (InlongConstants.STANDARD_MODE.equals(groupInfo.getLightweight())) {
+                if (CollectionUtils.isNotEmpty(transformResponses)) {
+                    relations = NodeRelationUtils.createNodeRelations(inlongStream);
+                    // in standard mode, replace upstream source node and transform input fields node
+                    // to MQ node (which is inlong stream id)
+                    String mqNodeName = sources.get(0).getSourceName();
+                    Set<String> nodeNameSet = getInputNodeNames(sources, transformResponses);
+                    adjustTransformField(transformResponses, nodeNameSet, mqNodeName);
+                    adjustNodeRelations(relations, nodeNameSet, mqNodeName);
+                } else {
+                    relations = NodeRelationUtils.createNodeRelations(sources, sinks);
+                }
+            } else {
+                relations = NodeRelationUtils.createNodeRelations(inlongStream);
+            }
+
+            // create extract-transform-load nodes
+            List<Node> nodes = this.createNodes(sources, transformResponses, sinks, fieldMap);
+
             StreamInfo streamInfo = new StreamInfo(streamId, nodes, relations);
             sortStreamInfos.add(streamInfo);
 
             // rebuild joinerNode relation
-            NodeRelationUtils.optimizeNodeRelation(streamInfo, transformResponseList);
+            NodeRelationUtils.optimizeNodeRelation(streamInfo, transformResponses);
         }
 
         return new GroupInfo(groupInfo.getInlongGroupId(), sortStreamInfos);
     }
 
     /**
-     * Get Sort GroupInfo of STANDARD inlong group.
-     *
-     * @see org.apache.inlong.sort.protocol.GroupInfo
+     * Deduplicate to get the node names of Source and Transform.
      */
-    private GroupInfo getStandardGroupInfo(InlongGroupInfo groupInfo, List<InlongStreamInfo> streamInfoList) {
-        // get source info
-        Map<String, List<StreamSource>> sourceMap = sourceService.getSourcesMap(groupInfo, streamInfoList);
-        // get sink info
-        Map<String, List<StreamSink>> sinkMap = sinkService.getSinksMap(groupInfo, streamInfoList);
-
-        // create StreamInfo for Sort protocol
-        List<StreamInfo> sortStreamInfos = new ArrayList<>();
-        for (InlongStreamInfo inlongStream : streamInfoList) {
-            String streamId = inlongStream.getInlongStreamId();
-
-            Map<String, StreamField> fieldMap = new HashMap<>();
-            inlongStream.getSourceList().forEach(
-                    source -> parseConstantFieldMap(source.getSourceName(), source.getFieldList(), fieldMap));
-
-            List<StreamSource> sources = sourceMap.get(streamId);
-            List<StreamSink> sinks = sinkMap.get(streamId);
-            StreamInfo sortStream = new StreamInfo(streamId,
-                    this.createNodesWithoutTransform(sources, sinks, fieldMap),
-                    NodeRelationUtils.createNodeRelations(sources, sinks));
-            sortStreamInfos.add(sortStream);
+    private Set<String> getInputNodeNames(List<StreamSource> sources, List<TransformResponse> transforms) {
+        Set<String> result = new HashSet<>();
+        if (CollectionUtils.isNotEmpty(sources)) {
+            result.addAll(sources.stream().map(StreamSource::getSourceName).collect(Collectors.toSet()));
         }
-
-        return new GroupInfo(groupInfo.getInlongGroupId(), sortStreamInfos);
+        if (CollectionUtils.isNotEmpty(transforms)) {
+            result.addAll(transforms.stream().map(TransformResponse::getTransformName).collect(Collectors.toSet()));
+        }
+        return result;
     }
 
-    private List<Node> createNodesWithoutTransform(List<StreamSource> sources, List<StreamSink> sinks,
-            Map<String, StreamField> constantFieldMap) {
-        List<Node> nodes = Lists.newArrayList();
-        nodes.addAll(ExtractNodeUtils.createExtractNodes(sources));
-        nodes.addAll(LoadNodeUtils.createLoadNodes(sinks, constantFieldMap));
-        return nodes;
+    /**
+     * Set origin node to mq node for transform fields if necessary.
+     *
+     * In standard mode for InlongGroup, transform input node must either be
+     * mq source node or transform node, otherwise replace it with mq node name.
+     */
+    private void adjustTransformField(List<TransformResponse> transforms, Set<String> nodeNameSet, String mqNodeName) {
+        for (TransformResponse transform : transforms) {
+            for (StreamField field : transform.getFieldList()) {
+                if (!nodeNameSet.contains(field.getOriginNodeName())) {
+                    field.setOriginNodeName(mqNodeName);
+                }
+            }
+        }
     }
 
-    private List<Node> createNodesWithTransform(List<StreamSource> sources, List<TransformResponse> transformResponses,
+    /**
+     * Set the input node to MQ node for NodeRelations
+     */
+    private void adjustNodeRelations(List<NodeRelation> relations, Set<String> nodeNameSet, String mqNodeName) {
+        for (NodeRelation relation : relations) {
+            ListIterator<String> iterator = relation.getInputs().listIterator();
+            while (iterator.hasNext()) {
+                if (!nodeNameSet.contains(iterator.next())) {
+                    iterator.set(mqNodeName);
+                }
+            }
+        }
+    }
+
+    private List<Node> createNodes(List<StreamSource> sources, List<TransformResponse> transformResponses,
             List<StreamSink> sinks, Map<String, StreamField> constantFieldMap) {
-        List<Node> nodes = Lists.newArrayList();
+        List<Node> nodes = new ArrayList<>();
         nodes.addAll(ExtractNodeUtils.createExtractNodes(sources));
         nodes.addAll(TransformNodeUtils.createTransformNodes(transformResponses, constantFieldMap));
         nodes.addAll(LoadNodeUtils.createLoadNodes(sinks, constantFieldMap));
@@ -209,7 +230,7 @@ public class DefaultSortConfigOperator implements SortConfigOperator {
      */
     private void addToGroupExt(InlongGroupInfo groupInfo, String value) {
         if (groupInfo.getExtList() == null) {
-            groupInfo.setExtList(Lists.newArrayList());
+            groupInfo.setExtList(new ArrayList<>());
         }
 
         InlongGroupExtInfo extInfo = new InlongGroupExtInfo();
@@ -227,7 +248,7 @@ public class DefaultSortConfigOperator implements SortConfigOperator {
     private void addToStreamExt(List<InlongStreamInfo> streamInfos, String value) {
         streamInfos.forEach(streamInfo -> {
             if (streamInfo.getExtList() == null) {
-                streamInfo.setExtList(Lists.newArrayList());
+                streamInfo.setExtList(new ArrayList<>());
             }
 
             InlongStreamExtInfo extInfo = new InlongStreamExtInfo();
