@@ -17,7 +17,6 @@
 
 package org.apache.inlong.manager.service.sink;
 
-import com.fasterxml.jackson.databind.ObjectMapper;
 import com.github.pagehelper.Page;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -26,6 +25,7 @@ import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.enums.SinkStatus;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.common.util.CommonBeanUtils;
+import org.apache.inlong.manager.common.util.JsonUtils;
 import org.apache.inlong.manager.common.util.Preconditions;
 import org.apache.inlong.manager.dao.entity.StreamSinkEntity;
 import org.apache.inlong.manager.dao.entity.StreamSinkFieldEntity;
@@ -35,12 +35,15 @@ import org.apache.inlong.manager.pojo.common.PageResult;
 import org.apache.inlong.manager.pojo.sink.SinkField;
 import org.apache.inlong.manager.pojo.sink.SinkRequest;
 import org.apache.inlong.manager.pojo.sink.StreamSink;
+import org.apache.inlong.manager.service.node.DataNodeOperateHelper;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.Objects;
 import java.util.stream.Collectors;
 
@@ -49,14 +52,15 @@ import java.util.stream.Collectors;
  */
 public abstract class AbstractSinkOperator implements StreamSinkOperator {
 
+    protected static final String KEY_GROUP_ID = "inlongGroupId";
+    protected static final String KEY_STREAM_ID = "inlongStreamId";
     private static final Logger LOGGER = LoggerFactory.getLogger(AbstractSinkOperator.class);
-
-    @Autowired
-    protected ObjectMapper objectMapper;
     @Autowired
     protected StreamSinkEntityMapper sinkMapper;
     @Autowired
     protected StreamSinkFieldEntityMapper sinkFieldMapper;
+    @Autowired
+    protected DataNodeOperateHelper dataNodeHelper;
 
     /**
      * Setting the parameters of the latest entity.
@@ -110,7 +114,7 @@ public abstract class AbstractSinkOperator implements StreamSinkOperator {
     }
 
     @Override
-    public void updateOpt(SinkRequest request, String operator) {
+    public void updateOpt(SinkRequest request, SinkStatus nextStatus, String operator) {
         StreamSinkEntity entity = sinkMapper.selectByPrimaryKey(request.getId());
         Preconditions.checkNotNull(entity, ErrorCodeEnum.SINK_INFO_NOT_FOUND.getMessage());
 
@@ -123,9 +127,11 @@ public abstract class AbstractSinkOperator implements StreamSinkOperator {
         CommonBeanUtils.copyProperties(request, entity, true);
         setTargetEntity(request, entity);
         entity.setPreviousStatus(entity.getStatus());
-        entity.setStatus(SinkStatus.CONFIG_ING.getCode());
+        if (nextStatus != null) {
+            entity.setStatus(nextStatus.getCode());
+        }
         entity.setModifier(operator);
-        int rowCount = sinkMapper.updateByPrimaryKeySelective(entity);
+        int rowCount = sinkMapper.updateByIdSelective(entity);
         if (rowCount != InlongConstants.AFFECTED_ONE_ROW) {
             LOGGER.error(errMsg);
             throw new BusinessException(ErrorCodeEnum.CONFIG_EXPIRED);
@@ -199,7 +205,7 @@ public abstract class AbstractSinkOperator implements StreamSinkOperator {
         entity.setStatus(InlongConstants.DELETED_STATUS);
         entity.setIsDeleted(entity.getId());
         entity.setModifier(operator);
-        int rowCount = sinkMapper.updateByPrimaryKeySelective(entity);
+        int rowCount = sinkMapper.updateByIdSelective(entity);
         if (rowCount != InlongConstants.AFFECTED_ONE_ROW) {
             LOGGER.error("sink has already updated with groupId={}, streamId={}, name={}, curVersion={}",
                     entity.getInlongGroupId(), entity.getInlongStreamId(), entity.getSinkName(), entity.getVersion());
@@ -208,6 +214,27 @@ public abstract class AbstractSinkOperator implements StreamSinkOperator {
         sinkFieldMapper.logicDeleteAll(entity.getId());
     }
 
+    @Override
+    public Map<String, String> parse2IdParams(StreamSinkEntity streamSink, List<String> fields) {
+        Map<String, String> param;
+        try {
+            param = JsonUtils.parseObject(streamSink.getExtParams(), HashMap.class);
+            // put group and stream info
+            assert param != null;
+            param.put(KEY_GROUP_ID, streamSink.getInlongGroupId());
+            param.put(KEY_STREAM_ID, streamSink.getInlongStreamId());
+            return param;
+        } catch (Exception e) {
+            LOGGER.error(String.format(
+                            "cannot parse properties for groupId=%s, streamId=%s, sinkName=%s, the row properties: %s",
+                            streamSink.getInlongGroupId(), streamSink.getInlongStreamId(),
+                            streamSink.getSinkName(), streamSink.getExtParams()),
+                    e);
+
+            return null;
+        }
+    }
+
     /**
      * Check the validity of sink fields.
      */
