@@ -25,17 +25,19 @@ import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.inlong.manager.common.consts.InlongConstants;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
-import org.apache.inlong.manager.common.enums.GroupStatus;
 import org.apache.inlong.manager.common.enums.SinkStatus;
+import org.apache.inlong.manager.common.enums.StreamStatus;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.common.util.Preconditions;
-import org.apache.inlong.manager.dao.entity.InlongGroupEntity;
+import org.apache.inlong.manager.dao.entity.InlongStreamEntity;
 import org.apache.inlong.manager.dao.entity.StreamSinkEntity;
+import org.apache.inlong.manager.dao.mapper.InlongStreamEntityMapper;
 import org.apache.inlong.manager.dao.mapper.StreamSinkEntityMapper;
 import org.apache.inlong.manager.dao.mapper.StreamSinkFieldEntityMapper;
 import org.apache.inlong.manager.pojo.common.OrderFieldEnum;
 import org.apache.inlong.manager.pojo.common.OrderTypeEnum;
 import org.apache.inlong.manager.pojo.common.PageResult;
+import org.apache.inlong.manager.pojo.common.UpdateResult;
 import org.apache.inlong.manager.pojo.group.InlongGroupInfo;
 import org.apache.inlong.manager.pojo.sink.SinkApproveDTO;
 import org.apache.inlong.manager.pojo.sink.SinkBriefInfo;
@@ -58,7 +60,6 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Objects;
 import java.util.stream.Collectors;
 
 /**
@@ -74,6 +75,8 @@ public class StreamSinkServiceImpl implements StreamSinkService {
     @Autowired
     private GroupCheckService groupCheckService;
     @Autowired
+    private InlongStreamEntityMapper streamMapper;
+    @Autowired
     private StreamSinkEntityMapper sinkMapper;
     @Autowired
     private StreamSinkFieldEntityMapper sinkFieldMapper;
@@ -93,15 +96,18 @@ public class StreamSinkServiceImpl implements StreamSinkService {
         String groupId = request.getInlongGroupId();
         groupCheckService.checkGroupStatus(groupId, operator);
 
-        // Make sure that there is no sink info with the current groupId and streamId
+        // Make sure that there is no same sink name under the current groupId and streamId
         String streamId = request.getInlongStreamId();
         String sinkName = request.getSinkName();
-        List<StreamSinkEntity> sinkList = sinkMapper.selectByRelatedId(groupId, streamId, sinkName);
-        for (StreamSinkEntity sinkEntity : sinkList) {
-            if (sinkEntity != null && Objects.equals(sinkEntity.getSinkName(), sinkName)) {
-                String err = "sink name=%s already exists with the groupId=%s streamId=%s";
-                throw new BusinessException(String.format(err, sinkName, groupId, streamId));
-            }
+        // Check whether the stream exist or not
+        InlongStreamEntity streamEntity = streamMapper.selectByIdentifier(groupId, streamId);
+        Preconditions.checkNotNull(streamEntity, ErrorCodeEnum.STREAM_NOT_FOUND.getMessage());
+
+        // Check whether the sink name exists with the same groupId and streamId
+        StreamSinkEntity exists = sinkMapper.selectByUniqueKey(groupId, streamId, sinkName);
+        if (exists != null && exists.getSinkName().equals(sinkName)) {
+            String err = "sink name=%s already exists with the groupId=%s streamId=%s";
+            throw new BusinessException(String.format(err, sinkName, groupId, streamId));
         }
 
         // According to the sink type, save sink information
@@ -112,6 +118,18 @@ public class StreamSinkServiceImpl implements StreamSinkService {
             fields.forEach(sinkField -> sinkField.setId(null));
         }
         int id = sinkOperator.saveOpt(request, operator);
+        boolean streamSuccess = StreamStatus.CONFIG_SUCCESSFUL.getCode().equals(streamEntity.getStatus());
+        if (streamSuccess || StreamStatus.CONFIG_FAILED.getCode().equals(streamEntity.getStatus())) {
+            SinkStatus nextStatus = SinkStatus.CONFIG_ING;
+            StreamSinkEntity sinkEntity = sinkMapper.selectByPrimaryKey(id);
+            sinkEntity.setStatus(nextStatus.getCode());
+            sinkMapper.updateStatus(sinkEntity);
+        }
+
+        // If the stream is [CONFIG_SUCCESSFUL], then asynchronously start the [CREATE_STREAM_RESOURCE] process
+        if (streamSuccess && request.getStartProcess()) {
+            this.startProcessForSink(groupId, streamId, operator);
+        }
 
         LOGGER.info("success to save sink info: {}", request);
         return id;
@@ -141,7 +159,7 @@ public class StreamSinkServiceImpl implements StreamSinkService {
     @Override
     public List<StreamSink> listSink(String groupId, String streamId) {
         Preconditions.checkNotNull(groupId, ErrorCodeEnum.GROUP_ID_IS_EMPTY.getMessage());
-        List<StreamSinkEntity> entityList = sinkMapper.selectByRelatedId(groupId, streamId, null);
+        List<StreamSinkEntity> entityList = sinkMapper.selectByRelatedId(groupId, streamId);
         if (CollectionUtils.isEmpty(entityList)) {
             return Collections.emptyList();
         }
@@ -204,7 +222,7 @@ public class StreamSinkServiceImpl implements StreamSinkService {
     @Override
     @Transactional(rollbackFor = Throwable.class)
     public Boolean update(SinkRequest request, String operator) {
-        LOGGER.info("begin to update sink info: {}", request);
+        LOGGER.info("begin to update sink by id: {}", request);
         this.checkParams(request);
         Preconditions.checkNotNull(request.getId(), ErrorCodeEnum.ID_IS_EMPTY.getMessage());
 
@@ -212,42 +230,61 @@ public class StreamSinkServiceImpl implements StreamSinkService {
         String groupId = request.getInlongGroupId();
         String streamId = request.getInlongStreamId();
         String sinkName = request.getSinkName();
-        final InlongGroupEntity groupEntity = groupCheckService.checkGroupStatus(groupId, operator);
+        groupCheckService.checkGroupStatus(groupId, operator);
+
+        // Check whether the stream exist or not
+        InlongStreamEntity streamEntity = streamMapper.selectByIdentifier(groupId, streamId);
+        Preconditions.checkNotNull(streamEntity, ErrorCodeEnum.STREAM_NOT_FOUND.getMessage());
 
         // Check whether the sink name exists with the same groupId and streamId
-        List<StreamSinkEntity> sinkList = sinkMapper.selectByRelatedId(groupId, streamId, sinkName);
-        for (StreamSinkEntity entity : sinkList) {
-            Integer sinkId = entity.getId();
-            if (!Objects.equals(request.getId(), sinkId) && Objects.equals(entity.getSinkName(), sinkName)) {
-                String err = "sink name=%s already exists with the groupId=%s streamId=%s";
-                throw new BusinessException(String.format(err, sinkName, groupId, streamId));
-            }
-        }
-        List<SinkField> fields = request.getSinkFieldList();
-        // Remove id in sinkField when save
-        if (CollectionUtils.isNotEmpty(fields)) {
-            fields.forEach(sinkField -> sinkField.setId(null));
+        StreamSinkEntity existEntity = sinkMapper.selectByUniqueKey(groupId, streamId, sinkName);
+        if (existEntity != null && !existEntity.getId().equals(request.getId())) {
+            String errMsg = "sink name=%s already exists with the groupId=%s streamId=%s";
+            throw new BusinessException(String.format(errMsg, sinkName, groupId, streamId));
         }
 
+        SinkStatus nextStatus = null;
+        boolean streamSuccess = StreamStatus.CONFIG_SUCCESSFUL.getCode().equals(streamEntity.getStatus());
+        if (streamSuccess || StreamStatus.CONFIG_FAILED.getCode().equals(streamEntity.getStatus())) {
+            nextStatus = SinkStatus.CONFIG_ING;
+        }
         StreamSinkOperator sinkOperator = operatorFactory.getInstance(request.getSinkType());
-        sinkOperator.updateOpt(request, operator);
+        sinkOperator.updateOpt(request, nextStatus, operator);
 
-        // The inlong group status is [Configuration successful], then asynchronously initiate
-        // the [Single inlong stream resource creation] workflow
-        if (GroupStatus.CONFIG_SUCCESSFUL.getCode().equals(groupEntity.getStatus())) {
-            // To work around the circular reference check we manually instantiate and wire
-            if (streamProcessOperation == null) {
-                streamProcessOperation = new InlongStreamProcessService();
-                autowireCapableBeanFactory.autowireBean(streamProcessOperation);
-            }
-            streamProcessOperation.startProcess(groupId, streamId, operator, true);
+        // If the stream is [CONFIG_SUCCESSFUL], then asynchronously start the [CREATE_STREAM_RESOURCE] process
+        if (streamSuccess && request.getStartProcess()) {
+            this.startProcessForSink(groupId, streamId, operator);
         }
-        LOGGER.info("success to update sink info: {}", request);
+
+        LOGGER.info("success to update sink by id: {}", request);
         return true;
     }
 
     @Override
-    public void updateStatus(int id, int status, String log) {
+    @Transactional(rollbackFor = Throwable.class)
+    public UpdateResult updateByKey(SinkRequest request, String operator) {
+        LOGGER.info("begin to update sink by key: {}", request);
+
+        // Check whether the stream sink exists
+        String groupId = request.getInlongGroupId();
+        String streamId = request.getInlongStreamId();
+        String sinkName = request.getSinkName();
+        StreamSinkEntity entity = sinkMapper.selectByUniqueKey(groupId, streamId, sinkName);
+        if (entity == null) {
+            String errMsg = String.format("stream sink not found with groupId=%s, streamId=%s, sinkName=%s",
+                    groupId, streamId, sinkName);
+            LOGGER.error(errMsg);
+            throw new BusinessException(errMsg);
+        }
+
+        request.setId(entity.getId());
+        Boolean result = this.update(request, operator);
+        LOGGER.info("success to update sink by key: {}", request);
+        return new UpdateResult(entity.getId(), result, request.getVersion() + 1);
+    }
+
+    @Override
+    public void updateStatus(Integer id, int status, String log) {
         StreamSinkEntity entity = new StreamSinkEntity();
         entity.setId(id);
         entity.setStatus(status);
@@ -257,17 +294,51 @@ public class StreamSinkServiceImpl implements StreamSinkService {
         LOGGER.info("success to update sink status={} for id={} with log: {}", status, id, log);
     }
 
-    @Transactional(rollbackFor = Throwable.class)
     @Override
-    public Boolean delete(Integer id, String operator) {
+    @Transactional(rollbackFor = Throwable.class)
+    public Boolean delete(Integer id, Boolean startProcess, String operator) {
         LOGGER.info("begin to delete sink by id={}", id);
         Preconditions.checkNotNull(id, ErrorCodeEnum.ID_IS_EMPTY.getMessage());
         StreamSinkEntity entity = sinkMapper.selectByPrimaryKey(id);
         Preconditions.checkNotNull(entity, ErrorCodeEnum.SINK_INFO_NOT_FOUND.getMessage());
+
         groupCheckService.checkGroupStatus(entity.getInlongGroupId(), operator);
+
         StreamSinkOperator sinkOperator = operatorFactory.getInstance(entity.getSinkType());
         sinkOperator.deleteOpt(entity, operator);
-        LOGGER.info("success to delete sink info: {}", entity);
+
+        if (startProcess) {
+            this.deleteProcessForSink(entity.getInlongGroupId(), entity.getInlongStreamId(), operator);
+        }
+
+        LOGGER.info("success to delete sink by id: {}", entity);
+        return true;
+    }
+
+    @Override
+    @Transactional(rollbackFor = Throwable.class)
+    public Boolean deleteByKey(String groupId, String streamId, String sinkName,
+            Boolean startProcess, String operator) {
+        LOGGER.info("begin to delete sink by groupId={}, streamId={}, sinkName={}", groupId, streamId, sinkName);
+
+        // Check whether the sink name exists with the same groupId and streamId
+        Preconditions.checkNotNull(groupId, ErrorCodeEnum.GROUP_ID_IS_EMPTY.getMessage());
+        Preconditions.checkNotNull(streamId, ErrorCodeEnum.STREAM_ID_IS_EMPTY.getMessage());
+        Preconditions.checkNotNull(sinkName, "stream sink name is empty or null");
+        StreamSinkEntity entity = sinkMapper.selectByUniqueKey(groupId, streamId, sinkName);
+        Preconditions.checkNotNull(entity, String.format("stream sink not exist by groupId=%s streamId=%s sinkName=%s",
+                groupId, streamId, sinkName));
+
+        groupCheckService.checkGroupStatus(entity.getInlongGroupId(), operator);
+
+        StreamSinkOperator sinkOperator = operatorFactory.getInstance(entity.getSinkType());
+        sinkOperator.deleteOpt(entity, operator);
+
+        if (startProcess) {
+            this.deleteProcessForSink(entity.getInlongGroupId(), entity.getInlongStreamId(), operator);
+        }
+
+        LOGGER.info("success to delete sink by key: {}", entity);
         return true;
     }
 
@@ -281,7 +352,7 @@ public class StreamSinkServiceImpl implements StreamSinkService {
         // Check if it can be deleted
         groupCheckService.checkGroupStatus(groupId, operator);
 
-        List<StreamSinkEntity> entityList = sinkMapper.selectByRelatedId(groupId, streamId, null);
+        List<StreamSinkEntity> entityList = sinkMapper.selectByRelatedId(groupId, streamId);
         if (CollectionUtils.isNotEmpty(entityList)) {
             entityList.forEach(entity -> {
                 Integer id = entity.getId();
@@ -289,7 +360,7 @@ public class StreamSinkServiceImpl implements StreamSinkService {
                 entity.setStatus(InlongConstants.DELETED_STATUS);
                 entity.setIsDeleted(id);
                 entity.setModifier(operator);
-                int rowCount = sinkMapper.updateByPrimaryKeySelective(entity);
+                int rowCount = sinkMapper.updateByIdSelective(entity);
                 if (rowCount != InlongConstants.AFFECTED_ONE_ROW) {
                     LOGGER.error("sink has already updated with groupId={}, streamId={}, name={}, curVersion={}",
                             entity.getInlongGroupId(), entity.getInlongStreamId(), entity.getSinkName(),
@@ -314,10 +385,10 @@ public class StreamSinkServiceImpl implements StreamSinkService {
         // Check if it can be deleted
         groupCheckService.checkGroupStatus(groupId, operator);
 
-        List<StreamSinkEntity> entityList = sinkMapper.selectByRelatedId(groupId, streamId, null);
+        List<StreamSinkEntity> entityList = sinkMapper.selectByRelatedId(groupId, streamId);
         if (CollectionUtils.isNotEmpty(entityList)) {
             entityList.forEach(entity -> {
-                sinkMapper.deleteByPrimaryKey(entity.getId());
+                sinkMapper.deleteById(entity.getId());
                 sinkFieldMapper.deleteAll(entity.getId());
             });
         }
@@ -367,7 +438,7 @@ public class StreamSinkServiceImpl implements StreamSinkService {
             entity.setPreviousStatus(entity.getStatus());
             entity.setStatus(status);
             entity.setModifier(operator);
-            int rowCount = sinkMapper.updateByPrimaryKeySelective(entity);
+            int rowCount = sinkMapper.updateByIdSelective(entity);
             if (rowCount != InlongConstants.AFFECTED_ONE_ROW) {
                 LOGGER.error("sink has already updated with groupId={}, streamId={}, name={}, curVersion={}",
                         entity.getInlongGroupId(), entity.getInlongStreamId(), entity.getSinkName(),
@@ -391,4 +462,26 @@ public class StreamSinkServiceImpl implements StreamSinkService {
         String sinkName = request.getSinkName();
         Preconditions.checkNotNull(sinkName, ErrorCodeEnum.SINK_NAME_IS_NULL.getMessage());
     }
+
+    private void startProcessForSink(String groupId, String streamId, String operator) {
+        // to work around the circular reference check, manually instantiate and wire
+        if (streamProcessOperation == null) {
+            streamProcessOperation = new InlongStreamProcessService();
+            autowireCapableBeanFactory.autowireBean(streamProcessOperation);
+        }
+
+        streamProcessOperation.startProcess(groupId, streamId, operator, false);
+        LOGGER.info("success to start the start-stream-process for groupId={} streamId={}", groupId, streamId);
+    }
+
+    private void deleteProcessForSink(String groupId, String streamId, String operator) {
+        // to work around the circular reference check, manually instantiate and wire
+        if (streamProcessOperation == null) {
+            streamProcessOperation = new InlongStreamProcessService();
+            autowireCapableBeanFactory.autowireBean(streamProcessOperation);
+        }
+
+        streamProcessOperation.deleteProcess(groupId, streamId, operator, false);
+        LOGGER.info("success to start the delete-stream-process for groupId={} streamId={}", groupId, streamId);
+    }
 }
