@@ -21,14 +21,17 @@ import com.github.pagehelper.Page;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.inlong.manager.common.consts.InlongConstants;
+import org.apache.inlong.manager.common.consts.SourceType;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.enums.GroupStatus;
 import org.apache.inlong.manager.common.enums.SourceStatus;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.common.util.CommonBeanUtils;
 import org.apache.inlong.manager.common.util.Preconditions;
+import org.apache.inlong.manager.dao.entity.InlongStreamFieldEntity;
 import org.apache.inlong.manager.dao.entity.StreamSourceEntity;
 import org.apache.inlong.manager.dao.entity.StreamSourceFieldEntity;
+import org.apache.inlong.manager.dao.mapper.InlongStreamFieldEntityMapper;
 import org.apache.inlong.manager.dao.mapper.StreamSourceEntityMapper;
 import org.apache.inlong.manager.dao.mapper.StreamSourceFieldEntityMapper;
 import org.apache.inlong.manager.pojo.common.PageResult;
@@ -57,6 +60,8 @@ public abstract class AbstractSourceOperator implements StreamSourceOperator {
     protected StreamSourceEntityMapper sourceMapper;
     @Autowired
     protected StreamSourceFieldEntityMapper sourceFieldMapper;
+    @Autowired
+    protected InlongStreamFieldEntityMapper streamFieldMapper;
 
     /**
      * Getting the source type.
@@ -77,7 +82,10 @@ public abstract class AbstractSourceOperator implements StreamSourceOperator {
     @Transactional(rollbackFor = Throwable.class)
     public Integer saveOpt(SourceRequest request, Integer groupStatus, String operator) {
         StreamSourceEntity entity = CommonBeanUtils.copyProperties(request, StreamSourceEntity::new);
-        if (GroupStatus.forCode(groupStatus).equals(GroupStatus.CONFIG_SUCCESSFUL)) {
+        if (SourceType.AUTO_PUSH.equals(request.getSourceType())) {
+            // auto push task needs not be issued to agent
+            entity.setStatus(SourceStatus.SOURCE_NORMAL.getCode());
+        } else if (GroupStatus.forCode(groupStatus).equals(GroupStatus.CONFIG_SUCCESSFUL)) {
             entity.setStatus(SourceStatus.TO_BE_ISSUED_ADD.getCode());
         } else {
             entity.setStatus(SourceStatus.SOURCE_NEW.getCode());
@@ -112,10 +120,18 @@ public abstract class AbstractSourceOperator implements StreamSourceOperator {
 
     @Override
     @Transactional(rollbackFor = Throwable.class, isolation = Isolation.REPEATABLE_READ)
-    public void updateOpt(SourceRequest request, Integer groupStatus, String operator) {
+    public void updateOpt(SourceRequest request, Integer groupStatus, Integer groupMode, String operator) {
         StreamSourceEntity entity = sourceMapper.selectByIdForUpdate(request.getId());
         Preconditions.checkNotNull(entity, ErrorCodeEnum.SOURCE_INFO_NOT_FOUND.getMessage());
-        if (!SourceStatus.ALLOWED_UPDATE.contains(entity.getStatus())) {
+
+        if (SourceType.AUTO_PUSH.equals(entity.getSourceType())) {
+            updateFieldOpt(entity, request.getFieldList());
+            return;
+        }
+
+        boolean allowUpdate = InlongConstants.LIGHTWEIGHT_MODE.equals(groupMode)
+                || SourceStatus.ALLOWED_UPDATE.contains(entity.getStatus());
+        if (!allowUpdate) {
             throw new BusinessException(String.format("source=%s is not allowed to update, "
                     + "please wait until its changed to final status or stop / frozen / delete it firstly", entity));
         }
@@ -126,7 +142,7 @@ public abstract class AbstractSourceOperator implements StreamSourceOperator {
             throw new BusinessException(ErrorCodeEnum.CONFIG_EXPIRED);
         }
 
-        // Source type cannot be changed
+        // source type cannot be changed
         if (!Objects.equals(entity.getSourceType(), request.getSourceType())) {
             throw new BusinessException(String.format("source type=%s cannot change to %s",
                     entity.getSourceType(), request.getSourceType()));
@@ -144,27 +160,31 @@ public abstract class AbstractSourceOperator implements StreamSourceOperator {
             }
         }
 
-        // Setting updated parameters of stream source entity.
+        // setting updated parameters of stream source entity.
         setTargetEntity(request, entity);
         entity.setModifier(operator);
 
-        // Re-issue task if necessary
         entity.setPreviousStatus(entity.getStatus());
-        if (GroupStatus.forCode(groupStatus).equals(GroupStatus.CONFIG_SUCCESSFUL)) {
-            entity.setStatus(SourceStatus.TO_BE_ISSUED_ADD.getCode());
-        } else {
-            switch (SourceStatus.forCode(entity.getStatus())) {
-                case SOURCE_NORMAL:
-                    entity.setStatus(SourceStatus.TO_BE_ISSUED_ADD.getCode());
-                    break;
-                case SOURCE_FAILED:
-                    entity.setStatus(SourceStatus.SOURCE_NEW.getCode());
-                    break;
-                default:
-                    // others leave it be
-                    break;
+
+        // re-issue task if necessary
+        if (InlongConstants.STANDARD_MODE.equals(groupMode)) {
+            if (GroupStatus.forCode(groupStatus).equals(GroupStatus.CONFIG_SUCCESSFUL)) {
+                entity.setStatus(SourceStatus.TO_BE_ISSUED_ADD.getCode());
+            } else {
+                switch (SourceStatus.forCode(entity.getStatus())) {
+                    case SOURCE_NORMAL:
+                        entity.setStatus(SourceStatus.TO_BE_ISSUED_ADD.getCode());
+                        break;
+                    case SOURCE_FAILED:
+                        entity.setStatus(SourceStatus.SOURCE_NEW.getCode());
+                        break;
+                    default:
+                        // others leave it be
+                        break;
+                }
             }
         }
+
         int rowCount = sourceMapper.updateByPrimaryKeySelective(entity);
         if (rowCount != InlongConstants.AFFECTED_ONE_ROW) {
             LOGGER.warn(errMsg);
@@ -216,21 +236,41 @@ public abstract class AbstractSourceOperator implements StreamSourceOperator {
         }
     }
 
-    private void updateFieldOpt(StreamSourceEntity entity, List<StreamField> fieldInfos) {
+    protected void updateFieldOpt(StreamSourceEntity entity, List<StreamField> fieldInfos) {
         Integer sourceId = entity.getId();
         if (CollectionUtils.isEmpty(fieldInfos)) {
             return;
         }
 
-        // First physically delete the existing fields
+        // Stream source fields
         sourceFieldMapper.deleteAll(sourceId);
-        // Then batch save the source fields
         this.saveFieldOpt(entity, fieldInfos);
 
+        // InLong stream fields
+        String groupId = entity.getInlongGroupId();
+        String streamId = entity.getInlongStreamId();
+        streamFieldMapper.deleteAllByIdentifier(groupId, streamId);
+        saveStreamField(groupId, streamId, fieldInfos);
+
         LOGGER.info("success to update source fields");
     }
 
-    private void saveFieldOpt(StreamSourceEntity entity, List<StreamField> fieldInfos) {
+    protected void saveStreamField(String groupId, String streamId, List<StreamField> infoList) {
+        if (CollectionUtils.isEmpty(infoList)) {
+            return;
+        }
+        infoList.forEach(streamField -> streamField.setId(null));
+        List<InlongStreamFieldEntity> list = CommonBeanUtils.copyListProperties(infoList,
+                InlongStreamFieldEntity::new);
+        for (InlongStreamFieldEntity entity : list) {
+            entity.setInlongGroupId(groupId);
+            entity.setInlongStreamId(streamId);
+            entity.setIsDeleted(InlongConstants.UN_DELETED);
+        }
+        streamFieldMapper.insertAll(list);
+    }
+
+    protected void saveFieldOpt(StreamSourceEntity entity, List<StreamField> fieldInfos) {
         LOGGER.info("begin to save source fields={}", fieldInfos);
         if (CollectionUtils.isEmpty(fieldInfos)) {
             return;
