@@ -19,6 +19,7 @@ package org.apache.inlong.manager.web.controller;
 
 import io.swagger.annotations.Api;
 import io.swagger.annotations.ApiImplicitParam;
+import io.swagger.annotations.ApiImplicitParams;
 import io.swagger.annotations.ApiOperation;
 import org.apache.inlong.manager.common.enums.OperationType;
 import org.apache.inlong.manager.common.validation.UpdateValidation;
@@ -33,6 +34,7 @@ import org.apache.inlong.manager.pojo.cluster.ClusterTagRequest;
 import org.apache.inlong.manager.pojo.cluster.ClusterTagResponse;
 import org.apache.inlong.manager.pojo.common.PageResult;
 import org.apache.inlong.manager.pojo.common.Response;
+import org.apache.inlong.manager.pojo.common.UpdateResult;
 import org.apache.inlong.manager.pojo.user.UserRoleCode;
 import org.apache.inlong.manager.service.cluster.InlongClusterService;
 import org.apache.inlong.manager.service.operationlog.OperationLog;
@@ -47,8 +49,11 @@ import org.springframework.web.bind.annotation.PostMapping;
 import org.springframework.web.bind.annotation.RequestBody;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.RequestMethod;
+import org.springframework.web.bind.annotation.RequestParam;
 import org.springframework.web.bind.annotation.RestController;
 
+import java.util.List;
+
 /**
  * Inlong cluster controller
  */
@@ -132,6 +137,14 @@ public class InlongClusterController {
         return Response.success(clusterService.update(request, username));
     }
 
+    @PostMapping(value = "/cluster/updateByKey")
+    @OperationLog(operation = OperationType.UPDATE)
+    @ApiOperation(value = "Update cluster by key")
+    public Response<UpdateResult> updateByKey(@RequestBody ClusterRequest request) {
+        String username = LoginUserUtils.getLoginUser().getName();
+        return Response.success(clusterService.updateByKey(request, username));
+    }
+
     @PostMapping(value = "/cluster/bindTag")
     @OperationLog(operation = OperationType.UPDATE)
     @ApiOperation(value = "Bind or unbind cluster tag")
@@ -149,6 +162,19 @@ public class InlongClusterController {
         return Response.success(clusterService.delete(id, LoginUserUtils.getLoginUser().getName()));
     }
 
+    @DeleteMapping(value = "/cluster/deleteByKey")
+    @ApiOperation(value = "Delete cluster by cluster name and type")
+    @OperationLog(operation = OperationType.DELETE)
+    @ApiImplicitParams({
+            @ApiImplicitParam(name = "name", value = "Cluster name", dataTypeClass = String.class, required = true),
+            @ApiImplicitParam(name = "type", value = "Cluster type", dataTypeClass = String.class, required = true),
+    })
+    @RequiresRoles(value = UserRoleCode.ADMIN)
+    public Response<Boolean> deleteByKey(@RequestParam String name, @RequestParam String type) {
+        return Response.success(clusterService.deleteByKey(name, type,
+                LoginUserUtils.getLoginUser().getName()));
+    }
+
     @PostMapping(value = "/cluster/node/save")
     @ApiOperation(value = "Save cluster node")
     @OperationLog(operation = OperationType.CREATE)
@@ -166,12 +192,25 @@ public class InlongClusterController {
     }
 
     @PostMapping(value = "/cluster/node/list")
-    @ApiOperation(value = "List cluster nodes")
+    @ApiOperation(value = "List cluster nodes by pagination")
     public Response<PageResult<ClusterNodeResponse>> listNode(@RequestBody ClusterPageRequest request) {
         String currentUser = LoginUserUtils.getLoginUser().getName();
         return Response.success(clusterService.listNode(request, currentUser));
     }
 
+    @GetMapping(value = "/cluster/node/listByGroupId")
+    @ApiOperation(value = "List cluster nodes by groupId, clusterType and protocolType")
+    @ApiImplicitParams({
+            @ApiImplicitParam(name = "inlongGroupId", dataTypeClass = String.class, required = true),
+            @ApiImplicitParam(name = "clusterType", dataTypeClass = String.class, required = true),
+            @ApiImplicitParam(name = "protocolType", dataTypeClass = String.class, required = false)
+    })
+    @OperationLog(operation = OperationType.GET)
+    public Response<List<ClusterNodeResponse>> listByGroupId(@RequestParam String inlongGroupId,
+            @RequestParam String clusterType, @RequestParam(required = false) String protocolType) {
+        return Response.success(clusterService.listNodeByGroupId(inlongGroupId, clusterType, protocolType));
+    }
+
     @RequestMapping(value = "/cluster/node/update", method = RequestMethod.POST)
     @OperationLog(operation = OperationType.UPDATE)
     @ApiOperation(value = "Update cluster node")
