@@ -19,11 +19,13 @@ package org.apache.inlong.manager.web.controller;
 
 import io.swagger.annotations.Api;
 import io.swagger.annotations.ApiImplicitParam;
+import io.swagger.annotations.ApiImplicitParams;
 import io.swagger.annotations.ApiOperation;
 import org.apache.inlong.manager.common.enums.OperationType;
 import org.apache.inlong.manager.common.validation.UpdateValidation;
 import org.apache.inlong.manager.pojo.common.PageResult;
 import org.apache.inlong.manager.pojo.common.Response;
+import org.apache.inlong.manager.pojo.common.UpdateResult;
 import org.apache.inlong.manager.pojo.sink.SinkPageRequest;
 import org.apache.inlong.manager.pojo.sink.SinkRequest;
 import org.apache.inlong.manager.pojo.sink.StreamSink;
@@ -36,6 +38,7 @@ import org.springframework.web.bind.annotation.PathVariable;
 import org.springframework.web.bind.annotation.RequestBody;
 import org.springframework.web.bind.annotation.RequestMapping;
 import org.springframework.web.bind.annotation.RequestMethod;
+import org.springframework.web.bind.annotation.RequestParam;
 import org.springframework.web.bind.annotation.RestController;
 
 /**
@@ -64,7 +67,7 @@ public class StreamSinkController {
     }
 
     @RequestMapping(value = "/sink/list", method = RequestMethod.GET)
-    @ApiOperation(value = "Get stream sink list by paginating")
+    @ApiOperation(value = "List stream sinks by paginating")
     public Response<PageResult<? extends StreamSink>> listByCondition(SinkPageRequest request) {
         return Response.success(sinkService.listByCondition(request));
     }
@@ -76,13 +79,38 @@ public class StreamSinkController {
         return Response.success(sinkService.update(request, LoginUserUtils.getLoginUser().getName()));
     }
 
+    @RequestMapping(value = "/sink/updateByKey", method = RequestMethod.POST)
+    @OperationLog(operation = OperationType.UPDATE)
+    @ApiOperation(value = "Update stream sink by key")
+    public Response<UpdateResult> updateByKey(@RequestBody SinkRequest request) {
+        return Response.success(sinkService.updateByKey(request, LoginUserUtils.getLoginUser().getName()));
+    }
+
     @RequestMapping(value = "/sink/delete/{id}", method = RequestMethod.DELETE)
     @OperationLog(operation = OperationType.DELETE)
     @ApiOperation(value = "Delete stream sink")
-    @ApiImplicitParam(name = "id", dataTypeClass = Integer.class, required = true)
-    public Response<Boolean> delete(@PathVariable Integer id) {
-        boolean result = sinkService.delete(id, LoginUserUtils.getLoginUser().getName());
-        return Response.success(result);
+    @ApiImplicitParams({
+            @ApiImplicitParam(name = "startProcess", dataTypeClass = boolean.class),
+            @ApiImplicitParam(name = "id", dataTypeClass = Integer.class, required = true)
+    })
+    public Response<Boolean> delete(@PathVariable Integer id,
+            @RequestParam(required = false, defaultValue = "false") boolean startProcess) {
+        return Response.success(sinkService.delete(id, startProcess, LoginUserUtils.getLoginUser().getName()));
+    }
+
+    @RequestMapping(value = "/sink/deleteByKey", method = RequestMethod.DELETE)
+    @OperationLog(operation = OperationType.DELETE)
+    @ApiOperation(value = "Delete stream sink by key")
+    @ApiImplicitParams({
+            @ApiImplicitParam(name = "startProcess", dataTypeClass = boolean.class),
+            @ApiImplicitParam(name = "groupId", dataTypeClass = String.class, required = true),
+            @ApiImplicitParam(name = "streamId", dataTypeClass = String.class, required = true),
+            @ApiImplicitParam(name = "name", dataTypeClass = String.class, required = true)
+    })
+    public Response<Boolean> deleteByKey(@RequestParam(required = false, defaultValue = "false") boolean startProcess,
+            @RequestParam String groupId, @RequestParam String streamId, @RequestParam String name) {
+        String username = LoginUserUtils.getLoginUser().getName();
+        return Response.success(sinkService.deleteByKey(groupId, streamId, name, startProcess, username));
     }
 
 }
