@@ -52,6 +52,7 @@ public class ProxyClientConfig {
     private int maxTimeoutCnt = ConfigConstants.MAX_TIMEOUT_CNT;
     private String authSecretId;
     private String authSecretKey;
+    private String protocolType;
 
     private boolean enableSaveManagerVIps = true;
 
@@ -88,17 +89,22 @@ public class ProxyClientConfig {
     private int metricIntervalInMs = 60 * 1000;
     // max cache time for proxy config.
     private long maxProxyCacheTimeInMs = 30 * 60 * 1000;
-
     // metric groupId
     private String metricGroupId = "inlong_sla_metric";
 
     private int ioThreadNum = Runtime.getRuntime().availableProcessors();
     private boolean enableBusyWait = false;
 
+    private int virtualNode;
+
+    private LoadBalance loadBalance;
+
+    private int maxRetry;
+
     /*pay attention to the last url parameter ip*/
     public ProxyClientConfig(String localHost, boolean isLocalVisit, String managerIp,
-            int managerPort, String groupId, String netTag, String authSecretId, String authSecretKey)
-            throws ProxysdkException {
+            int managerPort, String groupId, String netTag, String authSecretId, String authSecretKey,
+            LoadBalance loadBalance, int virtualNode, int maxRetry) throws ProxysdkException {
         if (Utils.isBlank(localHost)) {
             throw new ProxysdkException("localHost is blank!");
         }
@@ -123,9 +129,19 @@ public class ProxyClientConfig {
         this.proxyHttpUpdateIntervalMinutes = ConfigConstants.PROXY_HTTP_UPDATE_INTERVAL_MINUTES;
         this.proxyUpdateMaxRetry = ConfigConstants.PROXY_UPDATE_MAX_RETRY;
         this.connectTimeoutMillis = ConfigConstants.DEFAULT_CONNECT_TIMEOUT_MILLIS;
-        this.setRequestTimeoutMillis(ConfigConstants.DEFAULT_SEND_BUFFER_SIZE);
+        this.setRequestTimeoutMillis(ConfigConstants.DEFAULT_REQUEST_TIMEOUT_MILLIS);
         this.authSecretId = authSecretId;
         this.authSecretKey = authSecretKey;
+        this.loadBalance = loadBalance;
+        this.virtualNode = virtualNode;
+        this.maxRetry = maxRetry;
+    }
+
+    public ProxyClientConfig(String localHost, boolean isLocalVisit, String managerIp, int managerPort, String groupId,
+            String netTag, String authSecretId, String authSecretKey) throws ProxysdkException {
+        this(localHost, isLocalVisit, managerIp, managerPort, groupId, netTag, authSecretId, authSecretKey,
+                ConfigConstants.DEFAULT_LOAD_BALANCE, ConfigConstants.DEFAULT_VIRTUAL_NODE,
+                ConfigConstants.DEFAULT_RANDOM_MAX_RETRY);
     }
 
     public String getTlsServerCertFilePathAndName() {
@@ -459,4 +475,28 @@ public class ProxyClientConfig {
     public void setEnableBusyWait(boolean enableBusyWait) {
         this.enableBusyWait = enableBusyWait;
     }
+
+    public int getVirtualNode() {
+        return virtualNode;
+    }
+
+    public void setVirtualNode(int virtualNode) {
+        this.virtualNode = virtualNode;
+    }
+
+    public LoadBalance getLoadBalance() {
+        return loadBalance;
+    }
+
+    public void setLoadBalance(LoadBalance loadBalance) {
+        this.loadBalance = loadBalance;
+    }
+
+    public int getMaxRetry() {
+        return maxRetry;
+    }
+
+    public void setMaxRetry(int maxRetry) {
+        this.maxRetry = maxRetry;
+    }
 }
