@@ -18,6 +18,7 @@
 
 package org.apache.inlong.sdk.dataproxy.utils;
 
+import org.apache.commons.collections.MapUtils;
 import org.apache.inlong.sdk.dataproxy.ProxyClientConfig;
 import org.apache.inlong.sdk.dataproxy.network.Utils;
 import org.slf4j.Logger;
@@ -38,7 +39,8 @@ public class ProxyUtils {
     static {
         Collections.addAll(invalidAttr, "groupId", "streamId", "dt", "msgUUID", "cp",
                 "cnt", "mt", "m", "sid", "t", "NodeIP", "messageId", "_file_status_check", "_secretId",
-                "_signature", "_timeStamp", "_nonce", "_userName", "_clientIP", "_encyVersion", "_encyAesKey");
+                "_signature", "_timeStamp", "_nonce", "_userName", "_clientIP", "_encyVersion", "_encyAesKey",
+                "proxySend", "errMsg", "errCode");
     }
 
     public static boolean isAttrKeysValid(Map<String, String> attrsMap) {
@@ -99,6 +101,9 @@ public class ProxyUtils {
 
     public static StringBuilder convertAttrToStr(Map<String, String> extraAttrMap) {
         StringBuilder attrs = new StringBuilder();
+        if (MapUtils.isEmpty(extraAttrMap)) {
+            return attrs;
+        }
         for (Map.Entry<String, String> entry : extraAttrMap.entrySet()) {
             String key = entry.getKey();
             String value = entry.getValue();
