@@ -22,6 +22,8 @@ import lombok.Data;
 import lombok.EqualsAndHashCode;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonCreator;
+import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonInclude;
+import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonInclude.Include;
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonProperty;
 import org.apache.flink.shaded.jackson2.com.fasterxml.jackson.annotation.JsonTypeName;
 import org.apache.inlong.common.enums.MetaField;
@@ -37,6 +39,7 @@ import org.apache.inlong.sort.protocol.node.format.CsvFormat;
 import org.apache.inlong.sort.protocol.node.format.DebeziumJsonFormat;
 import org.apache.inlong.sort.protocol.node.format.Format;
 import org.apache.inlong.sort.protocol.node.format.JsonFormat;
+import org.apache.inlong.sort.protocol.node.format.RawFormat;
 import org.apache.inlong.sort.protocol.transformation.WatermarkField;
 
 import javax.annotation.Nonnull;
@@ -52,6 +55,7 @@ import java.util.Set;
  */
 @EqualsAndHashCode(callSuper = true)
 @JsonTypeName("kafkaExtract")
+@JsonInclude(Include.NON_NULL)
 @Data
 public class KafkaExtractNode extends ExtractNode implements InlongMetric, Metadata, Serializable {
 
@@ -79,6 +83,24 @@ public class KafkaExtractNode extends ExtractNode implements InlongMetric, Metad
     @JsonProperty("scanSpecificOffsets")
     private String scanSpecificOffsets;
 
+    @JsonProperty("scanTimestampMillis")
+    private String scanTimestampMillis;
+
+    public KafkaExtractNode(@JsonProperty("id") String id,
+            @JsonProperty("name") String name,
+            @JsonProperty("fields") List<FieldInfo> fields,
+            @Nullable @JsonProperty("watermarkField") WatermarkField watermarkField,
+            @JsonProperty("properties") Map<String, String> properties,
+            @Nonnull @JsonProperty("topic") String topic,
+            @Nonnull @JsonProperty("bootstrapServers") String bootstrapServers,
+            @Nonnull @JsonProperty("format") Format format,
+            @JsonProperty("scanStartupMode") KafkaScanStartupMode kafkaScanStartupMode,
+            @JsonProperty("primaryKey") String primaryKey,
+            @JsonProperty("groupId") String groupId) {
+        this(id, name, fields, watermarkField, properties, topic, bootstrapServers, format, kafkaScanStartupMode,
+                primaryKey, groupId, null, null);
+    }
+
     @JsonCreator
     public KafkaExtractNode(@JsonProperty("id") String id,
             @JsonProperty("name") String name,
@@ -91,7 +113,8 @@ public class KafkaExtractNode extends ExtractNode implements InlongMetric, Metad
             @JsonProperty("scanStartupMode") KafkaScanStartupMode kafkaScanStartupMode,
             @JsonProperty("primaryKey") String primaryKey,
             @JsonProperty("groupId") String groupId,
-            @JsonProperty("scanSpecificOffsets") String scanSpecificOffsets) {
+            @JsonProperty("scanSpecificOffsets") String scanSpecificOffsets,
+            @JsonProperty("scanTimestampMillis") String scanTimestampMillis) {
         super(id, name, fields, watermarkField, properties);
         this.topic = Preconditions.checkNotNull(topic, "kafka topic is empty");
         this.bootstrapServers = Preconditions.checkNotNull(bootstrapServers, "kafka bootstrapServers is empty");
@@ -103,6 +126,10 @@ public class KafkaExtractNode extends ExtractNode implements InlongMetric, Metad
             Preconditions.checkArgument(StringUtils.isNotEmpty(scanSpecificOffsets), "scanSpecificOffsets is empty");
             this.scanSpecificOffsets = scanSpecificOffsets;
         }
+        if (KafkaScanStartupMode.TIMESTAMP_MILLIS == kafkaScanStartupMode) {
+            Preconditions.checkArgument(StringUtils.isNotBlank(scanTimestampMillis), "scanTimestampMillis is empty");
+            this.scanTimestampMillis = scanTimestampMillis;
+        }
     }
 
     /**
@@ -122,15 +149,24 @@ public class KafkaExtractNode extends ExtractNode implements InlongMetric, Metad
                 if (StringUtils.isNotEmpty(scanSpecificOffsets)) {
                     options.put(KafkaConstant.SCAN_STARTUP_SPECIFIC_OFFSETS, scanSpecificOffsets);
                 }
+                if (StringUtils.isNotBlank(scanTimestampMillis)) {
+                    options.put(KafkaConstant.SCAN_STARTUP_TIMESTAMP_MILLIS, scanTimestampMillis);
+                }
                 options.putAll(format.generateOptions(false));
             } else {
                 options.put(KafkaConstant.CONNECTOR, KafkaConstant.UPSERT_KAFKA);
                 options.putAll(format.generateOptions(true));
             }
-        } else if (format instanceof CanalJsonFormat || format instanceof DebeziumJsonFormat) {
+        } else if (format instanceof CanalJsonFormat || format instanceof DebeziumJsonFormat
+                || format instanceof RawFormat) {
             options.put(KafkaConstant.CONNECTOR, KafkaConstant.KAFKA);
             options.put(KafkaConstant.SCAN_STARTUP_MODE, kafkaScanStartupMode.getValue());
-            options.put(KafkaConstant.SCAN_STARTUP_SPECIFIC_OFFSETS, scanSpecificOffsets);
+            if (StringUtils.isNotEmpty(scanSpecificOffsets)) {
+                options.put(KafkaConstant.SCAN_STARTUP_SPECIFIC_OFFSETS, scanSpecificOffsets);
+            }
+            if (StringUtils.isNotBlank(scanTimestampMillis)) {
+                options.put(KafkaConstant.SCAN_STARTUP_TIMESTAMP_MILLIS, scanTimestampMillis);
+            }
             options.putAll(format.generateOptions(false));
         } else {
             throw new IllegalArgumentException("kafka extract node format is IllegalArgument");
