@@ -40,9 +40,10 @@ import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
 import org.apache.iceberg.SerializableTable;
 import org.apache.iceberg.Table;
+import org.apache.iceberg.catalog.TableIdentifier;
+import org.apache.iceberg.flink.CatalogLoader;
 import org.apache.iceberg.flink.FlinkSchemaUtil;
 import org.apache.iceberg.flink.TableLoader;
-import org.apache.iceberg.flink.sink.RowDataTaskWriterFactory;
 import org.apache.iceberg.flink.sink.TaskWriterFactory;
 import org.apache.iceberg.flink.util.FlinkCompatibilityUtil;
 import org.apache.iceberg.io.WriteResult;
@@ -50,6 +51,15 @@ import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.types.TypeUtil;
 import org.apache.iceberg.util.PropertyUtil;
+import org.apache.inlong.sort.base.sink.MultipleSinkOption;
+import org.apache.inlong.sort.iceberg.sink.multiple.IcebergMultipleFilesCommiter;
+import org.apache.inlong.sort.iceberg.sink.multiple.IcebergMultipleStreamWriter;
+import org.apache.inlong.sort.iceberg.sink.multiple.IcebergProcessOperator;
+import org.apache.inlong.sort.iceberg.sink.multiple.IcebergSingleFileCommiter;
+import org.apache.inlong.sort.iceberg.sink.multiple.IcebergSingleStreamWriter;
+import org.apache.inlong.sort.iceberg.sink.multiple.MultipleWriteResult;
+import org.apache.inlong.sort.iceberg.sink.multiple.RecordWithSchema;
+import org.apache.inlong.sort.iceberg.sink.multiple.DynamicSchemaHandleOperator;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -69,11 +79,22 @@ import static org.apache.iceberg.TableProperties.WRITE_DISTRIBUTION_MODE_NONE;
 import static org.apache.iceberg.TableProperties.WRITE_TARGET_FILE_SIZE_BYTES;
 import static org.apache.iceberg.TableProperties.WRITE_TARGET_FILE_SIZE_BYTES_DEFAULT;
 
+/**
+ * Copy from iceberg-flink:iceberg-flink-1.13:0.13.2
+ * Add an option `sink.ignore.changelog` to support insert-only mode without primaryKey.
+ * Add option `inlong.metric` and `metrics.audit.proxy.hosts` to support collect inlong metrics and audit.
+ */
 public class FlinkSink {
     private static final Logger LOG = LoggerFactory.getLogger(FlinkSink.class);
 
-    private static final String ICEBERG_STREAM_WRITER_NAME = IcebergStreamWriter.class.getSimpleName();
-    private static final String ICEBERG_FILES_COMMITTER_NAME = IcebergFilesCommitter.class.getSimpleName();
+    private static final String ICEBERG_STREAM_WRITER_NAME = IcebergSingleStreamWriter.class.getSimpleName();
+    private static final String ICEBERG_FILES_COMMITTER_NAME = IcebergSingleFileCommiter.class.getSimpleName();
+    private static final String ICEBERG_MULTIPLE_STREAM_WRITER_NAME =
+            IcebergMultipleStreamWriter.class.getSimpleName();
+    private static final String ICEBERG_MULTIPLE_FILES_COMMITTER_NAME =
+            IcebergMultipleFilesCommiter.class.getSimpleName();
+    private static final String ICEBERG_WHOLE_DATABASE_MIGRATION_NAME =
+            DynamicSchemaHandleOperator.class.getSimpleName();
 
     private FlinkSink() {
     }
@@ -129,13 +150,17 @@ public class FlinkSink {
         private Table table;
         private TableSchema tableSchema;
         private boolean overwrite = false;
+        private boolean appendMode = false;
         private DistributionMode distributionMode = null;
         private Integer writeParallelism = null;
         private boolean upsert = false;
         private List<String> equalityFieldColumns = null;
         private String uidPrefix = null;
-        private String inLongMetric = null;
+        private String inlongMetric = null;
         private String auditHostAndPorts = null;
+        private CatalogLoader catalogLoader = null;
+        private boolean multipleSink = false;
+        private MultipleSinkOption multipleSinkOption = null;
 
         private Builder() {
         }
@@ -161,9 +186,9 @@ public class FlinkSink {
         }
 
         /**
-         * This iceberg {@link Table} instance is used for initializing {@link IcebergStreamWriter} which will write all
-         * the records into {@link DataFile}s and emit them to downstream operator. Providing a table would avoid so
-         * many table loading from each separate task.
+         * This iceberg {@link Table} instance is used for initializing {@link IcebergSingleStreamWriter} which will
+         * write all the records into {@link DataFile}s and emit them to downstream operator. Providing a table would \
+         * avoid so many table loading from each separate task.
          *
          * @param newTable the loaded iceberg table instance.
          * @return {@link Builder} to connect the iceberg table.
@@ -174,7 +199,7 @@ public class FlinkSink {
         }
 
         /**
-         * The table loader is used for loading tables in {@link IcebergFilesCommitter} lazily, we need this loader
+         * The table loader is used for loading tables in {@link IcebergSingleFileCommiter} lazily, we need this loader
          * because {@link Table} is not serializable and could not just use the loaded table from Builder#table in the
          * remote task manager.
          *
@@ -191,19 +216,53 @@ public class FlinkSink {
             return this;
         }
 
+        /**
+         * The catalog loader is used for loading tables in {@link IcebergMultipleStreamWriter} and
+         * {@link DynamicSchemaHandleOperator} lazily, we need this loader because in multiple sink scene which table
+         * to load is determined in runtime, so we should hold a {@link org.apache.iceberg.catalog.Catalog} at runtime.
+         *
+         * @param catalogLoader to load iceberg catalog inside tasks.
+         * @return {@link Builder} to connect the iceberg table.
+         */
+        public Builder catalogLoader(CatalogLoader catalogLoader) {
+            this.catalogLoader = catalogLoader;
+            return this;
+        }
+
+        public Builder multipleSink(boolean multipleSink) {
+            this.multipleSink = multipleSink;
+            return this;
+        }
+
+        public Builder multipleSinkOption(MultipleSinkOption multipleSinkOption) {
+            this.multipleSinkOption = multipleSinkOption;
+            return this;
+        }
+
         public Builder overwrite(boolean newOverwrite) {
             this.overwrite = newOverwrite;
             return this;
         }
 
+        /**
+         * The appendMode properties is used to insert data without equality field columns.
+         *
+         * @param appendMode append mode properties.
+         * @return {@link FlinkSink.Builder} to connect the iceberg table.
+         */
+        public FlinkSink.Builder appendMode(boolean appendMode) {
+            this.appendMode = appendMode;
+            return this;
+        }
+
         /**
          * Add metric output for iceberg writer
-         * @param inLongMetric
+         * @param inlongMetric
          * @param auditHostAndPorts
          * @return
          */
-        public Builder metric(String inLongMetric, String auditHostAndPorts) {
-            this.inLongMetric = inLongMetric;
+        public Builder metric(String inlongMetric, String auditHostAndPorts) {
+            this.inlongMetric = inlongMetric;
             this.auditHostAndPorts = auditHostAndPorts;
             return this;
         }
@@ -286,6 +345,11 @@ public class FlinkSink {
         }
 
         private <T> DataStreamSink<T> chainIcebergOperators() {
+            return multipleSink ? chainIcebergMultipleSinkOperators() : chainIcebergSingleSinkOperators();
+        }
+
+        private <T> DataStreamSink<T> chainIcebergSingleSinkOperators() {
+
             Preconditions.checkArgument(inputCreator != null,
                     "Please use forRowData() or forMapperOutputType() to initialize the input DataStream.");
             Preconditions.checkNotNull(tableLoader, "Table loader shouldn't be null");
@@ -319,6 +383,23 @@ public class FlinkSink {
             return appendDummySink(committerStream);
         }
 
+        private <T> DataStreamSink<T> chainIcebergMultipleSinkOperators() {
+            Preconditions.checkArgument(inputCreator != null,
+                    "Please use forRowData() or forMapperOutputType() to initialize the input DataStream.");
+            DataStream<RowData> rowDataInput = inputCreator.apply(uidPrefix);
+
+            // Add parallel writers that append rows to files
+            SingleOutputStreamOperator<MultipleWriteResult> writerStream = appendMultipleWriter(rowDataInput);
+
+            // Add single-parallelism committer that commits files
+            // after successful checkpoint or end of input
+            SingleOutputStreamOperator<Void> committerStream = appendMultipleCommitter(writerStream);
+
+            // Add dummy discard sink
+            return appendDummySink(committerStream);
+        }
+
+
         /**
          * Append the iceberg sink operators to write records to iceberg table.
          *
@@ -348,7 +429,8 @@ public class FlinkSink {
         private <T> DataStreamSink<T> appendDummySink(SingleOutputStreamOperator<Void> committerStream) {
             DataStreamSink<T> resultStream = committerStream
                     .addSink(new DiscardingSink())
-                    .name(operatorName(String.format("IcebergSink %s", this.table.name())))
+                    .name(operatorName(
+                            String.format("IcebergSink %s", multipleSink ? "whole migration" : this.table.name())))
                     .setParallelism(1);
             if (uidPrefix != null) {
                 resultStream = resultStream.uid(uidPrefix + "-dummysink");
@@ -357,7 +439,8 @@ public class FlinkSink {
         }
 
         private SingleOutputStreamOperator<Void> appendCommitter(SingleOutputStreamOperator<WriteResult> writerStream) {
-            IcebergFilesCommitter filesCommitter = new IcebergFilesCommitter(tableLoader, overwrite);
+            IcebergProcessOperator<WriteResult, Void> filesCommitter = new IcebergProcessOperator<>(
+                    new IcebergSingleFileCommiter(TableIdentifier.of(table.name()), tableLoader, overwrite));
             SingleOutputStreamOperator<Void> committerStream = writerStream
                     .transform(operatorName(ICEBERG_FILES_COMMITTER_NAME), Types.VOID, filesCommitter)
                     .setParallelism(1)
@@ -368,6 +451,20 @@ public class FlinkSink {
             return committerStream;
         }
 
+        private SingleOutputStreamOperator<Void> appendMultipleCommitter(
+                SingleOutputStreamOperator<MultipleWriteResult> writerStream) {
+            IcebergProcessOperator<MultipleWriteResult, Void> multipleFilesCommiter =
+                    new IcebergProcessOperator<>(new IcebergMultipleFilesCommiter(catalogLoader, overwrite));
+            SingleOutputStreamOperator<Void> committerStream = writerStream
+                    .transform(operatorName(ICEBERG_MULTIPLE_FILES_COMMITTER_NAME), Types.VOID, multipleFilesCommiter)
+                    .setParallelism(1)
+                    .setMaxParallelism(1);
+            if (uidPrefix != null) {
+                committerStream = committerStream.uid(uidPrefix + "-committer");
+            }
+            return committerStream;
+        }
+
         private SingleOutputStreamOperator<WriteResult> appendWriter(DataStream<RowData> input, RowType flinkRowType) {
             // Find out the equality field id list based on the user-provided equality field column names.
             List<Integer> equalityFieldIds = Lists.newArrayList();
@@ -381,8 +478,9 @@ public class FlinkSink {
             }
 
             // Fallback to use upsert mode parsed from table properties if don't specify in job level.
-            boolean upsertMode = upsert || PropertyUtil.propertyAsBoolean(table.properties(),
-                    UPSERT_ENABLED, UPSERT_ENABLED_DEFAULT);
+            // Only if not appendMode, upsert can be valid.
+            boolean upsertMode = (upsert || PropertyUtil.propertyAsBoolean(table.properties(),
+                    UPSERT_ENABLED, UPSERT_ENABLED_DEFAULT)) && !appendMode;
 
             // Validate the equality fields and partition fields if we enable the upsert mode.
             if (upsertMode) {
@@ -399,8 +497,8 @@ public class FlinkSink {
                 }
             }
 
-            IcebergStreamWriter<RowData> streamWriter = createStreamWriter(
-                    table, flinkRowType, equalityFieldIds, upsertMode, inLongMetric, auditHostAndPorts);
+            IcebergProcessOperator<RowData, WriteResult> streamWriter = createStreamWriter(
+                    table, flinkRowType, equalityFieldIds, upsertMode, appendMode, inlongMetric, auditHostAndPorts);
 
             int parallelism = writeParallelism == null ? input.getParallelism() : writeParallelism;
             SingleOutputStreamOperator<WriteResult> writerStream = input
@@ -414,6 +512,34 @@ public class FlinkSink {
             return writerStream;
         }
 
+        private SingleOutputStreamOperator<MultipleWriteResult> appendMultipleWriter(DataStream<RowData> input) {
+            // equality field will be initialized at runtime
+            // upsert mode will be initialized at runtime
+
+            int parallelism = writeParallelism == null ? input.getParallelism() : writeParallelism;
+            DynamicSchemaHandleOperator routeOperator = new DynamicSchemaHandleOperator(
+                    catalogLoader,
+                    multipleSinkOption);
+            SingleOutputStreamOperator<RecordWithSchema> routeStream = input
+                    .transform(operatorName(ICEBERG_WHOLE_DATABASE_MIGRATION_NAME),
+                            TypeInformation.of(RecordWithSchema.class),
+                            routeOperator)
+                    .setParallelism(parallelism);
+
+            IcebergProcessOperator streamWriter =
+                    new IcebergProcessOperator(new IcebergMultipleStreamWriter(
+                            appendMode, catalogLoader, inlongMetric, auditHostAndPorts, multipleSinkOption));
+            SingleOutputStreamOperator<MultipleWriteResult> writerStream = routeStream
+                    .transform(operatorName(ICEBERG_MULTIPLE_STREAM_WRITER_NAME),
+                            TypeInformation.of(IcebergProcessOperator.class),
+                            streamWriter)
+                    .setParallelism(parallelism);
+            if (uidPrefix != null) {
+                writerStream = writerStream.uid(uidPrefix + "-writer");
+            }
+            return writerStream;
+        }
+
         private DataStream<RowData> distributeDataStream(DataStream<RowData> input,
                 Map<String, String> properties,
                 PartitionSpec partitionSpec,
@@ -470,11 +596,12 @@ public class FlinkSink {
         }
     }
 
-    static IcebergStreamWriter<RowData> createStreamWriter(Table table,
+    static IcebergProcessOperator<RowData, WriteResult> createStreamWriter(Table table,
             RowType flinkRowType,
             List<Integer> equalityFieldIds,
             boolean upsert,
-            String inLongMetric,
+            boolean appendMode,
+            String inlongMetric,
             String auditHostAndPorts) {
         Preconditions.checkArgument(table != null, "Iceberg table should't be null");
         Map<String, String> props = table.properties();
@@ -483,10 +610,11 @@ public class FlinkSink {
 
         Table serializableTable = SerializableTable.copyOf(table);
         TaskWriterFactory<RowData> taskWriterFactory = new RowDataTaskWriterFactory(
-                serializableTable, flinkRowType, targetFileSize,
-                fileFormat, equalityFieldIds, upsert);
+                serializableTable, serializableTable.schema(), flinkRowType, targetFileSize,
+                fileFormat, equalityFieldIds, upsert, appendMode);
 
-        return new IcebergStreamWriter<>(table.name(), taskWriterFactory, inLongMetric, auditHostAndPorts);
+        return new IcebergProcessOperator<>(new IcebergSingleStreamWriter<>(
+                table.name(), taskWriterFactory, inlongMetric, auditHostAndPorts));
     }
 
     private static FileFormat getFileFormat(Map<String, String> properties) {
