@@ -53,7 +53,6 @@ import java.util.Objects;
 import java.util.Properties;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
-
 import static org.apache.flink.util.Preconditions.checkNotNull;
 import static org.apache.inlong.sort.kafka.table.KafkaOptions.KAFKA_IGNORE_ALL_CHANGELOG;
 
@@ -103,6 +102,7 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
      * The Kafka topic to write to.
      */
     protected final String topic;
+    protected final String topicPattern;
     /**
      * Properties for the Kafka producer.
      */
@@ -139,11 +139,12 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
     /**
      * Metric for inLong
      */
-    private final String inLongMetric;
+    private final String inlongMetric;
     /**
      * audit host and ports
      */
     private final String auditHostAndPorts;
+    private @Nullable final String sinkMultipleFormat;
     /**
      * Metadata that is appended at the end of a physical sink row.
      */
@@ -172,8 +173,10 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
             boolean upsertMode,
             SinkBufferFlushMode flushMode,
             @Nullable Integer parallelism,
-            String inLongMetric,
-            String auditHostAndPorts) {
+            String inlongMetric,
+            String auditHostAndPorts,
+            @Nullable String sinkMultipleFormat,
+            @Nullable String topicPattern) {
         // Format attributes
         this.consumedDataType =
                 checkNotNull(consumedDataType, "Consumed data type must not be null.");
@@ -200,8 +203,10 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                     "Sink buffer flush is only supported in upsert-kafka.");
         }
         this.parallelism = parallelism;
-        this.inLongMetric = inLongMetric;
+        this.inlongMetric = inlongMetric;
         this.auditHostAndPorts = auditHostAndPorts;
+        this.sinkMultipleFormat = sinkMultipleFormat;
+        this.topicPattern = topicPattern;
     }
 
     @Override
@@ -224,7 +229,7 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                 createSerialization(context, valueEncodingFormat, valueProjection, null);
 
         final FlinkKafkaProducer<RowData> kafkaProducer =
-                createKafkaProducer(keySerialization, valueSerialization);
+                createKafkaProducer(keySerialization, valueSerialization, sinkMultipleFormat);
 
         if (flushMode.isEnabled() && upsertMode) {
             BufferedUpsertSinkFunction buffedSinkFunction =
@@ -302,8 +307,10 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                         upsertMode,
                         flushMode,
                         parallelism,
-                        inLongMetric,
-                        auditHostAndPorts);
+                        inlongMetric,
+                        auditHostAndPorts,
+                        sinkMultipleFormat,
+                        topicPattern);
         copy.metadataKeys = metadataKeys;
         return copy;
     }
@@ -337,7 +344,7 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                 && Objects.equals(upsertMode, that.upsertMode)
                 && Objects.equals(flushMode, that.flushMode)
                 && Objects.equals(parallelism, that.parallelism)
-                && Objects.equals(inLongMetric, that.inLongMetric)
+                && Objects.equals(inlongMetric, that.inlongMetric)
                 && Objects.equals(auditHostAndPorts, that.auditHostAndPorts);
     }
 
@@ -359,15 +366,19 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                 upsertMode,
                 flushMode,
                 parallelism,
-                inLongMetric,
-                auditHostAndPorts);
+                inlongMetric,
+                auditHostAndPorts,
+                sinkMultipleFormat,
+                topicPattern);
     }
 
     // --------------------------------------------------------------------------------------------
 
     protected FlinkKafkaProducer<RowData> createKafkaProducer(
             SerializationSchema<RowData> keySerialization,
-            SerializationSchema<RowData> valueSerialization) {
+            SerializationSchema<RowData> valueSerialization,
+            String sinkMultipleFormat
+    ) {
         final List<LogicalType> physicalChildren = physicalDataType.getLogicalType().getChildren();
 
         final RowData.FieldGetter[] keyFieldGetters =
@@ -412,7 +423,9 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                         valueFieldGetters,
                         hasMetadata,
                         metadataPositions,
-                        upsertMode);
+                        upsertMode,
+                        sinkMultipleFormat,
+                        topicPattern);
 
         return new FlinkKafkaProducer<>(
                 topic,
@@ -420,11 +433,12 @@ public class KafkaDynamicSink implements DynamicTableSink, SupportsWritingMetada
                 properties,
                 FlinkKafkaProducer.Semantic.valueOf(semantic.toString()),
                 FlinkKafkaProducer.DEFAULT_KAFKA_PRODUCERS_POOL_SIZE,
-                inLongMetric,
+                inlongMetric,
                 auditHostAndPorts);
     }
 
-    private @Nullable SerializationSchema<RowData> createSerialization(
+    private @Nullable
+    SerializationSchema<RowData> createSerialization(
             Context context,
             @Nullable EncodingFormat<SerializationSchema<RowData>> format,
             int[] projection,
