@@ -29,6 +29,7 @@ import io.debezium.time.NanoTime;
 import io.debezium.time.NanoTimestamp;
 import io.debezium.time.Timestamp;
 import io.debezium.time.ZonedTimestamp;
+import java.time.ZonedDateTime;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.table.data.DecimalData;
 import org.apache.flink.table.data.GenericRowData;
@@ -40,6 +41,7 @@ import org.apache.flink.table.types.logical.LogicalType;
 import org.apache.flink.table.types.logical.RowType;
 import org.apache.flink.types.RowKind;
 import org.apache.flink.util.Collector;
+import org.apache.inlong.sort.base.filter.RowValidator;
 import org.apache.inlong.sort.cdc.debezium.DebeziumDeserializationSchema;
 import org.apache.inlong.sort.cdc.debezium.utils.TemporalConversions;
 import org.apache.kafka.connect.data.ConnectSchema;
@@ -50,15 +52,13 @@ import org.apache.kafka.connect.data.Struct;
 import org.apache.kafka.connect.source.SourceRecord;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-
-import java.io.Serializable;
-import java.math.BigDecimal;
 import java.nio.ByteBuffer;
+
+import java.math.BigDecimal;
 import java.time.Instant;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.ZoneId;
-import java.time.ZonedDateTime;
 import java.time.format.DateTimeFormatter;
 import java.util.HashMap;
 import java.util.List;
@@ -82,9 +82,7 @@ public final class RowDataDebeziumDeserializeSchema
 
     private static final DateTimeFormatter timeFormatter = DateTimeFormatter.ISO_TIME;
 
-    private static final DateTimeFormatter timestampFormatter = DateTimeFormatter.ofPattern(
-            "yyyy-MM-dd HH:mm:ss");
-
+    private static final ZoneId ZONE_UTC = ZoneId.of("UTC");
     /**
      * TypeInformation of the produced {@link RowData}. *
      */
@@ -109,7 +107,7 @@ public final class RowDataDebeziumDeserializeSchema
     /**
      * Validator to validate the row value.
      */
-    private final ValueValidator validator;
+    private final RowValidator rowKindValidator;
 
     private boolean migrateAll;
 
@@ -119,7 +117,7 @@ public final class RowDataDebeziumDeserializeSchema
             RowType physicalDataType,
             MetadataConverter[] metadataConverters,
             TypeInformation<RowData> resultTypeInfo,
-            ValueValidator validator,
+            RowValidator rowValidator,
             ZoneId serverTimeZone,
             boolean appendSource,
             DeserializationRuntimeConverterFactory userDefinedConverterFactory,
@@ -134,7 +132,7 @@ public final class RowDataDebeziumDeserializeSchema
                         serverTimeZone,
                         userDefinedConverterFactory);
         this.resultTypeInfo = checkNotNull(resultTypeInfo);
-        this.validator = checkNotNull(validator);
+        this.rowKindValidator = rowValidator;
         this.appendSource = checkNotNull(appendSource);
     }
 
@@ -600,9 +598,12 @@ public final class RowDataDebeziumDeserializeSchema
                     Schema fieldSchema = schema.field(fieldName).schema();
                     String schemaName = fieldSchema.name();
                     if (schemaName != null) {
-                        // normal type doesn't have schema name
-                        // schema names are time schemas
-                        fieldValue = getTimeValue(fieldValue, schemaName);
+                        fieldValue = getValueWithSchema(fieldValue, schemaName);
+                    }
+                    if (fieldValue instanceof ByteBuffer) {
+                        // binary data (blob or varbinary in mysql) are stored in bytebuffer
+                        // use utf-8 to decode as a string by default
+                        fieldValue = new String(((ByteBuffer) fieldValue).array());
                     }
                     data.put(fieldName, fieldValue);
                 }
@@ -616,13 +617,16 @@ public final class RowDataDebeziumDeserializeSchema
     }
 
     /**
-     * transform debezium time format to database format
+     * extract the data with the format provided by debezium
      *
      * @param fieldValue
      * @param schemaName
-     * @return
+     * @return the extracted data with schema
      */
-    private Object getTimeValue(Object fieldValue, String schemaName) {
+    private Object getValueWithSchema(Object fieldValue, String schemaName) {
+        if (fieldValue == null) {
+            return null;
+        }
         switch (schemaName) {
             case MicroTime.SCHEMA_NAME:
                 Instant instant = Instant.ofEpochMilli((Long) fieldValue / 1000);
@@ -633,16 +637,18 @@ public final class RowDataDebeziumDeserializeSchema
                 break;
             case ZonedTimestamp.SCHEMA_NAME:
                 ZonedDateTime zonedDateTime = ZonedDateTime.parse((CharSequence) fieldValue);
-                fieldValue = timestampFormatter.format(zonedDateTime
-                        .withZoneSameInstant(serverTimeZone).toLocalDateTime());
+                fieldValue = zonedDateTime.withZoneSameInstant(serverTimeZone).toLocalDateTime()
+                    .atZone(ZONE_UTC).format(DateTimeFormatter.ISO_INSTANT);
                 break;
             case Timestamp.SCHEMA_NAME:
                 Instant instantTime = Instant.ofEpochMilli((Long) fieldValue);
-                fieldValue = timestampFormatter.format(LocalDateTime.ofInstant(instantTime,
-                        serverTimeZone));
+                fieldValue = LocalDateTime.ofInstant(instantTime, ZONE_UTC).toString();
+                break;
+            case Decimal.LOGICAL_NAME:
+                // no need to transfer decimal type since the value is already decimal
                 break;
             default:
-                LOG.error("parse schema {} error", schemaName);
+                LOG.debug("schema {} is not being supported", schemaName);
         }
         return fieldValue;
     }
@@ -661,24 +667,20 @@ public final class RowDataDebeziumDeserializeSchema
         Schema valueSchema = record.valueSchema();
         if (op == Envelope.Operation.CREATE || op == Envelope.Operation.READ) {
             GenericRowData insert = extractAfterRow(value, valueSchema);
-            validator.validate(insert, RowKind.INSERT);
             insert.setRowKind(RowKind.INSERT);
             emit(record, insert, tableSchema, out);
         } else if (op == Envelope.Operation.DELETE) {
             GenericRowData delete = extractBeforeRow(value, valueSchema);
-            validator.validate(delete, RowKind.DELETE);
             delete.setRowKind(RowKind.DELETE);
             emit(record, delete, tableSchema, out);
         } else {
             if (!appendSource) {
                 GenericRowData before = extractBeforeRow(value, valueSchema);
-                validator.validate(before, RowKind.UPDATE_BEFORE);
                 before.setRowKind(RowKind.UPDATE_BEFORE);
                 emit(record, before, tableSchema, out);
             }
 
             GenericRowData after = extractAfterRow(value, valueSchema);
-            validator.validate(after, RowKind.UPDATE_AFTER);
             after.setRowKind(RowKind.UPDATE_AFTER);
             emit(record, after, tableSchema, out);
         }
@@ -699,6 +701,9 @@ public final class RowDataDebeziumDeserializeSchema
     private void emit(SourceRecord inRecord, RowData physicalRow,
                       TableChange tableChange, Collector<RowData> collector
     ) {
+        if (!rowKindValidator.validate(physicalRow.getRowKind())) {
+            return;
+        }
         if (appendSource) {
             physicalRow.setRowKind(RowKind.INSERT);
         }
@@ -717,14 +722,6 @@ public final class RowDataDebeziumDeserializeSchema
         return resultTypeInfo;
     }
 
-    /**
-     * Custom validator to validate the row value.
-     */
-    public interface ValueValidator extends Serializable {
-
-        void validate(RowData rowData, RowKind rowKind) throws Exception;
-    }
-
     /**
      * Builder of {@link RowDataDebeziumDeserializeSchema}.
      */
@@ -733,8 +730,7 @@ public final class RowDataDebeziumDeserializeSchema
         private RowType physicalRowType;
         private TypeInformation<RowData> resultTypeInfo;
         private MetadataConverter[] metadataConverters = new MetadataConverter[0];
-        private ValueValidator validator = (rowData, rowKind) -> {
-        };
+        private RowValidator rowValidator;
         private ZoneId serverTimeZone = ZoneId.of("UTC");
         private boolean appendSource = false;
         private boolean migrateAll = false;
@@ -761,8 +757,8 @@ public final class RowDataDebeziumDeserializeSchema
             return this;
         }
 
-        public Builder setValueValidator(ValueValidator validator) {
-            this.validator = validator;
+        public Builder setValidator(RowValidator rowFilter) {
+            this.rowValidator = rowFilter;
             return this;
         }
 
@@ -787,7 +783,7 @@ public final class RowDataDebeziumDeserializeSchema
                     physicalRowType,
                     metadataConverters,
                     resultTypeInfo,
-                    validator,
+                    rowValidator,
                     serverTimeZone,
                     appendSource,
                     userDefinedConverterFactory,
