@@ -17,17 +17,20 @@
 
 package org.apache.inlong.sort.parser;
 
+import java.util.ArrayList;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.table.api.EnvironmentSettings;
 import org.apache.flink.table.api.bridge.java.StreamTableEnvironment;
 import org.apache.inlong.common.enums.MetaField;
 import org.apache.inlong.sort.formats.common.StringFormatInfo;
+import org.apache.inlong.sort.formats.common.VarBinaryFormatInfo;
 import org.apache.inlong.sort.parser.impl.FlinkSqlParser;
 import org.apache.inlong.sort.parser.result.ParseResult;
 import org.apache.inlong.sort.protocol.FieldInfo;
 import org.apache.inlong.sort.protocol.GroupInfo;
 import org.apache.inlong.sort.protocol.MetaFieldInfo;
 import org.apache.inlong.sort.protocol.StreamInfo;
+import org.apache.inlong.sort.protocol.enums.ExtractMode;
 import org.apache.inlong.sort.protocol.node.Node;
 import org.apache.inlong.sort.protocol.node.extract.MySqlExtractNode;
 import org.apache.inlong.sort.protocol.node.format.CsvFormat;
@@ -47,23 +50,41 @@ import java.util.stream.Collectors;
 public class AllMigrateTest {
 
     private MySqlExtractNode buildAllMigrateExtractNode() {
-        List<FieldInfo> fields = Arrays.asList(
-                new MetaFieldInfo("data", MetaField.DATA));
+
         Map<String, String> option = new HashMap<>();
         option.put("append-mode", "true");
         option.put("migrate-all", "true");
-        MySqlExtractNode node = new MySqlExtractNode("1", "mysql_input", fields,
+        List<String> tables = new ArrayList(10);
+        tables.add("test.*");
+        List<FieldInfo> fields = Collections.singletonList(
+            new MetaFieldInfo("data", MetaField.DATA));
+
+        return new MySqlExtractNode("1", "mysql_input", fields,
                 null, option, null,
-                Arrays.asList("[\\s\\S]*.*"), "localhost", "root", "password",
-                "[\\s\\S]*.*", null, null, false, null);
-        return node;
+            tables, "localhost", "root", "inlong",
+                "test", null, null, false, null,
+            ExtractMode.CDC, null,null);
     }
 
-    private KafkaLoadNode buildAllMigrateKafkaNode() {
-        List<FieldInfo> fields = Arrays.asList(new FieldInfo("data", new StringFormatInfo()));
-        List<FieldRelation> relations = Arrays
-                .asList(new FieldRelation(new FieldInfo("data", new StringFormatInfo()),
-                        new FieldInfo("data", new StringFormatInfo())));
+    private MySqlExtractNode buildAllMigrateExtractNodeWithBytesFormat() {
+        List<FieldInfo> fields = Collections.singletonList(
+            new MetaFieldInfo("data", MetaField.DATA_BYTES_DEBEZIUM));
+        Map<String, String> option = new HashMap<>();
+        option.put("append-mode", "true");
+        option.put("migrate-all", "true");
+        return new MySqlExtractNode("1", "mysql_input", fields,
+            null, option, null,
+            Collections.singletonList("test"), "localhost", "root", "inlong",
+            "test", null, null, false, "UTC-8", ExtractMode.CDC,
+            null, null);
+    }
+
+    private KafkaLoadNode buildAllMigrateKafkaNodeWithBytesFormat() {
+        List<FieldInfo> fields = Collections.singletonList(
+            new FieldInfo("data", new VarBinaryFormatInfo()));
+        List<FieldRelation> relations = Collections.singletonList(
+            new FieldRelation(new FieldInfo("data", new VarBinaryFormatInfo()),
+                new FieldInfo("data", new VarBinaryFormatInfo())));
         CsvFormat csvFormat = new CsvFormat();
         csvFormat.setDisableQuoteCharacter(true);
         return new KafkaLoadNode("2", "kafka_output", fields, relations, null, null,
@@ -72,6 +93,20 @@ public class AllMigrateTest {
                 null, null);
     }
 
+    private KafkaLoadNode buildAllMigrateKafkaNode() {
+        List<FieldInfo> fields = Collections.singletonList(
+            new FieldInfo("data", new StringFormatInfo()));
+        List<FieldRelation> relations = Collections.singletonList(
+            new FieldRelation(new FieldInfo("data", new StringFormatInfo()),
+                new FieldInfo("data", new StringFormatInfo())));
+        CsvFormat csvFormat = new CsvFormat();
+        csvFormat.setDisableQuoteCharacter(true);
+        return new KafkaLoadNode("2", "kafka_output", fields, relations, null, null,
+            "topic", "localhost:9092",
+            csvFormat, null,
+            null, null);
+    }
+
     private NodeRelation buildNodeRelation(List<Node> inputs, List<Node> outputs) {
         List<String> inputIds = inputs.stream().map(Node::getId).collect(Collectors.toList());
         List<String> outputIds = outputs.stream().map(Node::getId).collect(Collectors.toList());
@@ -79,7 +114,7 @@ public class AllMigrateTest {
     }
 
     /**
-     * Test flink sql parse
+     * Test all migrate, the full database data is represented as a canal string
      *
      * @throws Exception The exception may throws when execute the case
      */
@@ -103,7 +138,33 @@ public class AllMigrateTest {
         FlinkSqlParser parser = FlinkSqlParser.getInstance(tableEnv, groupInfo);
         ParseResult result = parser.parse();
         Assert.assertTrue(result.tryExecute());
+    }
 
+    /**
+     * Test all migrate, the full database data is represented as bytes of canal json
+     *
+     * @throws Exception The exception may throws when execute the case
+     */
+    @Test
+    public void testAllMigrateWithBytesFormat() throws Exception {
+        EnvironmentSettings settings = EnvironmentSettings
+            .newInstance()
+            .useBlinkPlanner()
+            .inStreamingMode()
+            .build();
+        StreamExecutionEnvironment env = StreamExecutionEnvironment.getExecutionEnvironment();
+        env.setParallelism(1);
+        env.enableCheckpointing(10000);
+        StreamTableEnvironment tableEnv = StreamTableEnvironment.create(env, settings);
+        Node inputNode = buildAllMigrateExtractNodeWithBytesFormat();
+        Node outputNode = buildAllMigrateKafkaNodeWithBytesFormat();
+        StreamInfo streamInfo = new StreamInfo("1", Arrays.asList(inputNode, outputNode),
+            Collections.singletonList(buildNodeRelation(Collections.singletonList(inputNode),
+                Collections.singletonList(outputNode))));
+        GroupInfo groupInfo = new GroupInfo("1", Collections.singletonList(streamInfo));
+        FlinkSqlParser parser = FlinkSqlParser.getInstance(tableEnv, groupInfo);
+        ParseResult result = parser.parse();
+        Assert.assertTrue(result.tryExecute());
     }
 
 }
