@@ -52,6 +52,7 @@ import org.apache.inlong.tubemq.corebase.utils.DataConverterUtil;
 import org.apache.inlong.tubemq.corebase.utils.MixedUtils;
 import org.apache.inlong.tubemq.corebase.utils.TStringUtils;
 import org.apache.inlong.tubemq.corebase.utils.ThreadUtils;
+import org.apache.inlong.tubemq.corebase.utils.Tuple2;
 import org.apache.inlong.tubemq.corerpc.RpcConfig;
 import org.apache.inlong.tubemq.corerpc.RpcConstants;
 import org.apache.inlong.tubemq.corerpc.RpcServiceFactory;
@@ -81,8 +82,8 @@ public class ProducerManager {
     private final ScheduledExecutorService heartbeatService;
     private final AtomicLong visitToken =
             new AtomicLong(TBaseConstants.META_VALUE_UNDEFINED);
-    private final AllowedSetting allowedSetting =
-            new AllowedSetting();
+    private final MaxMsgSizeHolder msgSizeHolder =
+            new MaxMsgSizeHolder();
     private final AtomicReference<String> authAuthorizedTokenRef =
             new AtomicReference<>("");
     private final ClientAuthenticateHandler authenticateHandler =
@@ -341,10 +342,11 @@ public class ProducerManager {
     /**
      * Get allowed message size.
      *
+     * @param topicName  the topic name
      * @return max allowed message size
      */
-    public int getMaxMsgSize() {
-        return allowedSetting.getMaxMsgSize();
+    public int getMaxMsgSize(String topicName) {
+        return msgSizeHolder.getDefMaxMsgSize(topicName);
     }
 
     /**
@@ -516,27 +518,32 @@ public class ProducerManager {
         return builder.build();
     }
 
-    private void updateTopicPartitions(List<TopicInfo> topicInfoList) {
+    private void updateTopicConfigure(
+            Tuple2<Map<String, Integer>, List<TopicInfo>> topicInfoTuple) {
+        int baseValue;
+        Partition tmpPart;
+        List<Partition> partList;
+        Map<Integer, List<Partition>> brokerPartList;
+        // update topic max msg size
+        msgSizeHolder.updTopicMaxSizeInB(topicInfoTuple.getF0());
+        // update topic Partition info
         Map<String, Map<Integer, List<Partition>>> partitionListMap =
                 new ConcurrentHashMap<>();
-        for (TopicInfo topicInfo : topicInfoList) {
-            Map<Integer, List<Partition>> brokerPartList =
+        for (TopicInfo topicInfo : topicInfoTuple.getF1()) {
+            brokerPartList =
                     partitionListMap.get(topicInfo.getTopic());
             if (brokerPartList == null) {
                 brokerPartList = new ConcurrentHashMap<>();
                 partitionListMap.put(topicInfo.getTopic(), brokerPartList);
             }
             for (int j = 0; j < topicInfo.getTopicStoreNum(); j++) {
-                int baseValue = j * TBaseConstants.META_STORE_INS_BASE;
+                baseValue = j * TBaseConstants.META_STORE_INS_BASE;
                 for (int i = 0; i < topicInfo.getPartitionNum(); i++) {
-                    Partition part =
-                            new Partition(topicInfo.getBroker(), topicInfo.getTopic(), baseValue + i);
-                    List<Partition> partList = brokerPartList.get(part.getBrokerId());
-                    if (partList == null) {
-                        partList = new ArrayList<>();
-                        brokerPartList.put(part.getBrokerId(), partList);
-                    }
-                    partList.add(part);
+                    tmpPart = new Partition(topicInfo.getBroker(),
+                            topicInfo.getTopic(), baseValue + i);
+                    partList = brokerPartList.computeIfAbsent(
+                            tmpPart.getBrokerId(), k -> new ArrayList<>());
+                    partList.add(tmpPart);
                 }
             }
         }
@@ -560,8 +567,8 @@ public class ProducerManager {
                                       long pkgCheckSum, StringBuilder sBuilder) {
         if (pkgCheckSum != brokerInfoCheckSum) {
             if (pkgBrokerInfos != null) {
-                brokersMap =
-                        DataConverterUtil.convertBrokerInfo(pkgBrokerInfos);
+                brokersMap = DataConverterUtil.convertBrokerInfo(
+                        pkgBrokerInfos, tubeClientConfig.isTlsEnable());
                 brokerInfoCheckSum = pkgCheckSum;
                 lastBrokerUpdatedTime = System.currentTimeMillis();
                 if (pkgBrokerInfos.isEmpty()) {
@@ -595,20 +602,36 @@ public class ProducerManager {
             processAuthorizedToken(response.getAuthorizedInfo());
         }
         if (response.hasAppdConfig()) {
-            procAllowedConfig4P(response.getAppdConfig());
+            msgSizeHolder.updAllowedSetting(response.getAppdConfig());
         }
     }
 
-    private void processHeartBeatSyncInfo(ClientMaster.HeartResponseM2P response) {
+    private void processHeartBeatSyncInfo(ClientMaster.HeartResponseM2P response,
+                                          StringBuilder strBuff) {
         if (response.hasRequireAuth()) {
             nextWithAuthInfo2M.set(response.getRequireAuth());
         }
         if (response.hasAppdConfig()) {
-            procAllowedConfig4P(response.getAppdConfig());
+            msgSizeHolder.updAllowedSetting(response.getAppdConfig());
         }
         if (response.hasAuthorizedInfo()) {
             processAuthorizedToken(response.getAuthorizedInfo());
         }
+        if (response.getErrCode() == TErrCodeConstants.NOT_READY) {
+            lastHeartbeatTime = System.currentTimeMillis();
+            return;
+        }
+        if (response.getBrokerCheckSum() != brokerInfoCheckSum) {
+            updateBrokerInfoList(false, response.getBrokerInfosList(),
+                    response.getBrokerCheckSum(), strBuff);
+        }
+        if (response.getTopicInfosList().isEmpty()
+                && System.currentTimeMillis() - lastEmptyTopicPrintTime > 60000) {
+            logger.warn("[Heartbeat Update] found empty topicList update!");
+            lastEmptyTopicPrintTime = System.currentTimeMillis();
+        }
+        updateTopicConfigure(DataConverterUtil
+                .convertTopicInfo(brokersMap, response.getTopicInfosList()));
     }
 
     private void processAuthorizedToken(ClientMaster.MasterAuthorizedInfo inAuthorizedTokenInfo) {
@@ -654,27 +677,20 @@ public class ProducerManager {
     private ClientMaster.ApprovedClientConfig.Builder buildAllowedConfig4P() {
         ClientMaster.ApprovedClientConfig.Builder appdConfig =
                 ClientMaster.ApprovedClientConfig.newBuilder();
-        appdConfig.setConfigId(allowedSetting.getConfigId());
+        appdConfig.setConfigId(msgSizeHolder.getConfigId());
         return appdConfig;
     }
 
-    // set allowed configure info
-    private void procAllowedConfig4P(ClientMaster.ApprovedClientConfig allowedConfig) {
-        if (allowedConfig != null) {
-            allowedSetting.updAllowedSetting(allowedConfig);
-        }
-    }
-
     // #lizard forgives
     private class ProducerHeartbeatTask implements Runnable {
         @Override
         public void run() {
-            StringBuilder sBuilder = new StringBuilder(512);
+            StringBuilder strBuff = new StringBuilder(512);
             while (!heartBeatStatus.compareAndSet(0, 1)) {
                 ThreadUtils.sleep(100);
             }
             // print metrics information
-            clientStatsInfo.selfPrintStatsInfo(false, true, sBuilder);
+            clientStatsInfo.selfPrintStatsInfo(false, true, strBuff);
             // check whether public topics
             if (publishTopics.isEmpty()) {
                 return;
@@ -689,71 +705,49 @@ public class ProducerManager {
                         clientStatsInfo.bookHB2MasterException();
                         logger.error("[Heartbeat Failed] receive null HeartResponseM2P response!");
                     } else {
-                        logger.error(sBuilder.append("[Heartbeat Failed] ")
+                        logger.error(strBuff.append("[Heartbeat Failed] ")
                                 .append(response.getErrMsg()).toString());
-                        sBuilder.delete(0, sBuilder.length());
+                        strBuff.delete(0, strBuff.length());
                         if (response.getErrCode() == TErrCodeConstants.HB_NO_NODE) {
                             clientStatsInfo.bookHB2MasterTimeout();
                             try {
                                 register2Master();
                             } catch (Throwable ee) {
-                                logger.error(sBuilder
+                                logger.error(strBuff
                                     .append("[Heartbeat Failed] re-register failure, error is ")
                                     .append(ee.getMessage()).toString());
-                                sBuilder.delete(0, sBuilder.length());
+                                strBuff.delete(0, strBuff.length());
                             }
                         } else {
                             clientStatsInfo.bookHB2MasterException();
                             if (response.getErrCode() == TErrCodeConstants.CERTIFICATE_FAILURE) {
-                                adjustHeartBeatPeriod("certificate failure", sBuilder);
+                                adjustHeartBeatPeriod("certificate failure", strBuff);
                             }
                         }
                     }
                     return;
                 }
-                processHeartBeatSyncInfo(response);
-                if (response.getErrCode() == TErrCodeConstants.NOT_READY) {
-                    lastHeartbeatTime = System.currentTimeMillis();
-                    return;
-                }
-                if (response.getBrokerCheckSum() != brokerInfoCheckSum) {
-                    updateBrokerInfoList(false, response.getBrokerInfosList(),
-                            response.getBrokerCheckSum(), sBuilder);
-                }
-                if (response.getTopicInfosList() != null) {
-                    if (response.getTopicInfosList().isEmpty()
-                            && System.currentTimeMillis() - lastEmptyTopicPrintTime > 60000) {
-                        logger.warn("[Heartbeat Update] found empty topicList update!");
-                        lastEmptyTopicPrintTime = System.currentTimeMillis();
-                    }
-                    updateTopicPartitions(DataConverterUtil
-                            .convertTopicInfo(brokersMap, response.getTopicInfosList()));
-                } else {
-                    logger.error(sBuilder
-                            .append("[Heartbeat Failed] Found brokerList or topicList is null, brokerList is ")
-                            .append(response.getBrokerInfosList() != null).toString());
-                    sBuilder.delete(0, sBuilder.length());
-                }
+                processHeartBeatSyncInfo(response, strBuff);
                 heartbeatRetryTimes = 0;
                 long currentTime = System.currentTimeMillis();
                 if ((currentTime - lastHeartbeatTime)
                         > (tubeClientConfig.getHeartbeatPeriodMs() * 4)) {
-                    logger.warn(sBuilder.append(producerId)
+                    logger.warn(strBuff.append(producerId)
                             .append(" heartbeat interval is too long, please check! Total time : ")
                             .append(currentTime - lastHeartbeatTime).toString());
-                    sBuilder.delete(0, sBuilder.length());
+                    strBuff.delete(0, strBuff.length());
                 }
                 lastHeartbeatTime = currentTime;
             } catch (Throwable e) {
-                sBuilder.delete(0, sBuilder.length());
+                strBuff.delete(0, strBuff.length());
                 if (!(e.getCause() != null
                         && e.getCause() instanceof ClientClosedException)) {
                     logger.error("Heartbeat failed,retry later.Reason:{}",
-                            sBuilder.append(e.getClass().getSimpleName())
+                            strBuff.append(e.getClass().getSimpleName())
                                     .append("#").append(e.getMessage()).toString());
-                    sBuilder.delete(0, sBuilder.length());
+                    strBuff.delete(0, strBuff.length());
                 }
-                adjustHeartBeatPeriod("heartbeat exception", sBuilder);
+                adjustHeartBeatPeriod("heartbeat exception", strBuff);
             } finally {
                 heartBeatStatus.compareAndSet(1, 0);
             }
