@@ -316,11 +316,11 @@ public class SimpleMessageProducer implements MessageProducer {
         }
         int msgSize = TStringUtils.isBlank(message.getAttribute())
                 ? message.getData().length : (message.getData().length + message.getAttribute().length());
-        if (msgSize > producerManager.getMaxMsgSize()) {
+        if (msgSize > producerManager.getMaxMsgSize(message.getTopic())) {
             throw new TubeClientException(new StringBuilder(512)
                     .append("Illegal parameter: over max message length for the total size of")
                     .append(" message data and attribute, allowed size is ")
-                    .append(producerManager.getMaxMsgSize())
+                    .append(producerManager.getMaxMsgSize(message.getTopic()))
                     .append(", message's real size is ").append(msgSize).toString());
         }
         if (isShutDown.get()) {
