@@ -223,6 +223,7 @@ public class MessageStoreManager implements StoreService {
             if (targetTopics.isEmpty()) {
                 return removedTopics;
             }
+            logger.info("[Remove Topic] start remove topics : {}", targetTopics);
             for (String tmpTopic : targetTopics) {
                 ConcurrentHashMap<Integer, MessageStore> topicStores =
                         dataStores.get(tmpTopic);
@@ -246,14 +247,15 @@ public class MessageStoreManager implements StoreService {
                 if (tmpTopicConf != null) {
                     StringBuilder sBuilder = new StringBuilder(512);
                     for (int storeId = 0; storeId < tmpTopicConf.getNumTopicStores(); storeId++) {
-                        String storeDir = sBuilder.append(tmpTopicConf.getDataPath())
+                        String storeDir = sBuilder.append(tubeConfig.getPrimaryPath())
                                 .append(File.separator).append(tmpTopic).append("-")
                                 .append(storeId).toString();
                         sBuilder.delete(0, sBuilder.length());
+                        logger.info("[Remove Topic] remove topic files : {}", storeDir);
                         try {
                             delTopicFiles(storeDir);
                         } catch (Throwable e) {
-                            logger.error("[Remove Topic] Remove topic data error : ", e);
+                            logger.error("[Remove Topic] remove topic files error : ", e);
                         }
                         ThreadUtils.sleep(50);
                     }
@@ -262,6 +264,7 @@ public class MessageStoreManager implements StoreService {
                 }
                 ThreadUtils.sleep(100);
             }
+            logger.info("[Remove Topic] finished remove topics : {}", removedTopics);
             return removedTopics;
         } finally {
             this.isRemovingTopic.set(false);
@@ -366,7 +369,7 @@ public class MessageStoreManager implements StoreService {
         try {
             final long maxOffset = msgStore.getIndexMaxOffset();
             ConsumerNodeInfo consumerNodeInfo =
-                    new ConsumerNodeInfo(tubeBroker.getStoreManager(),
+                    new ConsumerNodeInfo(tubeBroker.getStoreManager(), "visit",
                             "visit", filterCondSet, "", System.currentTimeMillis(), "", "");
             int maxIndexReadSize = (msgCount + 1)
                     * DataStoreUtils.STORE_INDEX_HEAD_LEN * msgStore.getPartitionNum();
@@ -421,16 +424,18 @@ public class MessageStoreManager implements StoreService {
         if (qryTopicSet.isEmpty()) {
             return topicPubStoreInfoMap;
         }
+        Map<Integer, MessageStore> storeMap;
+        Map<Integer, TopicPubStoreInfo> storeInfoMap;
         for (String topic : qryTopicSet) {
             topicMetadata = confTopicInfo.get(topic);
             if (topicMetadata == null) {
                 continue;
             }
-            Map<Integer, MessageStore> storeMap = dataStores.get(topic);
+            storeMap = dataStores.get(topic);
             if (storeMap == null) {
                 continue;
             }
-            Map<Integer, TopicPubStoreInfo> storeInfoMap = new HashMap<>();
+            storeInfoMap = new HashMap<>();
             for (Map.Entry<Integer, MessageStore> entry : storeMap.entrySet()) {
                 if (entry == null
                         || entry.getKey() == null
@@ -439,11 +444,10 @@ public class MessageStoreManager implements StoreService {
                 }
                 store = entry.getValue();
                 for (Integer partitionId : topicMetadata.getPartIdsByStoreId(entry.getKey())) {
-                    TopicPubStoreInfo storeInfo =
-                            new TopicPubStoreInfo(topic, entry.getKey(), partitionId,
-                                    store.getIndexMinOffset(), store.getIndexMaxOffset(),
-                                    store.getDataMinOffset(), store.getDataMaxOffset());
-                    storeInfoMap.put(partitionId, storeInfo);
+                    storeInfoMap.put(partitionId, new TopicPubStoreInfo(topic,
+                            entry.getKey(), partitionId, store.getIndexMinOffset(),
+                            store.getIndexMaxOffset(), store.getDataMinOffset(),
+                            store.getDataMaxOffset()));
                 }
             }
             topicPubStoreInfoMap.put(topic, storeInfoMap);
@@ -460,12 +464,13 @@ public class MessageStoreManager implements StoreService {
     @Override
     public void getTopicPublishInfos(Map<String, OffsetRecordInfo> groupOffsetMap) {
         MessageStore store = null;
+        Map<Integer, MessageStore> storeMap;
+        Map<String, Map<Integer, RecordItem>> topicOffsetMap;
         for (Map.Entry<String, OffsetRecordInfo> entry : groupOffsetMap.entrySet()) {
             if (entry == null || entry.getKey() == null || entry.getValue() == null) {
                 continue;
             }
-            Map<String, Map<Integer, RecordItem>> topicOffsetMap =
-                    entry.getValue().getOffsetMap();
+            topicOffsetMap = entry.getValue().getOffsetMap();
             // Get offset records by topic
             for (Map.Entry<String, Map<Integer, RecordItem>> entryTopic
                     : topicOffsetMap.entrySet()) {
@@ -475,8 +480,7 @@ public class MessageStoreManager implements StoreService {
                     continue;
                 }
                 // Get message store instance
-                Map<Integer, MessageStore> storeMap =
-                        dataStores.get(entryTopic.getKey());
+                storeMap = dataStores.get(entryTopic.getKey());
                 if (storeMap == null) {
                     continue;
                 }
