@@ -62,7 +62,7 @@ public class MasterConfig extends AbstractFileConfig {
     private long stepChgWaitPeriodMs = 12 * 1000;
     private String confModAuthToken = "ASDFGHJKL";
     private String webResourcePath = "../resources";
-    private int maxGroupBrokerConsumeRate = 50;
+    private int maxGroupBrokerConsumeRate = 1000;
     private int maxGroupRebalanceWaitPeriod = 2;
     private int maxAutoForbiddenCnt = 5;
     private long socketSendBuffer = -1;
@@ -508,12 +508,12 @@ public class MasterConfig extends AbstractFileConfig {
         if (this.needBrokerVisitAuth) {
             if (TStringUtils.isBlank(masterConf.get("visitName"))) {
                 throw new IllegalArgumentException(new StringBuilder(256)
-                        .append("visitName is null or Blank in ").append(SECT_TOKEN_BROKER)
+                        .append("visitName is null or Blank in ").append(SECT_TOKEN_MASTER)
                         .append(" section!").toString());
             }
             if (TStringUtils.isBlank(masterConf.get("visitPassword"))) {
                 throw new IllegalArgumentException(new StringBuilder(256)
-                        .append("visitPassword is null or Blank in ").append(SECT_TOKEN_BROKER)
+                        .append("visitPassword is null or Blank in ").append(SECT_TOKEN_MASTER)
                         .append(" section!").toString());
             }
             this.visitName = masterConf.get("visitName").trim();
@@ -619,6 +619,9 @@ public class MasterConfig extends AbstractFileConfig {
         if (TStringUtils.isNotBlank(zkeeperSect.get("zkMasterCheckPeriodMs"))) {
             zkMetaConfig.setZkMasterCheckPeriodMs(getInt(zkeeperSect, "zkMasterCheckPeriodMs"));
         }
+        if (TStringUtils.isNotBlank(zkeeperSect.get("zkRequestTimeoutMs"))) {
+            zkMetaConfig.setZkRequestTimeoutMs(getInt(zkeeperSect, "zkRequestTimeoutMs"));
+        }
         return zkMetaConfig;
     }
 
