@@ -446,6 +446,30 @@ public abstract class AbsTopicDeployMapperImpl implements TopicDeployMapper {
         return retEntityMap;
     }
 
+    @Override
+    public Set<Integer> getDeployedBrokerIdByTopic(Set<String> topicNameSet) {
+        ConcurrentHashSet<String> keySet;
+        Set<Integer> retSet = new HashSet<>();
+        if (topicNameSet == null || topicNameSet.isEmpty()) {
+            return retSet;
+        }
+        for (String topicName : topicNameSet) {
+            if (topicName == null) {
+                continue;
+            }
+            keySet = topicName2RecordCache.get(topicName);
+            if (keySet != null) {
+                for (String key : keySet) {
+                    TopicDeployEntity entry = topicDeployCache.get(key);
+                    if (entry != null) {
+                        retSet.add(entry.getBrokerId());
+                    }
+                }
+            }
+        }
+        return retSet;
+    }
+
     @Override
     public Set<String> getDeployedTopicSet() {
         return new HashSet<>(topicName2RecordCache.keySet());
@@ -533,7 +557,7 @@ public abstract class AbsTopicDeployMapperImpl implements TopicDeployMapper {
         if (keySet != null) {
             keySet.remove(recordKey);
             if (keySet.isEmpty()) {
-                topicName2RecordCache.remove(curEntity.getTopicName());
+                topicName2RecordCache.remove(curEntity.getTopicName(), new ConcurrentHashSet<>());
             }
         }
         // delete brokerId index
@@ -541,7 +565,7 @@ public abstract class AbsTopicDeployMapperImpl implements TopicDeployMapper {
         if (keySet != null) {
             keySet.remove(recordKey);
             if (keySet.isEmpty()) {
-                brokerId2RecordCache.remove(curEntity.getBrokerId());
+                brokerId2RecordCache.remove(curEntity.getBrokerId(), new ConcurrentHashSet<>());
             }
         }
         // delete broker topic map
@@ -549,7 +573,7 @@ public abstract class AbsTopicDeployMapperImpl implements TopicDeployMapper {
         if (keySet != null) {
             keySet.remove(curEntity.getTopicName());
             if (keySet.isEmpty()) {
-                brokerId2TopicNameCache.remove(curEntity.getBrokerId());
+                brokerId2TopicNameCache.remove(curEntity.getBrokerId(), new ConcurrentHashSet<>());
             }
         }
     }
